@@ -202,8 +202,6 @@ void BasicIDEShell::Init()
     pObjectCatalog = 0;
     bCreatingWindow = sal_False;
 
-    bObjectCatalogDisplay = sal_True;
-
     pTabBar = new BasicIDETabBar( &GetViewFrame()->GetWindow() );
     pTabBar->SetSplitHdl( LINK( this, BasicIDEShell, TabBarSplitHdl ) );
     bTabBarSplitted = sal_False;
@@ -554,11 +552,7 @@ void BasicIDEShell::ShowObjectDialog( sal_Bool bShow, sal_Bool bCreateOrDestroy
             if ( pObjectCatalog )
             {
                 pObjectCatalog->SetCancelHdl( LINK( this, BasicIDEShell, ObjectDialogCancelHdl ) );
-                BasicEntryDescriptor aDesc;
-                IDEBaseWindow* pCurWin_ = GetCurWindow();
-                if ( pCurWin_ )
-                    aDesc = pCurWin_->CreateEntryDescriptor();
-                pObjectCatalog->SetCurrentEntry( aDesc );
+                pObjectCatalog->SetCurrentEntry(pCurWin);
             }
         }
 
