@@ -42,9 +42,11 @@
 #include <basic/sbmod.hxx>
 #include <unotools/intlwrapper.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/string.hxx>
 
 #include <basic/sbuno.hxx>
 #include <basic/basmgr.hxx>
+#include <basic/global.hxx>
 #include <sbunoobj.hxx>
 #include "basrid.hxx"
 #include "sbintern.hxx"
@@ -87,10 +89,6 @@ typedef WeakImplHelper1< XStarBasicModuleInfo > ModuleInfoHelper;
 typedef WeakImplHelper1< XStarBasicDialogInfo > DialogInfoHelper;
 typedef WeakImplHelper1< XStarBasicLibraryInfo > LibraryInfoHelper;
 typedef WeakImplHelper1< XStarBasicAccess > StarBasicAccessHelper;
-typedef vector< BasicError* > BasErrorLst;
-
-
-#define CURR_VER        2
 
 // Version 1
 //    sal_uIntPtr   nEndPos
@@ -381,68 +379,6 @@ void SAL_CALL BasMgrContainerListenerImpl::elementRemoved( const ContainerEvent&
     }
 }
 
-
-//=====================================================================
-
-class BasicErrorManager
-{
-private:
-    BasErrorLst aErrorList;
-    size_t CurrentError;
-
-public:
-                BasicErrorManager();
-                ~BasicErrorManager();
-
-    void        Reset();
-    void        InsertError( const BasicError& rError );
-
-    bool        HasErrors()         { return !aErrorList.empty(); }
-    BasicError* GetFirstError();
-    BasicError* GetNextError();
-};
-
-BasicErrorManager::BasicErrorManager()
-    : CurrentError( 0 )
-{
-}
-
-BasicErrorManager::~BasicErrorManager()
-{
-    Reset();
-}
-
-void BasicErrorManager::Reset()
-{
-    for ( size_t i = 0, n = aErrorList.size(); i < n; ++i )
-        delete aErrorList[ i ];
-    aErrorList.clear();
-}
-
-void BasicErrorManager::InsertError( const BasicError& rError )
-{
-    aErrorList.push_back( new BasicError( rError ) );
-}
-
-BasicError* BasicErrorManager::GetFirstError()
-{
-    CurrentError = 0;
-    return aErrorList.empty() ? NULL : aErrorList[ CurrentError ];
-}
-
-BasicError* BasicErrorManager::GetNextError()
-{
-    if (  !aErrorList.empty()
-       && CurrentError < ( aErrorList.size() - 1)
-       )
-    {
-        ++CurrentError;
-        return aErrorList[ CurrentError ];
-    }
-    return NULL;
-}
-
-
 BasicError::BasicError( sal_uIntPtr nId, sal_uInt16 nR, const String& rErrStr ) :
     aErrStr( rErrStr )
 {
@@ -597,12 +533,14 @@ void BasicLibs::Insert( BasicLibInfo* LibInfo )
 
 BasicLibInfo* BasicLibs::Remove( BasicLibInfo* LibInfo )
 {
-    size_t i = GetPos( LibInfo );
-    if ( i < aList.size() )
+    vector< BasicLibInfo* >::iterator it, eit = aList.end();
+    for (it = aList.begin(); it != eit; ++it)
     {
-        vector< BasicLibInfo* >::iterator it = aList.begin();
-        advance( it , i );
-        it = aList.erase( it );
+        if (*it == LibInfo)
+        {
+            aList.erase(it);
+            break;
+        }
     }
     return LibInfo;
 }
@@ -642,18 +580,15 @@ BasicLibInfo* BasicLibInfo::Create( SotStorageStream& rSStream )
         pInfo->bDoLoad = bDoLoad;
 
         // The name of the lib...
-        String aName;
-        rSStream.ReadByteString(aName);
+        String aName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetLibName( aName );
 
         // Absolute path...
-        String aStorageName;
-        rSStream.ReadByteString(aStorageName);
+        String aStorageName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetStorageName( aStorageName );
 
         // Relative path...
-        String aRelStorageName;
-        rSStream.ReadByteString(aRelStorageName);
+        String aRelStorageName = rSStream.ReadUniOrByteString(rSStream.GetStreamCharSet());
         pInfo->SetRelStorageName( aRelStorageName );
 
         if ( nVer >= 2 )
@@ -825,7 +760,7 @@ void BasicManager::SetLibraryContainerInfo( const LibraryContainerInfo& rInfo )
             {
                 Any aLibAny = xScriptCont->getByName( *pScriptLibName );
 
-                if ( pScriptLibName->equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("Standard")) )
+                if ( *pScriptLibName == "Standard" )
                     xScriptCont->loadLibrary( *pScriptLibName );
 
                 BasMgrContainerListenerImpl::insertLibraryImpl
@@ -897,7 +832,7 @@ void BasicManager::ImpMgrNotLoaded( const String& rStorageName )
     // pErrInf is only destroyed if the error os processed by an
     // ErrorHandler
     StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGROPEN, rStorageName, ERRCODE_BUTTON_OK );
-    pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENMGRSTREAM, rStorageName ) );
+    aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_OPENMGRSTREAM, rStorageName));
 
     // Create a stdlib otherwise we crash!
     BasicLibInfo* pStdLibInfo = CreateLibInfo();
@@ -920,7 +855,6 @@ void BasicManager::ImpCreateStdLib( StarBASIC* pParentFromStdLib )
     pStdLib->SetFlag( SBX_DONTSTORE | SBX_EXTSEARCH );
 }
 
-
 void BasicManager::LoadBasicManager( SotStorage& rStorage, const String& rBaseURL, sal_Bool bLoadLibs )
 {
     DBG_CHKTHIS( BasicManager, 0 );
@@ -1036,12 +970,11 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
     if( !ImplLoadBasic( *xManagerStream, pLibs->GetObject(0)->GetLibRef() ) )
     {
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGROPEN, aStorName, ERRCODE_BUTTON_OK );
-        pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENMGRSTREAM, aStorName ) );
+        aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_OPENMGRSTREAM, aStorName));
         // and it proceeds ...
     }
     xManagerStream->Seek( nBasicEndOff+1 ); // +1: 0x00 as separator
-    String aLibs;
-    xManagerStream->ReadByteString(aLibs);
+    String aLibs = xManagerStream->ReadUniOrByteString(xManagerStream->GetStreamCharSet());
     xManagerStream->SetBufferSize( 0 );
     xManagerStream.Clear(); // Close stream
 
@@ -1049,12 +982,12 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
     {
         String aCurStorageName( aStorName );
         INetURLObject aCurStorage( aCurStorageName, INET_PROT_FILE );
-        sal_uInt16 nLibs = aLibs.GetTokenCount( LIB_SEP );
-        for ( sal_uInt16 nLib = 0; nLib < nLibs; nLib++ )
+        sal_Int32 nLibs = comphelper::string::getTokenCount(aLibs, LIB_SEP);
+        for ( sal_Int32 nLib = 0; nLib < nLibs; nLib++ )
         {
-            String aLibInfo( aLibs.GetToken( nLib, LIB_SEP ) );
+            String aLibInfo(comphelper::string::getToken(aLibs, nLib, LIB_SEP));
             // TODO: Remove == 2
-            DBG_ASSERT( ( aLibInfo.GetTokenCount( LIBINFO_SEP ) == 2 ) || ( aLibInfo.GetTokenCount( LIBINFO_SEP ) == 3 ), "Ungueltige Lib-Info!" );
+            DBG_ASSERT( ( comphelper::string::getTokenCount(aLibInfo, LIBINFO_SEP) == 2 ) || ( comphelper::string::getTokenCount(aLibInfo, LIBINFO_SEP) == 3 ), "Ungueltige Lib-Info!" );
             String aLibName( aLibInfo.GetToken( 0, LIBINFO_SEP ) );
             String aLibAbsStorageName( aLibInfo.GetToken( 1, LIBINFO_SEP ) );
             String aLibRelStorageName( aLibInfo.GetToken( 2, LIBINFO_SEP ) );
@@ -1082,7 +1015,7 @@ void BasicManager::LoadOldBasicManager( SotStorage& rStorage )
             else
             {
                 StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD, aStorName, ERRCODE_BUTTON_OK );
-                pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_STORAGENOTFOUND, aStorName ) );
+                aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_STORAGENOTFOUND, aStorName));
             }
         }
     }
@@ -1098,7 +1031,6 @@ BasicManager::~BasicManager()
     // Destroy Basic-Infos...
     // In reverse order
     delete pLibs;
-    delete pErrorMgr;
     delete mpImpl;
 }
 
@@ -1132,7 +1064,6 @@ void BasicManager::Init()
     DBG_CHKTHIS( BasicManager, 0 );
 
     bBasMgrModified = sal_False;
-    pErrorMgr = new BasicErrorManager;
     pLibs = new BasicLibs;
     mpImpl = new BasicManagerImpl();
 }
@@ -1146,7 +1077,7 @@ BasicLibInfo* BasicManager::CreateLibInfo()
     return pInf;
 }
 
-sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurStorage, sal_Bool bInfosOnly ) const
+sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurStorage, sal_Bool bInfosOnly )
 {
     DBG_CHKTHIS( BasicManager, 0 );
 
@@ -1182,7 +1113,7 @@ sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurSt
     if ( !xBasicStorage.Is() || xBasicStorage->GetError() )
     {
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_MGROPEN, xStorage->GetName(), ERRCODE_BUTTON_OK );
-        pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLibInfo->GetLibName() ) );
+        aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLibInfo->GetLibName()));
     }
     else
     {
@@ -1191,7 +1122,7 @@ sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurSt
         if ( !xBasicStream.Is() || xBasicStream->GetError() )
         {
             StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD , pLibInfo->GetLibName(), ERRCODE_BUTTON_OK );
-            pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTREAM, pLibInfo->GetLibName() ) );
+            aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_OPENLIBSTREAM, pLibInfo->GetLibName()));
         }
         else
         {
@@ -1223,7 +1154,7 @@ sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurSt
             if ( !bLoaded )
             {
                 StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD, pLibInfo->GetLibName(), ERRCODE_BUTTON_OK );
-                pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_BASICLOADERROR, pLibInfo->GetLibName() ) );
+                aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_BASICLOADERROR, pLibInfo->GetLibName()));
             }
             else
             {
@@ -1234,8 +1165,8 @@ sal_Bool BasicManager::ImpLoadLibary( BasicLibInfo* pLibInfo, SotStorage* pCurSt
                 *xBasicStream >> nPasswordMarker;
                 if ( ( nPasswordMarker == PASSWORD_MARKER ) && !xBasicStream->IsEof() )
                 {
-                    String aPassword;
-                    xBasicStream->ReadByteString(aPassword);
+                    String aPassword = xBasicStream->ReadUniOrByteString(
+                        xBasicStream->GetStreamCharSet());
                     pLibInfo->SetPassword( aPassword );
                 }
                 xBasicStream->SetCryptMaskKey(rtl::OString());
@@ -1405,7 +1336,7 @@ sal_Bool BasicManager::RemoveLib( sal_uInt16 nLib, sal_Bool bDelBasicFromStorage
     if ( !pLibInfo || !nLib )
     {
         StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_REMOVELIB, String(), ERRCODE_BUTTON_OK );
-        pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_STDLIB, pLibInfo->GetLibName() ) );
+        aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_STDLIB, pLibInfo->GetLibName()));
         return sal_False;
     }
 
@@ -1428,7 +1359,7 @@ sal_Bool BasicManager::RemoveLib( sal_uInt16 nLib, sal_Bool bDelBasicFromStorage
             if ( !xBasicStorage.Is() || xBasicStorage->GetError() )
             {
                 StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_REMOVELIB, String(), ERRCODE_BUTTON_OK );
-                pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLibInfo->GetLibName() ) );
+                aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_OPENLIBSTORAGE, pLibInfo->GetLibName()));
             }
             else if ( xBasicStorage->IsStream( pLibInfo->GetLibName() ) )
             {
@@ -1596,8 +1527,8 @@ sal_Bool BasicManager::LoadLib( sal_uInt16 nLib )
     }
     else
     {
-        StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD, String(), ERRCODE_BUTTON_OK );
-        pErrorMgr->InsertError( BasicError( *pErrInf, BASERR_REASON_LIBNOTFOUND, String::CreateFromInt32(nLib) ) );
+        StringErrorInfo* pErrInf = new StringErrorInfo( ERRCODE_BASMGR_LIBLOAD, rtl::OUString(), ERRCODE_BUTTON_OK );
+        aErrors.push_back(BasicError(*pErrInf, BASERR_REASON_LIBNOTFOUND, rtl::OUString::valueOf(static_cast<sal_Int32>(nLib))));
     }
     return bDone;
 }
@@ -1709,23 +1640,11 @@ sal_Bool BasicManager::IsBasicModified() const
     return sal_False;
 }
 
-sal_Bool BasicManager::HasErrors()
+std::vector<BasicError>& BasicManager::GetErrors()
 {
-    DBG_CHKTHIS( BasicManager, 0 );
-    return pErrorMgr->HasErrors();
+    return aErrors;
 }
 
-BasicError* BasicManager::GetFirstError()
-{
-    DBG_CHKTHIS( BasicManager, 0 );
-    return pErrorMgr->GetFirstError();
-}
-
-BasicError* BasicManager::GetNextError()
-{
-    DBG_CHKTHIS( BasicManager, 0 );
-    return pErrorMgr->GetNextError();
-}
 bool BasicManager::GetGlobalUNOConstant( const sal_Char* _pAsciiName, ::com::sun::star::uno::Any& aOut )
 {
     bool bRes = false;
@@ -1820,12 +1739,11 @@ namespace
         String sModule = sMacro.GetToken( 0, '.', nLast );
         sMacro.Erase( 0, nLast );
 
-        IntlWrapper aIntlWrapper( ::comphelper::getProcessServiceFactory(), Application::GetSettings().GetLocale() );
-        const CollatorWrapper* pCollator = aIntlWrapper.getCollator();
+        utl::TransliterationWrapper& rTransliteration = SbGlobal::GetTransliteration();
         sal_uInt16 nLibCount = i_manager->GetLibCount();
         for ( sal_uInt16 nLib = 0; nLib < nLibCount; ++nLib )
         {
-            if ( COMPARE_EQUAL == pCollator->compareString( i_manager->GetLibName( nLib ), sLibName ) )
+            if ( rTransliteration.isEqual( i_manager->GetLibName( nLib ), sLibName ) )
             {
                 StarBASIC* pLib = i_manager->GetLib( nLib );
                 if( !pLib )
@@ -1840,7 +1758,7 @@ namespace
                     for( sal_uInt16 nMod = 0; nMod < nModCount; ++nMod )
                     {
                         SbModule* pMod = (SbModule*)pLib->GetModules()->Get( nMod );
-                        if ( pMod && COMPARE_EQUAL == pCollator->compareString( pMod->GetName(), sModule ) )
+                        if ( pMod && rTransliteration.isEqual( pMod->GetName(), sModule ) )
                         {
                             SbMethod* pMethod = (SbMethod*)pMod->Find( sMacro, SbxCLASS_METHOD );
                             if( pMethod )
@@ -1894,11 +1812,11 @@ ErrCode BasicManager::ExecuteMacro( String const& i_fullyQualifiedName, String c
 
         sQuotedArgs = '(';
 
-        sal_uInt16 nCount = sArgs.GetTokenCount(',');
-        for ( sal_uInt16 n=0; n<nCount; ++n )
+        sal_Int32 nCount = comphelper::string::getTokenCount(sArgs, ',');
+        for (sal_Int32 n=0; n < nCount; ++n)
         {
             sQuotedArgs += '\"';
-            sQuotedArgs += sArgs.GetToken( n, ',' );
+            sQuotedArgs += comphelper::string::getToken(sArgs, n, ',');
             sQuotedArgs += '\"';
             if ( n<nCount-1 )
                 sQuotedArgs += ',';
@@ -2370,7 +2288,7 @@ Any LibraryContainer_Impl::getByName( const ::rtl::OUString& aName )
     Reference< XNameContainer > xModuleContainer =
         (XNameContainer*)new ModuleContainer_Impl( pLib );
 
-    Reference< XNameContainer > xDialogContainer;
+    Reference< XNameContainer > xDialogContainer =
         (XNameContainer*)new DialogContainer_Impl( pLib );
 
     BasicLibInfo* pLibInfo = mpMgr->FindLibInfo( pLib );
