@@ -241,21 +241,6 @@ typedef std::hash_map< ::rtl::OUString, PCToTextDataMap*, ::rtl::OUStringHash, :
 ModuleTraceMap      GaModuleTraceMap;
 ModuleTraceMap&     rModuleTraceMap = GaModuleTraceMap;
 
-static void lcl_PrepareTraceForModule( SbModule* pModule )
-{
-    String aModuleName = pModule->GetName();
-    ModuleTraceMap::iterator it = rModuleTraceMap.find( aModuleName );
-    if( it != rModuleTraceMap.end() )
-    {
-        PCToTextDataMap* pInnerMap = it->second;
-        delete pInnerMap;
-        rModuleTraceMap.erase( it );
-    }
-
-    String aDisassemblyStr;
-    pModule->Disassemble( aDisassemblyStr );
-}
-
 static FILE* GpGlobalFile = NULL;
 
 static void lcl_lineOut( const char* pStr, const char* pPreStr = NULL, const char* pPostStr = NULL )
@@ -913,8 +898,8 @@ sal_Bool SbModule::Compile()
         return sal_False;
     SbxBase::ResetError();
 
-    SbModule* pOld = pCMOD;
-    pCMOD = this;
+    SbModule* pOld = GetSbData()->pCompMod;
+    GetSbData()->pCompMod = this;
 
     SbiParser* pParser = new SbiParser( (StarBASIC*) GetParent(), this );
     while( pParser->Parse() ) {}
@@ -925,7 +910,7 @@ sal_Bool SbModule::Compile()
     if( pImage )
         pImage->aOUSource = aOUSource;
 
-    pCMOD = pOld;
+    GetSbData()->pCompMod = pOld;
 
     // compiling a module, the module-global
     // variables of all modules become invalid
@@ -944,7 +929,7 @@ sal_Bool SbModule::Compile()
         }
 
         // #i31510 Init other libs only if Basic isn't running
-        if( pINST == NULL )
+        if( GetSbData()->pInst == NULL )
         {
             SbxObject* pParent_ = pBasic->GetParent();
             if( pParent_ )
@@ -957,16 +942,4 @@ sal_Bool SbModule::Compile()
     return bRet;
 }
 
-/**************************************************************************
-*
-*   Syntax-Highlighting
-*
-**************************************************************************/
-
-void StarBASIC::Highlight( const String& rSrc, SbTextPortions& rList )
-{
-    SbiTokenizer aTok( rSrc );
-    aTok.Hilite( rList );
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
