@@ -170,6 +170,31 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::findColumn( const ::rtl::OUString
             break;
     return i;
 }
+
+template < typename T, SQLSMALLINT sqlTypeId > T ODatabaseMetaDataResultSet::getInteger ( sal_Int32 columnIndex )
+{
+    ::cppu::OBroadcastHelper& rBHelper(ODatabaseMetaDataResultSet_BASE::rBHelper);
+    checkDisposed(rBHelper.bDisposed);
+    ::osl::MutexGuard aGuard( m_aMutex );
+
+    columnIndex = mapColumn(columnIndex);
+    T nVal = 0;
+    if(columnIndex <= m_nDriverColumnCount)
+    {
+        getValue<T>(m_pConnection, m_aStatementHandle, columnIndex, sqlTypeId, m_bWasNull, **this, nVal);
+
+        if ( !m_aValueRange.empty() )
+        {
+            ::std::map<sal_Int32, ::connectivity::TInt2IntMap >::iterator aValueRangeIter (m_aValueRange.find(columnIndex));
+            if ( aValueRangeIter != m_aValueRange.end() )
+                return static_cast<T>(aValueRangeIter->second[nVal]);
+        }
+    }
+    else
+        m_bWasNull = sal_True;
+    return nVal;
+}
+
 // -------------------------------------------------------------------------
 Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getBinaryStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
 {
@@ -215,24 +240,7 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::getBoolean( sal_Int32 columnIndex
 
 sal_Int8 SAL_CALL ODatabaseMetaDataResultSet::getByte( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
 {
-
-    checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
-    ::osl::MutexGuard aGuard( m_aMutex );
-
-
-    columnIndex = mapColumn(columnIndex);
-    sal_Int8  nVal = 0;
-    if(columnIndex <= m_nDriverColumnCount)
-    {
-        OTools::getValue(m_pConnection,m_aStatementHandle,columnIndex,SQL_C_TINYINT,m_bWasNull,**this,&nVal,sizeof nVal);
-
-        ::std::map<sal_Int32, ::connectivity::TInt2IntMap >::iterator   aValueRangeIter;
-        if ( !m_aValueRange.empty() && (aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-            return sal_Int8((*aValueRangeIter).second[(sal_Int32)nVal]);
-    }
-    else
-        m_bWasNull = sal_True;
-    return nVal;
+    return getInteger<sal_Int8, SQL_C_STINYINT>( columnIndex );
 }
 // -------------------------------------------------------------------------
 
@@ -322,24 +330,7 @@ float SAL_CALL ODatabaseMetaDataResultSet::getFloat( sal_Int32 columnIndex ) thr
 
 sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getInt( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
 {
-
-    checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
-    ::osl::MutexGuard aGuard( m_aMutex );
-
-
-    columnIndex = mapColumn(columnIndex);
-    sal_Int32 nVal = 0;
-    if(columnIndex <= m_nDriverColumnCount)
-    {
-        OTools::getValue(m_pConnection,m_aStatementHandle,columnIndex,SQL_C_LONG,m_bWasNull,**this,&nVal,sizeof nVal);
-
-        ::std::map<sal_Int32, ::connectivity::TInt2IntMap >::iterator   aValueRangeIter;
-        if ( !m_aValueRange.empty() && (aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-            return (*aValueRangeIter).second[(sal_Int32)nVal];
-    }
-    else
-        m_bWasNull = sal_True;
-    return nVal;
+    return getInteger<sal_Int32, SQL_C_SLONG>( columnIndex );
 }
 // -------------------------------------------------------------------------
 
@@ -349,10 +340,9 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getRow(  ) throw(SQLException, Ru
 }
 // -------------------------------------------------------------------------
 
-sal_Int64 SAL_CALL ODatabaseMetaDataResultSet::getLong( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+sal_Int64 SAL_CALL ODatabaseMetaDataResultSet::getLong( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
 {
-    ::dbtools::throwFunctionNotSupportedException( "XRow::getLong", *this );
-    return 0;
+    return getInteger<sal_Int64, SQL_C_SBIGINT>( columnIndex );
 }
 // -------------------------------------------------------------------------
 
@@ -398,23 +388,7 @@ Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 /*columnIndex*/, c
 
 sal_Int16 SAL_CALL ODatabaseMetaDataResultSet::getShort( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
 {
-
-    checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
-    ::osl::MutexGuard aGuard( m_aMutex );
-
-    columnIndex = mapColumn(columnIndex);
-    sal_Int16 nVal = 0;
-    if(columnIndex <= m_nDriverColumnCount)
-    {
-        OTools::getValue(m_pConnection,m_aStatementHandle,columnIndex,SQL_C_SHORT,m_bWasNull,**this,&nVal,sizeof nVal);
-
-        ::std::map<sal_Int32, ::connectivity::TInt2IntMap >::iterator   aValueRangeIter;
-        if ( !m_aValueRange.empty() && (aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-            return sal_Int16((*aValueRangeIter).second[(sal_Int32)nVal]);
-    }
-    else
-        m_bWasNull = sal_True;
-    return nVal;
+    return getInteger<sal_Int16, SQL_C_SSHORT>( columnIndex );
 }
 // -------------------------------------------------------------------------
 
@@ -892,8 +866,8 @@ void ODatabaseMetaDataResultSet::openTables(const Any& catalog, const ::rtl::OUS
     aPKO = ::rtl::OUStringToOString(schemaPattern,m_nTextEncoding);
     aPKN = ::rtl::OUStringToOString(tableNamePattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr();
 
 
@@ -906,7 +880,7 @@ void ODatabaseMetaDataResultSet::openTables(const Any& catalog, const ::rtl::OUS
         aCOL += ::rtl::OUStringToOString(*pBegin,m_nTextEncoding);
         aCOL += pComma;
     }
-    if ( aCOL.getLength() )
+    if ( !aCOL.isEmpty() )
     {
         aCOL = aCOL.replaceAt(aCOL.getLength()-1,1,pComma);
         pCOL = aCOL.getStr();
@@ -915,7 +889,7 @@ void ODatabaseMetaDataResultSet::openTables(const Any& catalog, const ::rtl::OUS
         pCOL = SQL_ALL_TABLE_TYPES;
 
     SQLRETURN nRetcode = N3SQLTables(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             (SDB_ODBC_CHAR *) pCOL, pCOL ? SQL_NTS : 0);
@@ -996,14 +970,14 @@ void ODatabaseMetaDataResultSet::openColumnPrivileges(  const Any& catalog, cons
     aPKN = ::rtl::OUStringToOString(table,m_nTextEncoding);
     aCOL = ::rtl::OUStringToOString(columnNamePattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr(),
                 *pCOL = aCOL.getStr();
 
 
     SQLRETURN nRetcode = N3SQLColumnPrivileges(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             (SDB_ODBC_CHAR *) pCOL, SQL_NTS);
@@ -1031,14 +1005,14 @@ void ODatabaseMetaDataResultSet::openColumns(   const Any& catalog,
     aPKN = ::rtl::OUStringToOString(tableNamePattern,m_nTextEncoding);
     aCOL = ::rtl::OUStringToOString(columnNamePattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr(),
                 *pCOL = aCOL.getStr();
 
 
     SQLRETURN nRetcode = N3SQLColumns(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             (SDB_ODBC_CHAR *) pCOL, SQL_NTS);
@@ -1100,14 +1074,14 @@ void ODatabaseMetaDataResultSet::openProcedureColumns(  const Any& catalog,
     aPKN = ::rtl::OUStringToOString(procedureNamePattern,m_nTextEncoding);
     aCOL = ::rtl::OUStringToOString(columnNamePattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr(),
                 *pCOL = aCOL.getStr();
 
 
     SQLRETURN nRetcode = N3SQLProcedureColumns(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             (SDB_ODBC_CHAR *) pCOL, SQL_NTS);
@@ -1135,13 +1109,13 @@ void ODatabaseMetaDataResultSet::openProcedures(const Any& catalog, const ::rtl:
     aPKO = ::rtl::OUStringToOString(schemaPattern,m_nTextEncoding);
     aPKN = ::rtl::OUStringToOString(procedureNamePattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr();
 
 
     SQLRETURN nRetcode = N3SQLProcedures(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS);
     OTools::ThrowException(m_pConnection,nRetcode,m_aStatementHandle,SQL_HANDLE_STMT,*this);
@@ -1179,13 +1153,13 @@ void ODatabaseMetaDataResultSet::openSpecialColumns(sal_Bool _bRowVer,const Any&
     aPKO = ::rtl::OUStringToOString(schema,m_nTextEncoding);
     aPKN = ::rtl::OUStringToOString(table,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = aPKN.getStr();
 
 
     SQLRETURN nRetcode = N3SQLSpecialColumns(m_aStatementHandle,_bRowVer ? SQL_ROWVER : SQL_BEST_ROWID,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             (SQLSMALLINT)scope,
@@ -1219,19 +1193,19 @@ void ODatabaseMetaDataResultSet::openForeignKeys( const Any& catalog, const ::rt
     if ( catalog2.hasValue() )
         aFKQ = ::rtl::OUStringToOString(comphelper::getString(catalog2),m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = schema && schema->getLength() ? ::rtl::OUStringToOString(*schema,m_nTextEncoding).getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = schema && !schema->isEmpty() ? ::rtl::OUStringToOString(*schema,m_nTextEncoding).getStr() : NULL,
                 *pPKN = table   ? (aPKN = ::rtl::OUStringToOString(*table,m_nTextEncoding)).getStr(): NULL,
-                *pFKQ = catalog2.hasValue() && aFKQ.getLength() ? aFKQ.getStr() : NULL,
-                *pFKO = schema2 && schema2->getLength() ? (aFKO = ::rtl::OUStringToOString(*schema2,m_nTextEncoding)).getStr() : NULL,
+                *pFKQ = catalog2.hasValue() && !aFKQ.isEmpty() ? aFKQ.getStr() : NULL,
+                *pFKO = schema2 && !schema2->isEmpty() ? (aFKO = ::rtl::OUStringToOString(*schema2,m_nTextEncoding)).getStr() : NULL,
                 *pFKN = table2  ? (aFKN = ::rtl::OUStringToOString(*table2,m_nTextEncoding)).getStr() : NULL;
 
 
     SQLRETURN nRetcode = N3SQLForeignKeys(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKN, pPKN ? SQL_NTS : 0,
-                            (SDB_ODBC_CHAR *) pFKQ, (catalog2.hasValue() && aFKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pFKQ, (catalog2.hasValue() && !aFKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pFKO, pFKO ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pFKN, SQL_NTS
                             );
@@ -1269,13 +1243,13 @@ void ODatabaseMetaDataResultSet::openPrimaryKeys(const Any& catalog, const ::rtl
         aPKQ = ::rtl::OUStringToOString(comphelper::getString(catalog),m_nTextEncoding);
     aPKO = ::rtl::OUStringToOString(schema,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = (aPKN = ::rtl::OUStringToOString(table,m_nTextEncoding)).getStr();
 
 
     SQLRETURN nRetcode = N3SQLPrimaryKeys(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS);
     OTools::ThrowException(m_pConnection,nRetcode,m_aStatementHandle,SQL_HANDLE_STMT,*this);
@@ -1299,13 +1273,13 @@ void ODatabaseMetaDataResultSet::openTablePrivileges(const Any& catalog, const :
         aPKQ = ::rtl::OUStringToOString(comphelper::getString(catalog),m_nTextEncoding);
     aPKO = ::rtl::OUStringToOString(schemaPattern,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = (aPKN = ::rtl::OUStringToOString(tableNamePattern,m_nTextEncoding)).getStr();
 
 
     SQLRETURN nRetcode = N3SQLTablePrivileges(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS);
     OTools::ThrowException(m_pConnection,nRetcode,m_aStatementHandle,SQL_HANDLE_STMT,*this);
@@ -1330,13 +1304,13 @@ void ODatabaseMetaDataResultSet::openIndexInfo( const Any& catalog, const ::rtl:
         aPKQ = ::rtl::OUStringToOString(comphelper::getString(catalog),m_nTextEncoding);
     aPKO = ::rtl::OUStringToOString(schema,m_nTextEncoding);
 
-    const char  *pPKQ = catalog.hasValue() && aPKQ.getLength() ? aPKQ.getStr()  : NULL,
-                *pPKO = pSchemaPat && pSchemaPat->getLength() ? aPKO.getStr() : NULL,
+    const char  *pPKQ = catalog.hasValue() && !aPKQ.isEmpty() ? aPKQ.getStr()  : NULL,
+                *pPKO = pSchemaPat && !pSchemaPat->isEmpty() ? aPKO.getStr() : NULL,
                 *pPKN = (aPKN = ::rtl::OUStringToOString(table,m_nTextEncoding)).getStr();
 
 
     SQLRETURN nRetcode = N3SQLStatistics(m_aStatementHandle,
-                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && aPKQ.getLength()) ? SQL_NTS : 0,
+                            (SDB_ODBC_CHAR *) pPKQ, (catalog.hasValue() && !aPKQ.isEmpty()) ? SQL_NTS : 0,
                             (SDB_ODBC_CHAR *) pPKO, pPKO ? SQL_NTS : 0 ,
                             (SDB_ODBC_CHAR *) pPKN, SQL_NTS,
                             unique ? SQL_INDEX_UNIQUE : SQL_INDEX_ALL,
