@@ -302,7 +302,7 @@ class DisposingForwarder
     Reference< lang::XComponent > m_xTarget;
 
     inline DisposingForwarder( Reference< lang::XComponent > const & xTarget )
-        SAL_THROW( () )
+        SAL_THROW(())
         : m_xTarget( xTarget )
         { OSL_ASSERT( m_xTarget.is() ); }
 public:
@@ -375,7 +375,7 @@ public:
         ContextEntry_Init const * pEntries, sal_Int32 nEntries,
         Reference< XComponentContext > const & xDelegate );
     virtual ~ComponentContext()
-        SAL_THROW( () );
+        SAL_THROW(());
 
     // XComponentContext
     virtual Any SAL_CALL getValueByName( OUString const & rName )
@@ -524,7 +524,7 @@ Any ComponentContext::lookupMap( OUString const & rName )
     SAL_THROW( (RuntimeException) )
 {
 #ifdef CONTEXT_DIAG
-    if (rName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("dump_maps") ))
+    if ( rName == "dump_maps" )
     {
         ::fprintf( stderr, ">>> dumping out ComponentContext %p m_map:\n", this );
         typedef ::std::map< OUString, ContextEntry * > t_sorted; // sorted map
@@ -593,7 +593,7 @@ Any ComponentContext::lookupMap( OUString const & rName )
             {
                 OUString serviceName;
                 if ((usesService >>= serviceName) &&
-                    serviceName.getLength())
+                    !serviceName.isEmpty())
                 {
                     xInstance = args.getLength()
                         ? m_xSMgr->createInstanceWithArgumentsAndContext(
@@ -653,7 +653,7 @@ Any ComponentContext::getValueByName( OUString const & rName )
     throw (RuntimeException)
 {
     // to determine the root context:
-    if (rName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("_root") ))
+    if ( rName == "_root" )
     {
         if (m_xDelegate.is())
             return m_xDelegate->getValueByName( rName );
@@ -676,7 +676,7 @@ Reference< lang::XMultiComponentFactory > ComponentContext::getServiceManager()
 }
 //__________________________________________________________________________________________________
 ComponentContext::~ComponentContext()
-    SAL_THROW( () )
+    SAL_THROW(())
 {
 #ifdef CONTEXT_DIAG
     ::fprintf( stderr, "> destructed context %p\n", this );
@@ -723,15 +723,15 @@ void ComponentContext::disposing()
             pEntry->value >>= xComp;
             if (xComp.is())
             {
-                if (iPos->first.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(TDMGR_SINGLETON) ))
+                if ( iPos->first == TDMGR_SINGLETON )
                 {
                     xTDMgr = xComp;
                 }
-                else if (iPos->first.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(AC_SINGLETON) ))
+                else if ( iPos->first == AC_SINGLETON )
                 {
                     xAC = xComp;
                 }
-                else if (iPos->first.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(AC_POLICY) ))
+                else if ( iPos->first == AC_POLICY )
                 {
                     xPolicy = xComp;
                 }
@@ -770,7 +770,7 @@ ComponentContext::ComponentContext(
     {
         ContextEntry_Init const & rEntry = pEntries[ nPos ];
 
-        if (rEntry.name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM(SMGR_SINGLETON) ))
+        if ( rEntry.name == SMGR_SINGLETON )
         {
             rEntry.value >>= m_xSMgr;
         }
@@ -865,7 +865,7 @@ extern "C" { static void s_createComponentContext_v(va_list * pParam)
 Reference< XComponentContext > SAL_CALL createComponentContext(
     ContextEntry_Init const * pEntries, sal_Int32 nEntries,
     Reference< XComponentContext > const & xDelegate )
-    SAL_THROW( () )
+    SAL_THROW(())
 {
     uno::Environment curr_env(Environment::getCurrent());
     uno::Environment source_env(rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(CPPU_STRINGIFY(CPPU_ENV))));
