@@ -32,7 +32,6 @@
 
 #define _CUI_CHARMAP_CXX_
 #include <tools/shl.hxx>
-#include <tools/debug.hxx>
 #include <vcl/sound.hxx>
 #include <vcl/svapp.hxx>
 #include <svtools/colorcfg.hxx>
@@ -292,7 +291,7 @@ SvxCharMapData::SvxCharMapData( SfxModalDialog* pDialog, sal_Bool bOne_, ResMgr*
         aDeleteBtn.Hide();
     }
 
-    String aDefStr( aFont.GetName() );
+    rtl::OUString aDefStr( aFont.GetName() );
     String aLastName;
     int nCount = mpDialog->GetDevFontCount();
     for ( int i = 0; i < nCount; i++ )
@@ -311,9 +310,10 @@ SvxCharMapData::SvxCharMapData( SfxModalDialog* pDialog, sal_Bool bOne_, ResMgr*
     bool bFound = (aFontLB.GetEntryPos( aDefStr ) == LISTBOX_ENTRY_NOTFOUND );
     if( !bFound )
     {
-        for ( xub_StrLen i = 0; i < aDefStr.GetTokenCount(); ++i )
+        sal_Int32 nIndex = 0;
+        do
         {
-            String aToken = aDefStr.GetToken(i);
+            rtl::OUString aToken = aDefStr.getToken(0, ';', nIndex);
             if ( aFontLB.GetEntryPos( aToken ) != LISTBOX_ENTRY_NOTFOUND )
             {
                 aDefStr = aToken;
@@ -321,6 +321,7 @@ SvxCharMapData::SvxCharMapData( SfxModalDialog* pDialog, sal_Bool bOne_, ResMgr*
                 break;
             }
         }
+        while ( nIndex >= 0 );
     }
 
     if ( bFound )
@@ -370,7 +371,7 @@ void SvxCharMapData::SetCharFont( const Font& rFont )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, OKHdl, OKButton *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, OKHdl)
 {
     String aStr = aShowText.GetText();
 
@@ -387,7 +388,7 @@ IMPL_LINK( SvxCharMapData, OKHdl, OKButton *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, FontSelectHdl, ListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, FontSelectHdl)
 {
     sal_uInt16 nPos = aFontLB.GetSelectEntryPos(),
         nFont = (sal_uInt16)(sal_uLong)aFontLB.GetEntryData( nPos );
@@ -449,7 +450,7 @@ IMPL_LINK( SvxCharMapData, FontSelectHdl, ListBox *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, SubsetSelectHdl, ListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, SubsetSelectHdl)
 {
     sal_uInt16 nPos = aSubsetLB.GetSelectEntryPos();
     const Subset* pSubset = reinterpret_cast<const Subset*> (aSubsetLB.GetEntryData(nPos));
@@ -464,7 +465,7 @@ IMPL_LINK( SvxCharMapData, SubsetSelectHdl, ListBox *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, CharDoubleClickHdl, Control *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, CharDoubleClickHdl)
 {
     mpDialog->EndDialog( sal_True );
     return 0;
@@ -472,7 +473,7 @@ IMPL_LINK( SvxCharMapData, CharDoubleClickHdl, Control *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, CharSelectHdl, Control *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, CharSelectHdl)
 {
     if ( !bOne )
     {
@@ -495,7 +496,7 @@ IMPL_LINK( SvxCharMapData, CharSelectHdl, Control *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, CharHighlightHdl, Control *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, CharHighlightHdl)
 {
     String aText;
     sal_UCS4 cChar = aShowSet.GetSelectCharacter();
@@ -534,7 +535,7 @@ IMPL_LINK( SvxCharMapData, CharHighlightHdl, Control *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, CharPreSelectHdl, Control *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, CharPreSelectHdl)
 {
     // adjust subset selection
     if( pSubsetMap )
@@ -551,31 +552,11 @@ IMPL_LINK( SvxCharMapData, CharPreSelectHdl, Control *, EMPTYARG )
 
 // -----------------------------------------------------------------------
 
-IMPL_LINK( SvxCharMapData, DeleteHdl, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG(SvxCharMapData, DeleteHdl)
 {
     aShowText.SetText( String() );
     aOKBtn.Disable();
     return 0;
 }
 
-IMPL_LINK( SvxCharMapData, AssignHdl, PushButton *, EMPTYARG )
-{
-    SfxAllItemSet aSet( SfxObjectShell::Current()->GetPool() );
-    aSet.Put( SfxStringItem( SID_CHARMAP, String::CreateFromAscii("test") ) );
-    SfxModalDialog* pDlg = new SfxMacroAssignDlg( mpDialog, com::sun::star::uno::Reference < com::sun::star::frame::XFrame >(), aSet );
-    if ( pDlg && pDlg->Execute() == RET_OK )
-    {
-        const SfxItemSet* pOutSet = pDlg->GetOutputItemSet();
-        const SfxPoolItem* pItem;
-        if( SFX_ITEM_SET == pOutSet->GetItemState( SID_CHARMAP, sal_False, &pItem ) )
-        {
-            // show assigned shortcut
-        }
-    }
-
-    delete pDlg;
-
-    return 0;
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
