@@ -119,7 +119,7 @@ ODatabaseImportExport::ODatabaseImportExport(const ::svx::ODataAccessDescriptor&
     osl_incrementInterlockedCount( &m_refCount );
     impl_initFromDescriptor( _aDataDescriptor, false );
 
-    xub_StrLen nCount = rExchange.GetTokenCount(char(11));
+    xub_StrLen nCount = comphelper::string::getTokenCount(rExchange, char(11));
     if( nCount > SBA_FORMAT_SELECTION_COUNT && rExchange.GetToken(4).Len())
     {
         m_pRowMarker = new sal_Int32[nCount-SBA_FORMAT_SELECTION_COUNT];
@@ -283,7 +283,7 @@ void ODatabaseImportExport::initialize()
 
     if ( !m_xConnection.is() )
     {   // we need a connection
-        OSL_ENSURE(m_sDataSourceName.getLength(),"There must be a datsource name!");
+        OSL_ENSURE(!m_sDataSourceName.isEmpty(),"There must be a datsource name!");
         Reference<XNameAccess> xDatabaseContext = Reference< XNameAccess >(m_xFactory->createInstance(SERVICE_SDB_DATABASECONTEXT), UNO_QUERY);
         Reference< XEventListener> xEvt((::cppu::OWeakObject*)this,UNO_QUERY);
 
@@ -348,7 +348,7 @@ void ODatabaseImportExport::initialize()
             throw;
         }
     }
-    if ( !m_aFont.Name.getLength() )
+    if ( m_aFont.Name.isEmpty() )
     {
         Font aApplicationFont = OutputDevice::GetDefaultFont(
             DEFAULTFONT_SANS_UNICODE,
@@ -412,16 +412,15 @@ sal_Bool ORTFImportExport::Write()
         m_xObject->getPropertyValue(PROPERTY_TEXTCOLOR) >>= nColor;
     ::Color aColor(nColor);
 
-    ByteString aFonts(rtl::OUStringToOString(m_aFont.Name, eDestEnc));
-    if(!aFonts.Len())
+    rtl::OString aFonts(rtl::OUStringToOString(m_aFont.Name, eDestEnc));
+    if (aFonts.isEmpty())
     {
         rtl::OUString aName = Application::GetSettings().GetStyleSettings().GetAppFont().GetName();
         aFonts = rtl::OUStringToOString(aName, eDestEnc);
     }
-    ByteString aFontNr;
 
     (*m_pStream)    << "{\\fonttbl";
-    xub_StrLen nTokenCount = aFonts.GetTokenCount();
+    xub_StrLen nTokenCount = comphelper::string::getTokenCount(aFonts, ';');
     for(sal_uInt32 j=0;j<nTokenCount;++j)
     {
         (*m_pStream) << "\\f";
@@ -618,7 +617,7 @@ void ORTFImportExport::appendRow(::rtl::OString* pHorzChar,sal_Int32 _nColumnCou
                 Reference<XPropertySet> xColumn(m_xRowSetColumns->getByIndex(i-1),UNO_QUERY_THROW);
                 dbtools::FormattedColumnValue aFormatedValue(aContext,xRowSet,xColumn);
                 ::rtl::OUString sValue = aFormatedValue.getFormattedValue();
-                if ( sValue.getLength() )
+                if ( !sValue.isEmpty() )
                     RTFOutFuncs::Out_String(*m_pStream,sValue,m_eDestEnc);
             }
             catch (Exception&)
@@ -936,7 +935,7 @@ void OHTMLImportExport::WriteTables()
                         Reference<XPropertySet> xColumn(m_xRowSetColumns->getByIndex(i-1),UNO_QUERY_THROW);
                         dbtools::FormattedColumnValue aFormatedValue(aContext,xRowSet,xColumn);
                         ::rtl::OUString sValue = aFormatedValue.getFormattedValue();
-                        if (sValue.getLength())
+                        if (!sValue.isEmpty())
                         {
                             aValue = sValue;
                         }
