@@ -435,12 +435,12 @@ OleComponent::OleComponent( const uno::Reference< lang::XMultiServiceFactory >&
 , m_bDisposed( sal_False )
 , m_bModified( sal_False )
 , m_pNativeImpl( new OleComponentNative_Impl() )
-, m_xFactory( xFactory )
+, m_pUnoOleObject( pUnoOleObject )
 , m_pOleWrapClientSite( NULL )
 , m_pImplAdviseSink( NULL )
-, m_pUnoOleObject( pUnoOleObject )
 , m_nOLEMiscFlags( 0 )
 , m_nAdvConn( 0 )
+, m_xFactory( xFactory )
 , m_bOleInitialized( sal_False )
 , m_bWorkaroundActive( sal_False )
 {
@@ -471,7 +471,7 @@ OleComponent::~OleComponent()
         m_refCount++;
         try {
             Dispose();
-        } catch( uno::Exception& ) {}
+        } catch( const uno::Exception& ) {}
     }
 
     for ( FormatEtcList::iterator aIter = m_pNativeImpl->m_aFormatsList.begin();
@@ -631,8 +631,8 @@ void OleComponent::RetrieveObjectDataFlavors_Impl()
                 sal_uInt32 nSupportedAspects = 0;
                 do
                 {
-                    HRESULT hr = pFormatEnum->Next( MAX_ENUM_ELE, pElem, &nNum );
-                    if( hr == S_OK || hr == S_FALSE )
+                    HRESULT hr2 = pFormatEnum->Next( MAX_ENUM_ELE, pElem, &nNum );
+                    if( hr2 == S_OK || hr2 == S_FALSE )
                     {
                         for( sal_uInt32 nInd = 0; nInd < FORMATS_NUM; nInd++ )
                             {
@@ -684,21 +684,21 @@ sal_Bool OleComponent::InitializeObject_Impl()
     if ( SUCCEEDED( m_pNativeImpl->m_pObj->QueryInterface( IID_IOleCache, (void**)&pIOleCache ) ) && pIOleCache )
     {
         IEnumSTATDATA* pEnumSD = NULL;
-        HRESULT hr = pIOleCache->EnumCache( &pEnumSD );
+        HRESULT hr2 = pIOleCache->EnumCache( &pEnumSD );
 
-        if ( SUCCEEDED( hr ) && pEnumSD )
+        if ( SUCCEEDED( hr2 ) && pEnumSD )
         {
             pEnumSD->Reset();
             STATDATA aSD;
             DWORD nNum;
             while( SUCCEEDED( pEnumSD->Next( 1, &aSD, &nNum ) ) && nNum == 1 )
-                hr = pIOleCache->Uncache( aSD.dwConnection );
+                hr2 = pIOleCache->Uncache( aSD.dwConnection );
         }
 
         // No IDataObject implementation, caching must be used instead
         DWORD nConn;
         FORMATETC aFormat = { 0, 0, DVASPECT_CONTENT, -1, TYMED_MFPICT };
-        hr = pIOleCache->Cache( &aFormat, ADVFCACHE_ONSAVE, &nConn );
+        hr2 = pIOleCache->Cache( &aFormat, ADVFCACHE_ONSAVE, &nConn );
 
         pIOleCache->Release();
         pIOleCache = NULL;
@@ -1465,7 +1465,7 @@ void SAL_CALL OleComponent::close( sal_Bool bDeliverOwnership )
                 {
                     ( (util::XCloseListener* )pIterator.next() )->queryClosing( aSource, bDeliverOwnership );
                 }
-                catch( uno::RuntimeException& )
+                catch( const uno::RuntimeException& )
                 {
                     pIterator.remove();
                 }
@@ -1483,7 +1483,7 @@ void SAL_CALL OleComponent::close( sal_Bool bDeliverOwnership )
                 {
                     ( (util::XCloseListener* )pCloseIterator.next() )->notifyClosing( aSource );
                 }
-                catch( uno::RuntimeException& )
+                catch( const uno::RuntimeException& )
                 {
                     pCloseIterator.remove();
                 }
@@ -1591,7 +1591,7 @@ uno::Any SAL_CALL OleComponent::getTransferData( const datatransfer::DataFlavor&
     // TODO: Investigate if there is already the format name
     //       and whether this format is really required
     else if ( aFlavor.DataType == getCppuType( ( const uno::Reference< io::XInputStream >* ) 0 )
-            && aFlavor.MimeType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "application/x-openoffice-contentstream" ) ) )
+            && aFlavor.MimeType == "application/x-openoffice-contentstream" )
     {
         // allow to retrieve stream-representation of the object persistence
         bSupportedFlavor = sal_True;
@@ -1672,7 +1672,7 @@ void SAL_CALL OleComponent::dispose() throw (::com::sun::star::uno::RuntimeExcep
     {
         close( sal_True );
     }
-    catch ( uno::Exception& )
+    catch ( const uno::Exception& )
     {
     }
 }
@@ -1729,7 +1729,7 @@ sal_Int64 SAL_CALL OleComponent::getSomething( const ::com::sun::star::uno::Sequ
                 return (sal_Int64) (IUnknown*) m_pNativeImpl->m_pObj;
         }
     }
-    catch ( uno::Exception& )
+    catch ( const uno::Exception& )
     {
     }
 
@@ -1760,7 +1760,7 @@ void SAL_CALL OleComponent::setModified( sal_Bool bModified )
                     lang::EventObject aEvent( (util::XModifiable*) this );
                     ((util::XModifyListener*)pIterator.next())->modified( aEvent );
                 }
-                catch( uno::RuntimeException& )
+                catch( const uno::RuntimeException& )
                 {
                     pIterator.remove();
                 }
