@@ -27,13 +27,11 @@
  ************************************************************************/
 
 #include <comphelper/processfactory.hxx>
-#include <tools/urlobj.hxx>
 #include <com/sun/star/frame/XDispatch.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <datman.hxx>
-#include <tools/debug.hxx>
 #include <svx/svxids.hrc>
 #include <svtools/miscopt.hxx>
 #include <svtools/imgdef.hxx>
@@ -283,7 +281,7 @@ void BibToolBar::InitListener()
 
             util::URL aURL;
             aURL.Complete = GetItemCommand(nId);
-            if(!aURL.Complete.getLength())
+            if(aURL.Complete.isEmpty())
                 continue;
 
             xTrans->parseStrict( aURL );
@@ -345,7 +343,7 @@ void BibToolBar::SendDispatch(sal_uInt16 nId, const Sequence< PropertyValue >& r
 
     uno::Reference< frame::XDispatchProvider >  xDSP( xController, UNO_QUERY );
 
-    if( xDSP.is() && aCommand.getLength())
+    if( xDSP.is() && !aCommand.isEmpty())
     {
         uno::Reference< lang::XMultiServiceFactory >  xMgr = comphelper::getProcessServiceFactory();
 
@@ -382,7 +380,7 @@ void BibToolBar::Click()
         if(pDatMan)
         {
             OUString sNew = pDatMan->CreateDBChangeDialog(GetParent());
-            if(sNew.getLength())
+            if(!sNew.isEmpty())
                 pDatMan->setActiveDataSource(sNew);
         }
         CheckItem( nId, sal_False );
