@@ -51,17 +51,6 @@ namespace filter{
 
 namespace css = ::com::sun::star;
 
-//_______________________________________________
-// definitions
-
-// Use this switch to change the behaviour of preselection DocumentService ... (see using for further informations)
-#define IGNORE_NON_URLMATCHING_TYPES_FOR_PRESELECTION_DOCUMENTSERVICE
-
-// enable/disable special handling for CSV/TXT problem
-#define WORKAROUND_CSV_TXT_BUG_i60158
-
-
-
 TypeDetection::TypeDetection(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
 {
     BaseContainer::init(xSMGR                                         ,
@@ -117,7 +106,139 @@ TypeDetection::~TypeDetection()
     // <- SAFE
 }
 
+namespace {
 
+/**
+ * Rank format types in order of complexity.  More complex formats are
+ * ranked higher so that they get tested sooner over simpler formats.
+ *
+ * Guidelines to determine how complex a format is (subject to change):
+ *
+ * 1) compressed text (XML, HTML, etc)
+ * 2) binary
+ * 3) non-compressed text
+ *   3.1) structured text
+ *     3.1.1) dialect of a structured text (e.g. docbook XML)
+ *     3.1.2) generic structured text (e.g. generic XML)
+ *   3.2) non-structured text
+ *
+ * In each category, rank them from strictly-structured to
+ * loosely-structured.
+ */
+int getFlatTypeRank(const rtl::OUString& rType)
+{
+    // List formats from more complex to less complex.
+    // TODO: Add more.
+    static const char* ranks[] = {
+        // Compressed XML
+        "writer8_template",
+        "writer8",
+        "calc8_template",
+        "calc8",
+        "writer_OOXML_Text_Template",
+        "writer_OOXML",
+        "writer_MS_Word_2007_Template",
+        "writer_MS_Word_2007",
+        "Office Open XML Spreadsheet Template",
+        "Office Open XML Spreadsheet",
+        "MS Excel 2007 XML Template",
+        "MS Excel 2007 XML",
+
+        // Compressed text
+        "pdf_Portable_Document_Format",
+
+        // Binary
+        "writer_T602_Document",
+        "writer_WordPerfect_Document",
+        "writer_MS_Works_Document",
+        "writer_MS_Word_97_Vorlage",
+        "writer_MS_Word_97",
+        "writer_MS_Word_95_Vorlage",
+        "writer_MS_Word_95",
+        "writer_MS_WinWord_60",
+        "writer_MS_WinWord_5",
+        "MS Excel 2007 Binary",
+        "calc_MS_Excel_97_VorlageTemplate",
+        "calc_MS_Excel_97",
+        "calc_MS_Excel_95_VorlageTemplate",
+        "calc_MS_Excel_95",
+        "calc_MS_Excel_5095_VorlageTemplate",
+        "calc_MS_Excel_5095",
+        "calc_MS_Excel_40_VorlageTemplate",
+        "calc_MS_Excel_40",
+        "calc_Pocket_Excel_File",
+        "calc_Lotus",
+        "calc_QPro",
+        "calc_SYLK",
+        "calc_DIF",
+        "calc_dBase",
+
+
+        // Non-compressed XML
+        "writer_ODT_FlatXML",
+        "calc_ODS_FlatXML",
+        "calc_MS_Excel_2003_XML",
+        "writer_MS_Word_2003_XML",
+        "writer_DocBook_File",
+        "XHTML_File",
+
+        // Non-compressed text
+        "writer_Rich_Text_Format",
+        "generic_HTML",
+        "generic_Text"
+    };
+
+    size_t n = SAL_N_ELEMENTS(ranks);
+
+    for (size_t i = 0; i < n; ++i)
+    {
+        if (rType.equalsAscii(ranks[i]))
+            return n - i - 1;
+    }
+
+    // Not ranked.  Treat them equally.  Unranked formats have higher priority
+    // than the ranked internal ones since they may be defined externally.
+    return n;
+}
+
+/**
+ * Types with matching pattern first, then extension, then custom ranks by
+ * types, then types that are supported by the document service come next.
+ * Lastly, sort them alphabetically.
+ */
+struct SortByPriority : public std::binary_function<FlatDetectionInfo, FlatDetectionInfo, bool>
+{
+    bool operator() (const FlatDetectionInfo& r1, const FlatDetectionInfo& r2) const
+    {
+        if (r1.bMatchByPattern != r2.bMatchByPattern)
+            return r1.bMatchByPattern;
+
+        if (r1.bMatchByExtension != r2.bMatchByExtension)
+            return r1.bMatchByExtension;
+
+        int rank1 = getFlatTypeRank(r1.sType);
+        int rank2 = getFlatTypeRank(r2.sType);
+
+        if (rank1 != rank2)
+            return rank1 > rank2;
+
+        if (r1.bPreselectedByDocumentService != r2.bPreselectedByDocumentService)
+            return r1.bPreselectedByDocumentService;
+
+        // All things being equal, sort them alphabetically.
+        return r1.sType > r2.sType;
+    }
+};
+
+struct EqualByName : public std::binary_function<FlatDetectionInfo, FlatDetectionInfo, bool>
+{
+    bool operator() (const FlatDetectionInfo& r1, const FlatDetectionInfo& r2) const
+    {
+        return r1.sType == r2.sType;
+    }
+};
+
+}
 
 ::rtl::OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::beans::PropertyValue >& lDescriptor,
                                                               sal_Bool                                         bAllowDeep )
@@ -143,9 +264,18 @@ TypeDetection::~TypeDetection()
     css::uno::Reference< css::util::XURLTransformer > xParser(m_xSMGR->createInstance(SERVICE_URLTRANSFORMER), css::uno::UNO_QUERY);
     xParser->parseStrict(aURL);
 
-    //*******************************************
-    // preselected filter, type or document service?
-    // use it as first "flat" detected type later!
+    rtl::OUString aSelectedFilter = stlDescriptor.getUnpackedValueOrDefault(
+        comphelper::MediaDescriptor::PROP_FILTERNAME(), rtl::OUString());
+    if (!aSelectedFilter.isEmpty())
+    {
+        // Caller specified the filter type.  Honor it.  Just get the default
+        // type for that filter, and bail out.
+        if (impl_validateAndSetFilterOnDescriptor(stlDescriptor, aSelectedFilter))
+            return stlDescriptor[comphelper::MediaDescriptor::PROP_TYPENAME()].get<rtl::OUString>();
+    }
+
+    // preselected type or document service? use it as first "flat" detected
+    // type later!
     FlatDetection lFlatTypes;
     impl_getPreselection(aURL, stlDescriptor, lFlatTypes);
 
@@ -157,6 +287,10 @@ TypeDetection::~TypeDetection()
     aLock.clear();
     // <- SAFE ----------------------------------
 
+    // Properly prioritize all candidate types.
+    lFlatTypes.sort(SortByPriority());
+    lFlatTypes.unique(EqualByName());
+
     ::rtl::OUString sType      ;
     ::rtl::OUString sLastChance;
 
@@ -180,7 +314,7 @@ TypeDetection::~TypeDetection()
         // the might needed input stream, start detection
         // which uses all registered deep detection services.
         if (
-            (!sType.getLength()) &&
+            (sType.isEmpty()) &&
             (bAllowDeep        )
            )
         {
@@ -192,13 +326,13 @@ TypeDetection::~TypeDetection()
         // pure deep detection failed
         // => ask might existing InteractionHandler
         // means: ask user for it's decision
-        if (!sType.getLength())
+        if (sType.isEmpty())
             sType = impl_askUserForTypeAndFilterIfAllowed(stlDescriptor);
 
         //*******************************************
         // no real detected type - but a might valid one.
         // update descriptor and set last chance for return.
-        if (!sType.getLength() && sLastChance.getLength())
+        if (sType.isEmpty() && !sLastChance.isEmpty())
         {
             OSL_FAIL("set first flat detected type without a registered deep detection service as \"last chance\" ... nevertheless some other deep detections said \"NO\". I TRY IT!");
             sType = sLastChance;
@@ -229,7 +363,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
     ::rtl::OUString sFilter = rDescriptor.getUnpackedValueOrDefault(
                                 ::comphelper::MediaDescriptor::PROP_FILTERNAME(),
                                 ::rtl::OUString());
-    if (sFilter.getLength())
+    if (!sFilter.isEmpty())
         return;
 
     // b)
@@ -238,39 +372,12 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
     ::rtl::OUString sDocumentService = rDescriptor.getUnpackedValueOrDefault(
                                             ::comphelper::MediaDescriptor::PROP_DOCUMENTSERVICE(),
                                             ::rtl::OUString());
-    if (sDocumentService.getLength())
+    if (!sDocumentService.isEmpty())
     {
         try
         {
             ::rtl::OUString sRealType = sType;
 
-            #ifdef WORKAROUND_CSV_TXT_BUG_i60158
-            // Workaround for #i60158#
-            // We do not have right filter for Text_Ascii in calc nor a suitable filter for CSV in writer.
-            // So we must overrule our detection and make the right things. Normaly we should have
-            // one type TextAscii and two filters registered for these one type.
-            // But then we loose automatic opening of CSV files in calc instead of opening these files
-            // inside writer.
-            if (
-                (sDocumentService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.sheet.SpreadsheetDocument"))) &&
-                (
-                    (sRealType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("writer_Text"))) ||
-                    (sRealType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("writer_Text_encoded")))
-                )
-               )
-            {
-                sRealType = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "calc_Text_txt_csv_StarCalc" ));
-            }
-            else
-            if (
-                (sDocumentService.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.TextDocument"))) &&
-                (sRealType.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("calc_Text_txt_csv_StarCalc")))
-               )
-            {
-                sRealType = ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "writer_Text" ));
-            }
-            #endif // WORKAROUND_CSV_TXT_BUG_i60158
-
             // SAFE ->
             ::osl::ResettableMutexGuard aLock(m_aLock);
 
@@ -308,7 +415,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
                 // <- SAFE
             }
 
-            if (sFilter.getLength() > 0)
+            if (!sFilter.isEmpty())
             {
                 rDescriptor[::comphelper::MediaDescriptor::PROP_TYPENAME()  ] <<= sRealType;
                 rDescriptor[::comphelper::MediaDescriptor::PROP_FILTERNAME()] <<= sFilter;
@@ -394,7 +501,7 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(::comphelper::MediaDescrip
             sFilter = ::rtl::OUString();
         }
 
-        if (sFilter.getLength())
+        if (!sFilter.isEmpty())
         {
             rDescriptor[::comphelper::MediaDescriptor::PROP_TYPENAME()  ] <<= sType  ;
             rDescriptor[::comphelper::MediaDescriptor::PROP_FILTERNAME()] <<= sFilter;
@@ -454,7 +561,7 @@ sal_Bool TypeDetection::impl_getPreselectionForType(const ::rtl::OUString& sPreS
     {
         // We cant check a preselected type for a given stream!
         // So we must believe, that it can work ...
-        if (aParsedURL.Complete.equalsAsciiL("private:stream", 14))
+        if ( aParsedURL.Complete == "private:stream" )
             bBreakDetection = sal_True;
     }
 
@@ -505,13 +612,12 @@ sal_Bool TypeDetection::impl_getPreselectionForType(const ::rtl::OUString& sPreS
     }
 
     // if its a valid type - set it on all return values!
-    if (sType.getLength())
+    if (!sType.isEmpty())
     {
         FlatDetectionInfo aInfo;
         aInfo.sType              = sType;
         aInfo.bMatchByExtension  = bMatchByExtension;
         aInfo.bMatchByPattern    = bMatchByPattern;
-        aInfo.bPreselectedAsType = sal_True;
 
         if (bPreferredPreselection)
             rFlatTypes.push_front(aInfo);
@@ -567,18 +673,7 @@ sal_Bool TypeDetection::impl_getPreselectionForFilter(const ::rtl::OUString& sPr
             sFilter = ::rtl::OUString();
     }
 
-    // We have to mark all retrieved preselection items as "preselected by filter"!
-    FlatDetection::iterator pIt;
-    for (  pIt  = rFlatTypes.begin();
-           pIt != rFlatTypes.end()  ;
-         ++pIt                      )
-    {
-        FlatDetectionInfo& rInfo = *pIt;
-        rInfo.bPreselectedAsType   = sal_False;
-        rInfo.bPreselectedByFilter = sal_True;
-    }
-
-    if (sFilter.getLength())
+    if (!sFilter.isEmpty())
         return sal_True;
     else
         return sal_False;
@@ -636,24 +731,6 @@ sal_Bool TypeDetection::impl_getPreselectionForDocumentService(const ::rtl::OUSt
          ++pIt                          )
     {
         FlatDetectionInfo& rInfo = *pIt;
-
-        /*
-            #i60158#
-            Preselection by DocumentService ...
-            How many filters (and corresponding types) must be checked ?
-            All or only the list of filters/types, which match to the given URL too ?
-            There is no final decision about this currently. So we make it "configurable" .-)
-        */
-        #ifdef IGNORE_NON_URLMATCHING_TYPES_FOR_PRESELECTION_DOCUMENTSERVICE
-        if (
-            (!rInfo.bMatchByExtension) &&
-            (!rInfo.bMatchByPattern  )
-           )
-           continue;
-        #endif
-
-        rInfo.bPreselectedAsType            = sal_False;
-        rInfo.bPreselectedByFilter          = sal_False;
         rInfo.bPreselectedByDocumentService = sal_True ;
         rFlatTypes.push_back(rInfo);
     }
@@ -687,15 +764,11 @@ void TypeDetection::impl_getPreselection(const css::util::URL&                aP
     */
 
     ::rtl::OUString sSelectedType = rDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_TYPENAME(), ::rtl::OUString());
-    if (sSelectedType.getLength())
+    if (!sSelectedType.isEmpty())
         impl_getPreselectionForType(sSelectedType, aParsedURL, rFlatTypes);
 
-    ::rtl::OUString sSelectedFilter = rDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_FILTERNAME(), ::rtl::OUString());
-    if (sSelectedFilter.getLength())
-        impl_getPreselectionForFilter(sSelectedFilter, aParsedURL, rFlatTypes);
-
     ::rtl::OUString sSelectedDoc = rDescriptor.getUnpackedValueOrDefault(::comphelper::MediaDescriptor::PROP_DOCUMENTSERVICE(), ::rtl::OUString());
-    if (sSelectedDoc.getLength())
+    if (!sSelectedDoc.isEmpty())
         impl_getPreselectionForDocumentService(sSelectedDoc, aParsedURL, rFlatTypes);
 }
 
@@ -757,28 +830,13 @@ void TypeDetection::impl_getPreselection(const css::util::URL&                aP
             aType[PROPNAME_DETECTSERVICE] >>= sDetectService;
 
             // c)
-            if (!sDetectService.getLength())
+            if (sDetectService.isEmpty())
             {
-                // accept or not accept flat types without deep detection: that's the question :-)
-                // May be there exists some states, where we have to use our LastChance feature instead
-                // of using the flat type directly.
-                // Here the list of task ID's, which wasrelated to these lines of code:
-                // #i47159#, #i43404#, #i46494#
-
-                // a flat detected type without the chance for a deep detection ... but preselected by the user
-                // explicitly (means preselected as type or filter ... not as documentservice!)
-                // should be accepted. So the user can overrule our detection.
-                if (
-                    (aFlatTypeInfo.bPreselectedAsType  ) ||
-                    (aFlatTypeInfo.bPreselectedByFilter)
-                   )
-                    return sFlatType;
-
                 // flat detected types without any registered deep detection service and not
                 // preselected by the user can be used as LAST CHANCE in case no other type could
                 // be detected. Of course only the first type without deep detector can be used.
                 // Further ones has to be ignored.
-                if (rLastChance.getLength() < 1)
+                if (rLastChance.isEmpty())
                     rLastChance = sFlatType;
 
                 continue;
@@ -791,7 +849,7 @@ void TypeDetection::impl_getPreselection(const css::util::URL&                aP
             ::rtl::OUString sDeepType = impl_askDetectService(sDetectService, rDescriptor);
 
             // d)
-            if (sDeepType.getLength())
+            if (!sDeepType.isEmpty())
                 return sDeepType;
         }
         catch(const css::container::NoSuchElementException&)
@@ -813,9 +871,9 @@ namespace
     {
         if (rA == rB)
             return false;
-        if (rA.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.FormatDetector")))
+        if ( rA == "com.sun.star.text.FormatDetector" )
             return false;
-        if (rB.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("com.sun.star.text.FormatDetector")))
+        if ( rB == "com.sun.star.text.FormatDetector" )
             return true;
         return rA < rB;
     }
@@ -843,7 +901,7 @@ namespace
     {
         const ::rtl::OUString& sDetectService = *pIt;
               ::rtl::OUString  sDeepType      = impl_askDetectService(sDetectService, rDescriptor);
-        if (sDeepType.getLength())
+        if (!sDeepType.isEmpty())
             return sDeepType;
         lInsideUsedDetectors.push_back(sDetectService);
     }
@@ -863,7 +921,7 @@ namespace
     ::rtl::OUString sPreselDocumentService = rDescriptor.getUnpackedValueOrDefault(
                                                 ::comphelper::MediaDescriptor::PROP_DOCUMENTSERVICE(),
                                                 ::rtl::OUString());
-    if (sPreselDocumentService.getLength())
+    if (!sPreselDocumentService.isEmpty())
     {
         for (  pIt  = lDetectors.begin();
                pIt != lDetectors.end()  ;
@@ -921,7 +979,7 @@ namespace
             if (bMatchDetectorToDocumentService)
             {
                 ::rtl::OUString sDeepType = impl_askDetectService(sDetectService, rDescriptor);
-                if (sDeepType.getLength())
+                if (!sDeepType.isEmpty())
                     return sDeepType;
                 lInsideUsedDetectors.push_back(sDetectService);
             }
@@ -942,15 +1000,13 @@ namespace
             continue;
 
         ::rtl::OUString sDeepType = impl_askDetectService(sDetectService, rDescriptor);
-        if (sDeepType.getLength())
+        if (!sDeepType.isEmpty())
             return sDeepType;
     }
 
     return ::rtl::OUString();
 }
 
-
-
 void TypeDetection::impl_seekStreamToZero(comphelper::MediaDescriptor& rDescriptor)
 {
     // try to seek to 0 ...
@@ -965,15 +1021,16 @@ void TypeDetection::impl_seekStreamToZero(comphelper::MediaDescriptor& rDescript
         {
             xSeek->seek(0);
         }
-        catch(const css::uno::RuntimeException& exRun)
-            { throw exRun; }
+        catch(const css::uno::RuntimeException&)
+        {
+            throw;
+        }
         catch(const css::uno::Exception&)
-            {}
+        {
+        }
     }
 }
 
-
-
 ::rtl::OUString TypeDetection::impl_askDetectService(const ::rtl::OUString&               sDetectService,
                                                            ::comphelper::MediaDescriptor& rDescriptor   )
 {
@@ -1090,9 +1147,9 @@ void TypeDetection::impl_seekStreamToZero(comphelper::MediaDescriptor& rDescript
     // and not for "missing files". Especialy if detection is done by a stream only
     // we cant check if the stream points to an "existing content"!
     if (
-        (!sURL.getLength()                                     ) || // "non existing file" ?
+        (sURL.isEmpty()                                     ) || // "non existing file" ?
         (!xStream.is()                                         ) || // non existing file !
-        (sURL.equalsIgnoreAsciiCaseAsciiL("private:stream", 14))    // not a good idea .-)
+        (sURL.equalsIgnoreAsciiCaseAsciiL(RTL_CONSTASCII_STRINGPARAM("private:stream")))    // not a good idea .-)
        )
         return ::rtl::OUString();
 
@@ -1134,7 +1191,7 @@ void TypeDetection::impl_openStream(::comphelper::MediaDescriptor& rDescriptor)
     sal_Bool bSuccess = sal_False;
     ::rtl::OUString sURL = rDescriptor.getUnpackedValueOrDefault( ::comphelper::MediaDescriptor::PROP_URL(), ::rtl::OUString() );
     sal_Bool bRequestedReadOnly = rDescriptor.getUnpackedValueOrDefault( ::comphelper::MediaDescriptor::PROP_READONLY(), sal_False );
-    if ( sURL.getLength() && ::utl::LocalFileHelper::IsLocalFile( INetURLObject( sURL ).GetMainURL( INetURLObject::NO_DECODE ) ) )
+    if ( !sURL.isEmpty() && ::utl::LocalFileHelper::IsLocalFile( INetURLObject( sURL ).GetMainURL( INetURLObject::NO_DECODE ) ) )
     {
         // OOo uses own file locking mechanics in case of local file
         bSuccess = rDescriptor.addInputStreamOwnLock();
