@@ -471,7 +471,7 @@ OUString FlashExportFilter_getImplementationName ()
 sal_Bool SAL_CALL FlashExportFilter_supportsService( const OUString& ServiceName )
     throw (RuntimeException)
 {
-    return ServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( SERVICE_NAME ) );
+    return ServiceName == SERVICE_NAME;
 }
 
 // -----------------------------------------------------------------------------
