@@ -236,7 +236,7 @@ void OComboBoxModel::setFastPropertyValue_NoBroadcast(sal_Int32 _nHandle, const
             DBG_ASSERT(_rValue.getValueType().getTypeClass() == TypeClass_STRING,
                 "OComboBoxModel::setFastPropertyValue_NoBroadcast : invalid type !" );
             _rValue >>= m_aListSource;
-            // die ListSource hat sich geaendert -> neu laden
+            // The ListSource has changed -> reload
             if (ListSourceType_VALUELIST != m_eListSourceType)
             {
                 if ( m_xCursor.is() && !hasField() && !hasExternalListSource() )
@@ -411,14 +411,13 @@ void SAL_CALL OComboBoxModel::read(const Reference<stario::XObjectInputStream>&
         return;
     }
 
-    // Maskierung fuer any
+    // Masking for any
     sal_uInt16 nAnyMask;
     _rxInStream >> nAnyMask;
 
     // ListSource
     if (nVersion < 0x0003)
     {
-        ::rtl::OUString sListSource;
         _rxInStream >> m_aListSource;
     }
     else // nVersion == 4
@@ -453,9 +452,9 @@ void SAL_CALL OComboBoxModel::read(const Reference<stario::XObjectInputStream>&
     if (nVersion > 0x0003)  // nVersion == 4
         _rxInStream >> m_aDefaultText;
 
-    // Stringliste muss geleert werden, wenn eine Listenquelle gesetzt ist
-    // dieses kann der Fall sein wenn im alive modus gespeichert wird
-    if  (   m_aListSource.getLength()
+    // StringList must be emptied if a ListSource is set.
+    // This can be the case if we save in alive mode.
+    if  (   !m_aListSource.isEmpty()
         &&  !hasExternalListSource()
         )
     {
@@ -468,8 +467,8 @@ void SAL_CALL OComboBoxModel::read(const Reference<stario::XObjectInputStream>&
     if (nVersion > 0x0005)
         readCommonProperties(_rxInStream);
 
-    // Nach dem Lesen die Defaultwerte anzeigen
-    if ( getControlSource().getLength() )
+    // After reading in, display the default values
+    if ( !getControlSource().isEmpty() )
     {
         // (not if we don't have a control source - the "State" property acts like it is persistent, then
         resetNoBroadcast();
@@ -485,7 +484,7 @@ void OComboBoxModel::loadData( bool _bForce )
     if ( hasExternalListSource() )
         return;
 
-    // Connection holen
+    // Get Connection
     Reference<XRowSet> xForm(m_xCursor, UNO_QUERY);
     if (!xForm.is())
         return;
@@ -500,7 +499,7 @@ void OComboBoxModel::loadData( bool _bForce )
         return;
     }
 
-    if (!m_aListSource.getLength() || m_eListSourceType == ListSourceType_VALUELIST)
+    if (m_aListSource.isEmpty() || m_eListSourceType == ListSourceType_VALUELIST)
         return;
 
     ::utl::SharedUNOComponent< XResultSet > xListCursor;
@@ -548,7 +547,7 @@ void OComboBoxModel::loadData( bool _bForce )
                     }
                 }
 
-                if (!aFieldName.getLength())
+                if (aFieldName.isEmpty())
                     break;
 
                 Reference<XDatabaseMetaData> xMeta = xConnection->getMetaData();
@@ -598,7 +597,7 @@ void OComboBoxModel::loadData( bool _bForce )
             xListCursor.reset( m_aListRowSet.execute() );
         }
     }
-    catch(SQLException& eSQL)
+    catch(const SQLException& eSQL)
     {
         onError(eSQL, FRM_RES_STRING(RID_BASELISTBOX_ERROR_FILLLIST));
         return;
@@ -625,7 +624,7 @@ void OComboBoxModel::loadData( bool _bForce )
             case ListSourceType_TABLE:
             case ListSourceType_QUERY:
             {
-                // die XDatabaseVAriant der ersten Spalte
+                // The XDatabaseVariant of the first column
                 Reference<XColumnsSupplier> xSupplyCols(xListCursor, UNO_QUERY);
                 DBG_ASSERT(xSupplyCols.is(), "OComboBoxModel::loadData : cursor supports the row set service but is no column supplier?!");
                 Reference<XIndexAccess> xColumns;
@@ -642,10 +641,10 @@ void OComboBoxModel::loadData( bool _bForce )
 
                 ::dbtools::FormattedColumnValue aValueFormatter( getContext(), xForm, xDataField );
 
-                // Listen fuellen
+                // Fill Lists
                 sal_Int16 i = 0;
-                // per definitionem the list cursor is positioned _before_ the first row at the moment
-                while (xListCursor->next() && (i++<SHRT_MAX)) // max anzahl eintraege
+                // At the moment by definition the list cursor is positioned _before_ the first row
+                while (xListCursor->next() && (i++<SHRT_MAX)) // Set max. count
                 {
                     aStringList.push_back( aValueFormatter.getFormattedValue() );
                 }
@@ -670,7 +669,7 @@ void OComboBoxModel::loadData( bool _bForce )
                 break;
         }
     }
-    catch(SQLException& eSQL)
+    catch(const SQLException& eSQL)
     {
         onError(eSQL, FRM_RES_STRING(RID_BASELISTBOX_ERROR_FILLLIST));
         return;
@@ -681,13 +680,13 @@ void OComboBoxModel::loadData( bool _bForce )
         return;
     }
 
-        // String-Sequence fuer ListBox erzeugen
+    // Create StringSequence for ListBox
     StringSequence aStringSeq(aStringList.size());
     ::rtl::OUString* pStringAry = aStringSeq.getArray();
     for (sal_Int32 i = 0; i<aStringSeq.getLength(); ++i)
         pStringAry[i] = aStringList[i];
 
-    // String-Sequence an ListBox setzen
+    // Set String-Sequence at ListBox
     setFastPropertyValue( PROPERTY_ID_STRINGITEMLIST, makeAny( aStringSeq ) );
 }
 
@@ -699,8 +698,8 @@ void OComboBoxModel::onConnectedDbColumn( const Reference< XInterface >& _rxForm
         m_pValueFormatter.reset( new ::dbtools::FormattedColumnValue( getContext(), Reference< XRowSet >( _rxForm, UNO_QUERY ), xField ) );
     getPropertyValue( PROPERTY_STRINGITEMLIST ) >>= m_aDesignModeStringItems;
 
-    // Daten nur laden, wenn eine Listenquelle angegeben wurde
-    if ( m_aListSource.getLength() && m_xCursor.is() && !hasExternalListSource() )
+    // Only load data if a ListSource was supplied
+    if ( !m_aListSource.isEmpty() && m_xCursor.is() && !hasExternalListSource() )
         loadData( false );
 }
 
@@ -722,7 +721,7 @@ void SAL_CALL OComboBoxModel::reloaded( const EventObject& aEvent ) throw(Runtim
     OBoundControlModel::reloaded(aEvent);
 
     // reload data if we have a list source
-    if ( m_aListSource.getLength() && m_xCursor.is() && !hasExternalListSource() )
+    if ( !m_aListSource.isEmpty() && m_xCursor.is() && !hasExternalListSource() )
         loadData( false );
 }
 
@@ -745,7 +744,7 @@ sal_Bool OComboBoxModel::commitControlValueToDbColumn( bool _bPostReset )
     if ( bModified )
     {
         if  (   !aNewValue.hasValue()
-            ||  (   !sNewValue.getLength()      // an empty string
+            ||  (   sNewValue.isEmpty()         // an empty string
                 &&  m_bEmptyIsNull              // which should be interpreted as NULL
                 )
             )
@@ -814,7 +813,7 @@ Any OComboBoxModel::translateDbColumnToControlValue()
     if ( m_pValueFormatter.get() )
     {
         ::rtl::OUString sValue( m_pValueFormatter->getFormattedValue() );
-        if  (   !sValue.getLength()
+        if  (   sValue.isEmpty()
             &&  m_pValueFormatter->getColumn().is()
             &&  m_pValueFormatter->getColumn()->wasNull()
             )
