@@ -69,15 +69,7 @@
 #include <rtl/logfile.hxx>
 
 using namespace ::com::sun::star;
-#ifndef css
-#define css ::com::sun::star
-#endif
-#ifndef css_ui
-#define css_ui ::com::sun::star::ui
-#endif
-
-const sal_Int32  HELPID_PREFIX_LENGTH    = 7;
-static const char HELPID_PREFIX[] = "helpid:";
+namespace css = ::com::sun::star;
 
 // Property names of a menu/menu item ItemDescriptor
 static const char ITEM_DESCRIPTOR_COMMANDURL[]  = "CommandURL";
@@ -94,23 +86,23 @@ static sal_uInt16 impl_convertItemStyleToItemBits( sal_Int16 nStyle )
 {
     sal_uInt16 nItemBits( 0 );
 
-    if (( nStyle & css_ui::ItemStyle::ALIGN_RIGHT ) == css_ui::ItemStyle::ALIGN_RIGHT )
+    if (( nStyle & ::com::sun::star::ui::ItemStyle::ALIGN_RIGHT ) == ::com::sun::star::ui::ItemStyle::ALIGN_RIGHT )
         nItemBits |= SIB_RIGHT;
-    else if ( nStyle & css_ui::ItemStyle::ALIGN_LEFT )
+    else if ( nStyle & ::com::sun::star::ui::ItemStyle::ALIGN_LEFT )
         nItemBits |= SIB_LEFT;
     else
         nItemBits |= SIB_CENTER;
 
-    if (( nStyle & css_ui::ItemStyle::DRAW_FLAT ) == css_ui::ItemStyle::DRAW_FLAT )
+    if (( nStyle & ::com::sun::star::ui::ItemStyle::DRAW_FLAT ) == ::com::sun::star::ui::ItemStyle::DRAW_FLAT )
         nItemBits |= SIB_FLAT;
-    else if ( nStyle & css_ui::ItemStyle::DRAW_OUT3D )
+    else if ( nStyle & ::com::sun::star::ui::ItemStyle::DRAW_OUT3D )
         nItemBits |= SIB_OUT;
     else
         nItemBits |= SIB_IN;
 
-    if (( nStyle & css_ui::ItemStyle::AUTO_SIZE ) == css_ui::ItemStyle::AUTO_SIZE )
+    if (( nStyle & ::com::sun::star::ui::ItemStyle::AUTO_SIZE ) == ::com::sun::star::ui::ItemStyle::AUTO_SIZE )
         nItemBits |= SIB_AUTOSIZE;
-    if ( nStyle & css_ui::ItemStyle::OWNER_DRAW )
+    if ( nStyle & ::com::sun::star::ui::ItemStyle::OWNER_DRAW )
         nItemBits |= SIB_USERDRAW;
 
     return nItemBits;
@@ -231,7 +223,7 @@ void SAL_CALL StatusBarManager::dispose() throw( uno::RuntimeException )
                                                             static_cast< ::cppu::OWeakObject *>( this ),
                                                             uno::UNO_QUERY ));
                 }
-                catch ( uno::Exception& )
+                catch ( const uno::Exception& )
                 {
                 }
             }
@@ -310,7 +302,7 @@ void StatusBarManager::UpdateControllers()
                 if ( xUpdatable.is() )
                     xUpdatable->update();
             }
-            catch ( uno::Exception& )
+            catch ( const uno::Exception& )
             {
             }
         }
@@ -336,7 +328,7 @@ void StatusBarManager::RemoveControllers()
             if ( xComponent.is() )
                 xComponent->dispose();
         }
-        catch ( uno::Exception& )
+        catch ( const uno::Exception& )
         {
         }
 
@@ -469,7 +461,6 @@ void StatusBarManager::FillStatusBar( const uno::Reference< container::XIndexAcc
         return;
 
     sal_uInt16         nId( 1 );
-    rtl::OUString  aHelpIdPrefix( RTL_CONSTASCII_USTRINGPARAM( HELPID_PREFIX ));
 
     RemoveControllers();
 
@@ -486,7 +477,7 @@ void StatusBarManager::FillStatusBar( const uno::Reference< container::XIndexAcc
         sal_Int16                               nOffset( 0 );
         sal_Int16                               nStyle( 0 );
         sal_Int16                               nWidth( 0 );
-        sal_uInt16                              nType( css_ui::ItemType::DEFAULT );
+        sal_uInt16                              nType( ::com::sun::star::ui::ItemType::DEFAULT );
 
         try
         {
@@ -494,33 +485,33 @@ void StatusBarManager::FillStatusBar( const uno::Reference< container::XIndexAcc
             {
                 for ( int i = 0; i < aProp.getLength(); i++ )
                 {
-                    if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_COMMANDURL)) )
+                    if ( aProp[i].Name == ITEM_DESCRIPTOR_COMMANDURL )
                     {
                         aProp[i].Value >>= aCommandURL;
                     }
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_HELPURL)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_HELPURL )
                     {
                         aProp[i].Value >>= aHelpURL;
                     }
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_STYLE)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_STYLE )
                     {
                         aProp[i].Value >>= nStyle;
                     }
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_TYPE)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_TYPE )
                     {
                         aProp[i].Value >>= nType;
                     }
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_WIDTH)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_WIDTH )
                     {
                         aProp[i].Value >>= nWidth;
                     }
-                    else if ( aProp[i].Name.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM(ITEM_DESCRIPTOR_OFFSET)) )
+                    else if ( aProp[i].Name == ITEM_DESCRIPTOR_OFFSET )
                     {
                         aProp[i].Value >>= nOffset;
                     }
                 }
 
-                if (( nType == ::com::sun::star::ui::ItemType::DEFAULT ) && ( aCommandURL.getLength() > 0 ))
+                if (( nType == ::com::sun::star::ui::ItemType::DEFAULT ) && !aCommandURL.isEmpty() )
                 {
                     rtl::OUString aString( RetrieveLabelFromCommand( aCommandURL ));
                     sal_uInt16        nItemBits( impl_convertItemStyleToItemBits( nStyle ));
@@ -532,7 +523,7 @@ void StatusBarManager::FillStatusBar( const uno::Reference< container::XIndexAcc
                 }
             }
         }
-        catch ( ::com::sun::star::lang::IndexOutOfBoundsException& )
+        catch ( const ::com::sun::star::lang::IndexOutOfBoundsException& )
         {
             break;
         }
@@ -668,7 +659,7 @@ void StatusBarManager::MouseButtonUp( const MouseEvent& rMEvt )
     MouseButton(rMEvt,&frame::XStatusbarController::mouseButtonUp);
 }
 
-IMPL_LINK( StatusBarManager, Click, StatusBar*, EMPTYARG )
+IMPL_LINK_NOARG(StatusBarManager, Click)
 {
     ResetableGuard aGuard( m_aLock );
 
@@ -687,7 +678,7 @@ IMPL_LINK( StatusBarManager, Click, StatusBar*, EMPTYARG )
     return 1;
 }
 
-IMPL_LINK( StatusBarManager, DoubleClick, StatusBar*, EMPTYARG )
+IMPL_LINK_NOARG(StatusBarManager, DoubleClick)
 {
     ResetableGuard aGuard( m_aLock );
 
