@@ -52,7 +52,6 @@
 //_________________________________________________________________________________________________________________
 #include <rtl/ustrbuf.hxx>
 #include <cppuhelper/weak.hxx>
-#include <tools/urlobj.hxx>
 #include <vcl/svapp.hxx>
 #include <rtl/logfile.hxx>
 
@@ -199,7 +198,7 @@ Sequence< Sequence< PropertyValue > > ConfigurationAccess_FactoryManager::getFac
     while ( pIter != m_aFactoryManagerMap.end() )
     {
         rtl::OUString aFactory = pIter->first;
-        if ( aFactory.getLength() > 0 )
+        if ( !aFactory.isEmpty() )
         {
             sal_Int32                 nToken = 0;
             Sequence< PropertyValue > aSeq( 1 );
@@ -320,7 +319,7 @@ void ConfigurationAccess_FactoryManager::readConfigurationData()
         {
             m_xConfigAccess.set( m_xConfigProvider->createInstanceWithArguments(SERVICENAME_CFGREADACCESS,aArgs ), UNO_QUERY );
         }
-        catch ( WrappedTargetException& )
+        catch ( const WrappedTargetException& )
         {
         }
 
@@ -374,11 +373,11 @@ sal_Bool ConfigurationAccess_FactoryManager::impl_getElementProps( const Any& aE
             xPropertySet->getPropertyValue( m_aPropModule ) >>= rModule;
             xPropertySet->getPropertyValue( m_aPropFactory ) >>= rServiceSpecifier;
         }
-        catch ( com::sun::star::beans::UnknownPropertyException& )
+        catch ( const com::sun::star::beans::UnknownPropertyException& )
         {
             return sal_False;
         }
-        catch ( com::sun::star::lang::WrappedTargetException& )
+        catch ( const com::sun::star::lang::WrappedTargetException& )
         {
             return sal_False;
         }
@@ -461,7 +460,7 @@ throw ( ::com::sun::star::container::NoSuchElementException, ::com::sun::star::l
         if ( xUIElementFactory.is() )
             return xUIElementFactory->createUIElement( ResourceURL, Args );
     }
-    catch ( UnknownModuleException& )
+    catch ( const UnknownModuleException& )
     {
     }
 
@@ -507,7 +506,7 @@ throw ( RuntimeException )
     rtl::OUString aServiceSpecifier = m_pConfigAccess->getFactorySpecifierFromTypeNameModule( aType, aName, aModuleId );
 
     aLock.unlock();
-    if ( aServiceSpecifier.getLength() )
+    if ( !aServiceSpecifier.isEmpty() )
         return Reference< XUIElementFactory >( xSManager->createInstance( aServiceSpecifier ), UNO_QUERY );
     else
         return Reference< XUIElementFactory >();
