@@ -440,7 +440,7 @@ void ODataInputStream::setSuccessor( const Reference < XConnectable > &r ) throw
          if( m_succ.is() ) {
               /// set this instance as the sink !
               m_succ->setPredecessor( Reference< XConnectable > (
-                  SAL_STATIC_CAST( XConnectable * , this ) ) );
+                  (static_cast< XConnectable *  >(this)) ) );
          }
      }
 }
@@ -459,7 +459,7 @@ void ODataInputStream::setPredecessor( const Reference < XConnectable > &r )
         m_pred = r;
         if( m_pred.is() ) {
             m_pred->setSuccessor( Reference< XConnectable > (
-                SAL_STATIC_CAST( XConnectable * , this ) ) );
+                (static_cast< XConnectable *  >(this)) ) );
         }
     }
 }
@@ -500,7 +500,9 @@ Sequence< OUString > ODataInputStream::getSupportedServiceNames(void) throw ()
 *
 ****/
 
-Reference< XInterface > SAL_CALL ODataInputStream_CreateInstance( const Reference < XComponentContext > & ) throw( Exception)
+Reference< XInterface > SAL_CALL ODataInputStream_CreateInstance(
+    SAL_UNUSED_PARAMETER const Reference < XComponentContext > & )
+    throw( Exception)
 {
     ODataInputStream *p = new ODataInputStream;
     return Reference< XInterface > ( (OWeakObject * ) p );
@@ -848,7 +850,7 @@ void ODataOutputStream::setSuccessor( const Reference < XConnectable > &r )
          {
               /// set this instance as the sink !
               m_succ->setPredecessor( Reference < XConnectable > (
-                  SAL_STATIC_CAST( XConnectable * , this  ) ));
+                  (static_cast< XConnectable *  >(this)) ));
          }
      }
 }
@@ -865,7 +867,7 @@ void ODataOutputStream::setPredecessor( const Reference < XConnectable > &r )
         m_pred = r;
         if( m_pred.is() ) {
             m_pred->setSuccessor( Reference< XConnectable > (
-                SAL_STATIC_CAST( XConnectable * , this  ) ));
+                (static_cast< XConnectable *  >(this)) ));
         }
     }
 }
@@ -904,7 +906,9 @@ Sequence< OUString > ODataOutputStream::getSupportedServiceNames(void) throw ()
 
 
 
-Reference< XInterface > SAL_CALL ODataOutputStream_CreateInstance( const Reference < XComponentContext > & ) throw(Exception)
+Reference< XInterface > SAL_CALL ODataOutputStream_CreateInstance(
+    SAL_UNUSED_PARAMETER const Reference < XComponentContext > & )
+    throw(Exception)
 {
     ODataOutputStream *p = new ODataOutputStream;
     Reference< XInterface > xService = *p;
@@ -1093,7 +1097,7 @@ void OObjectOutputStream::writeObject( const Reference< XPersistObject > & xPObj
 
     if( bWriteObj )
         xPObj->write( Reference< XObjectOutputStream > (
-            SAL_STATIC_CAST( XObjectOutputStream * , this ) ) );
+            (static_cast< XObjectOutputStream *  >(this)) ) );
 
     sal_Int32 nObjLen = m_rMarkable->offsetToMark( nObjLenMark ) -4;
     m_rMarkable->jumpToMark( nObjLenMark );
@@ -1186,11 +1190,12 @@ sal_Int32 OObjectOutputStream::offsetToMark(sal_Int32 nMark)
 
 
 
-Reference< XInterface > SAL_CALL OObjectOutputStream_CreateInstance( const Reference < XComponentContext > & )
+Reference< XInterface > SAL_CALL OObjectOutputStream_CreateInstance(
+    SAL_UNUSED_PARAMETER const Reference < XComponentContext > & )
     throw(Exception)
 {
     OObjectOutputStream *p = new OObjectOutputStream;
-    return  Reference< XInterface > ( SAL_STATIC_CAST( OWeakObject * , p ) );
+    return  Reference< XInterface > ( (static_cast< OWeakObject *  >(p)) );
 }
 
 OUString OObjectOutputStream_getImplementationName()
@@ -1361,7 +1366,7 @@ Reference< XPersistObject >  OObjectInputStream::readObject() throw (::com::sun:
     sal_Bool bLoadSuccesfull = sal_True;
     if( nId )
     {
-        if( aName.getLength() )
+        if( !aName.isEmpty() )
         {
             // load the object
             Reference< XInterface > x = m_rSMgr->createInstanceWithContext( aName, m_rCxt );
@@ -1378,7 +1383,7 @@ Reference< XPersistObject >  OObjectInputStream::readObject() throw (::com::sun:
 
                 m_aPersistVector[nId] = xLoadedObj;
                 xLoadedObj->read( Reference< XObjectInputStream >(
-                    SAL_STATIC_CAST( XObjectInputStream *, this ) ) );
+                    (static_cast< XObjectInputStream * >(this)) ) );
             }
             else
             {
@@ -1511,7 +1516,7 @@ Sequence< OUString > OObjectInputStream::getSupportedServiceNames(void) throw ()
 Reference< XInterface > SAL_CALL OObjectInputStream_CreateInstance( const Reference < XComponentContext > & rCtx ) throw(Exception)
 {
     OObjectInputStream *p = new OObjectInputStream( rCtx );
-    return Reference< XInterface> ( SAL_STATIC_CAST( OWeakObject *, p ) );
+    return Reference< XInterface> ( (static_cast< OWeakObject * >(p)) );
 }
 
 OUString OObjectInputStream_getImplementationName()
