@@ -65,7 +65,7 @@
 #include "diagnostics.h"
 
 #ifdef ANDROID
-#include <lo-bootstrap.h>
+#include <osl/detail/android-bootstrap.h>
 #endif
 
 #if defined HAVE_VALGRIND_H
@@ -99,7 +99,7 @@ OString getPluginJarPath(
     OUString sName1(RTL_CONSTASCII_USTRINGPARAM("javaplugin.jar"));
     OUString sName2(RTL_CONSTASCII_USTRINGPARAM("plugin.jar"));
     OUString sPath;
-    if (sVendor.equals(OUString(RTL_CONSTASCII_USTRINGPARAM(SUN_MICRO))))
+    if ( sVendor == SUN_MICRO )
     {
         SunVersion ver142("1.4.2-ea");
         SunVersion ver150("1.5.0-ea");
@@ -116,7 +116,7 @@ OString getPluginJarPath(
             //but this does not harm. 1.5.0-beta < 1.5.0
             sName = sName2;
         }
-        if (sName.getLength())
+        if (!sName.isEmpty())
         {
             sName = sLocation + OUSTR("/lib/") + sName;
             OSL_VERIFY(
@@ -140,7 +140,7 @@ OString getPluginJarPath(
                 sPath = sPath1 + OUString::createFromAscii(sep) + sPath2;
             }
         }
-        OSL_ASSERT(sPath.getLength());
+        OSL_ASSERT(!sPath.isEmpty());
     }
     ret = rtl::OUStringToOString(sPath, osl_getThreadTextEncoding());
 
@@ -167,7 +167,7 @@ JavaInfo* createJavaInfo(const rtl::Reference<VendorBase> & info)
     pInfo->nRequirements = info->needsRestart() ? JFW_REQUIRE_NEEDRESTART : 0;
     rtl::OUStringBuffer buf(1024);
     buf.append(info->getRuntimeLibrary());
-    if (info->getLibraryPaths().getLength() > 0)
+    if (!info->getLibraryPaths().isEmpty())
     {
         buf.appendAscii("\n");
         buf.append(info->getLibraryPaths());
@@ -239,8 +239,8 @@ javaPluginError jfw_plugin_getAllJavaInfos(
     OUString ouMinVer(sMinVersion);
     OUString ouMaxVer(sMaxVersion);
 
-    OSL_ASSERT(ouVendor.getLength() > 0);
-    if (ouVendor.getLength() == 0)
+    OSL_ASSERT(!ouVendor.isEmpty());
+    if (ouVendor.isEmpty())
         return JFW_PLUGIN_E_INVALID_ARG;
 
     JavaInfo** arInfo = NULL;
@@ -258,7 +258,7 @@ javaPluginError jfw_plugin_getAllJavaInfos(
         if (ouVendor.equals(cur->getVendor()) == sal_False)
             continue;
 
-        if (ouMinVer.getLength() > 0)
+        if (!ouMinVer.isEmpty())
         {
             try
             {
@@ -276,7 +276,7 @@ javaPluginError jfw_plugin_getAllJavaInfos(
             }
         }
 
-        if (ouMaxVer.getLength() > 0)
+        if (!ouMaxVer.isEmpty())
         {
             try
             {
@@ -347,7 +347,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     sal_Int32  nLenList,
     JavaInfo ** ppInfo)
 {
-    javaPluginError errcode = JFW_PLUGIN_E_NONE;
+    javaPluginError errorcode = JFW_PLUGIN_E_NONE;
 
     OSL_ASSERT(path);
     OSL_ASSERT(sVendor);
@@ -356,8 +356,8 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     if (!path || !sVendor || !sMinVersion || !sMaxVersion || !ppInfo)
         return JFW_PLUGIN_E_INVALID_ARG;
     OUString ouPath(path);
-    OSL_ASSERT(ouPath.getLength() > 0);
-    if (ouPath.getLength() == 0)
+    OSL_ASSERT(!ouPath.isEmpty());
+    if (ouPath.isEmpty())
         return JFW_PLUGIN_E_INVALID_ARG;
 
     //nLenlist contains the number of element in arExcludeList.
@@ -370,8 +370,8 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     OUString ouMinVer(sMinVersion);
     OUString ouMaxVer(sMaxVersion);
 
-    OSL_ASSERT(ouVendor.getLength() > 0);
-    if (ouVendor.getLength() == 0)
+    OSL_ASSERT(!ouVendor.isEmpty());
+    if (ouVendor.isEmpty())
         return JFW_PLUGIN_E_INVALID_ARG;
 
     rtl::Reference<VendorBase> aVendorInfo = getJREInfoByPath(ouPath);
@@ -382,7 +382,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     if (ouVendor.equals(aVendorInfo->getVendor()) == sal_False)
         return JFW_PLUGIN_E_NO_JRE;
 
-    if (ouMinVer.getLength() > 0)
+    if (!ouMinVer.isEmpty())
     {
         int nRes = 0;
         try
@@ -402,7 +402,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
             return JFW_PLUGIN_E_FAILED_VERSION;
     }
 
-    if (ouMaxVer.getLength() > 0)
+    if (!ouMaxVer.isEmpty())
     {
         int nRes = 0;
         try
@@ -444,7 +444,7 @@ javaPluginError jfw_plugin_getJavaInfoByPath(
     }
     *ppInfo = createJavaInfo(aVendorInfo);
 
-    return errcode;
+    return errorcode;
 }
 
 #if defined(WNT)
@@ -571,9 +571,9 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
     // unless guard is volatile the following warning occurs on gcc:
     // warning: variable 't' might be clobbered by `longjmp' or `vfork'
     volatile osl::MutexGuard guard(PluginMutex::get());
-    // unless errcode is volatile the following warning occurs on gcc:
-    // warning: variable 'errcode' might be clobbered by `longjmp' or `vfork'
-    volatile javaPluginError errcode = JFW_PLUGIN_E_NONE;
+    // unless errorcode is volatile the following warning occurs on gcc:
+    // warning: variable 'errorcode' might be clobbered by `longjmp' or `vfork'
+    volatile javaPluginError errorcode = JFW_PLUGIN_E_NONE;
     if ( pInfo == NULL || ppVm == NULL || ppEnv == NULL)
         return JFW_PLUGIN_E_INVALID_ARG;
     //Check if the Vendor (pInfo->sVendor) is supported by this plugin
@@ -671,7 +671,7 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
         {
             char sep[] =  {SAL_PATHSEPARATOR, 0};
             OString sAddPath = getPluginJarPath(pInfo->sVendor, pInfo->sLocation,pInfo->sVersion);
-            if (sAddPath.getLength())
+            if (!sAddPath.isEmpty())
                 sClassPathOption = sClassPath + rtl::OString(sep) + sAddPath;
             else
                 sClassPathOption = sClassPath;
@@ -687,8 +687,7 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
         }
 #endif
 #if OSL_DEBUG_LEVEL >= 2
-        JFW_TRACE2(OString("VM option: ") + OString(options[n].optionString) +
-                   OString("\n"));
+        JFW_TRACE2("VM option: " << options[n].optionString << "\n");
 #endif
         ++n;
     }
@@ -733,18 +732,17 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
 
     if(err != 0)
     {
-        rtl::OUString message;
         if( err < 0)
         {
             fprintf(stderr,"[Java framework] sunjavaplugin" SAL_DLLEXTENSION
                     "Can not create Java Virtual Machine\n");
-            errcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
+            errorcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
         }
         else if( err > 0)
         {
             fprintf(stderr,"[Java framework] sunjavaplugin" SAL_DLLEXTENSION
                     "Can not create JavaVirtualMachine, abort handler was called.\n");
-            errcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
+            errorcode = JFW_PLUGIN_E_VM_CREATION_FAILED;
         }
     }
     else
@@ -761,7 +759,7 @@ javaPluginError jfw_plugin_startJavaVirtualMachine(
     fprintf(stderr, "lo_get_javavm returns %p", *ppVm);
 #endif
 
-   return errcode;
+   return errorcode;
 }
 
 extern "C"
@@ -772,7 +770,7 @@ javaPluginError jfw_plugin_existJRE(const JavaInfo *pInfo, sal_Bool *exist)
         return JFW_PLUGIN_E_INVALID_ARG;
     ::rtl::OUString sLocation(pInfo->sLocation);
 
-    if (sLocation.getLength() == 0)
+    if (sLocation.isEmpty())
         return JFW_PLUGIN_E_INVALID_ARG;
     ::osl::DirectoryItem item;
     ::osl::File::RC rc_item = ::osl::DirectoryItem::get(sLocation, item);
