@@ -31,13 +31,13 @@
 
 #include "osl/process.h"
 #include "osl/security.hxx"
-#include "osl/thread.hxx"
 #include "osl/file.hxx"
 #include "osl/module.hxx"
 #include "rtl/byteseq.hxx"
 #include "rtl/ustrbuf.hxx"
 #include "rtl/instance.hxx"
-#include <salhelper/linkhelper.hxx>
+#include "salhelper/linkhelper.hxx"
+#include "salhelper/thread.hxx"
 #include "boost/scoped_array.hpp"
 #include "com/sun/star/uno/Sequence.hxx"
 #include <utility>
@@ -294,7 +294,7 @@ FileHandleReader::readLine(rtl::OString * pLine)
     }
 }
 
-class AsynchReader: public Thread
+class AsynchReader: public salhelper::Thread
 {
     size_t  m_nDataSize;
     boost::scoped_array<sal_Char> m_arData;
@@ -303,7 +303,9 @@ class AsynchReader: public Thread
     bool m_bDone;
     FileHandleGuard m_aGuard;
 
-    void SAL_CALL run();
+    virtual ~AsynchReader() {}
+
+    void execute();
 public:
 
     AsynchReader(oslFileHandle & rHandle);
@@ -317,17 +319,17 @@ public:
 };
 
 AsynchReader::AsynchReader(oslFileHandle & rHandle):
-    m_nDataSize(0), m_bError(false), m_bDone(false), m_aGuard(rHandle)
+    Thread("jvmfwkAsyncReader"), m_nDataSize(0), m_bError(false),
+    m_bDone(false), m_aGuard(rHandle)
 {
 }
 
 OString AsynchReader::getData()
 {
-    OSL_ASSERT(isRunning() == sal_False );
     return OString(m_arData.get(), m_nDataSize);
 }
 
-void AsynchReader::run()
+void AsynchReader::execute()
 {
     const sal_uInt64 BUFFER_SIZE = 4096;
     sal_Char aBuffer[BUFFER_SIZE];
@@ -378,7 +380,7 @@ bool getJavaProps(const OUString & exePath,
 {
     bool ret = false;
 
-    OSL_ASSERT( exePath.getLength() > 0);
+    OSL_ASSERT(!exePath.isEmpty());
     OUString usStartDir;
     //We need to set the CLASSPATH in case the office is started from
     //a different directory. The JREProperties.class is expected to reside
@@ -420,7 +422,7 @@ bool getJavaProps(const OUString & exePath,
     oslFileHandle fileErr= 0;
 
     FileHandleReader stdoutReader(fileOut);
-    AsynchReader stderrReader(fileErr);
+    rtl::Reference< AsynchReader > stderrReader(new AsynchReader(fileErr));
 
     JFW_TRACE2(OUSTR("\n[Java framework] Executing: ") + exePath + OUSTR(".\n"));
     oslProcessError procErr =
@@ -450,7 +452,7 @@ bool getJavaProps(const OUString & exePath,
     }
 
     //Start asynchronous reading (different thread) of error stream
-    stderrReader.create();
+    stderrReader->launch();
 
     //Use this thread to read output stream
     FileHandleReader::Result rs = FileHandleReader::RESULT_OK;
@@ -465,7 +467,7 @@ bool getJavaProps(const OUString & exePath,
             continue;
         JFW_TRACE2("[Java framework]:\" " << sLine << " \".\n");
         sLine = sLine.trim();
-        if (sLine.getLength() == 0)
+        if (sLine.isEmpty())
             continue;
         //The JREProperties class writes key value pairs, separated by '='
         sal_Int32 index = sLine.indexOf('=', 0);
@@ -489,9 +491,9 @@ bool getJavaProps(const OUString & exePath,
         ret = true;
 
     //process error stream data
-    stderrReader.join();
+    stderrReader->join();
     JFW_TRACE2("[Java framework]  Java wrote to stderr:\" "
-               << stderrReader.getData().getStr() << " \".\n");
+               << stderrReader->getData().getStr() << " \".\n");
 
     TimeValue waitMax= {5 ,0};
     procErr = osl_joinProcessWithTimeout(javaProcess, &waitMax);
@@ -512,7 +514,7 @@ bool decodeOutput(const rtl::OString& s, rtl::OUString* out)
     do
     {
         OString aToken = s.getToken( 0, ' ', nIndex );
-        if (aToken.getLength())
+        if (!aToken.isEmpty())
         {
             for (sal_Int32 i = 0; i < aToken.getLength(); ++i)
             {
@@ -742,7 +744,7 @@ bool getJREInfoFromBinPath(
                     sHome = OUString(sBinPath.getStr(), index - 1);
                 }
             }
-            if (sHome.getLength() > 0)
+            if (!sHome.isEmpty())
             {
                 ret = getJREInfoByPath(sHome, vecInfos);
                 if (ret)
@@ -870,7 +872,7 @@ rtl::Reference<VendorBase> getJREInfoByPath(
 
     OUString sResolvedDir = resolveDirPath(path);
     // If this path is invalid then there is no chance to find a JRE here
-    if (sResolvedDir.getLength() == 0)
+    if (sResolvedDir.isEmpty())
         return 0;
 
     //check if the directory path is good, that is a JRE was already recognized.
@@ -917,7 +919,7 @@ rtl::Reference<VendorBase> getJREInfoByPath(
 
             sFilePath = resolveFilePath(sFullPath);
 
-            if (sFilePath.getLength() == 0)
+            if (sFilePath.isEmpty())
             {
                 //The file path (to java exe) is not valid
                 cit_path ifull = find(vecBadPaths.begin(), vecBadPaths.end(), sFullPath);
@@ -1010,7 +1012,7 @@ rtl::Reference<VendorBase> getJREInfoByPath(
         }
     }
 
-    if (sVendorName.getLength() > 0)
+    if (!sVendorName.isEmpty())
     {
         //find the creator func for the respective vendor name
         for ( sal_Int32 c = 0;
@@ -1075,7 +1077,7 @@ void createJavaInfoFromPath(vector<rtl::Reference<VendorBase> >& vecInfos)
             OUString usTokenUrl;
             if(File::getFileURLFromSystemPath(usToken, usTokenUrl) == File::E_None)
             {
-                if(usTokenUrl.getLength())
+                if(!usTokenUrl.isEmpty())
                 {
                     OUString usBin;
                     // "."
@@ -1096,7 +1098,7 @@ void createJavaInfoFromPath(vector<rtl::Reference<VendorBase> >& vecInfos)
                     {
                         usBin = usTokenUrl;
                     }
-                    if(usBin.getLength())
+                    if(!usBin.isEmpty())
                     {
                         getJREInfoFromBinPath(usBin, vecInfos);
                     }
@@ -1186,7 +1188,7 @@ void createJavaInfoDirScan(vector<rtl::Reference<VendorBase> >& vecInfos)
             {
                 OUString usDir2(usDir1 + arCollectDirs[j]);
                 // prevent that we scan the whole /usr, /usr/lib, etc directories
-                if (arCollectDirs[j] != OUString())
+                if (!arCollectDirs[j].isEmpty())
                 {
                     //usr/java/xxx
                     //Examin every subdirectory
