@@ -26,12 +26,13 @@
  *
  ************************************************************************/
 
-#include <comphelper/string.hxx>
-#include <stdio.h>
-#include <tools/string.hxx>
-#include <tools/fsys.hxx>
+#include "sal/config.h"
 
-// local includes
+#include <cstring>
+
+#include <stdio.h>
+
+#include "common.hxx"
 #include "export.hxx"
 #include "xrmmerge.hxx"
 #include "tokens.h"
@@ -41,8 +42,8 @@
 
 using namespace std;
 
-extern "C" { int yyerror( char * ); }
-extern "C" { int YYWarning( char * ); }
+void yyerror( const char * );
+void YYWarning( const char * );
 
 // defines to parse command line
 #define STATE_NON       0x0001
@@ -61,15 +62,14 @@ sal_Bool bErrorLog;
 sal_Bool bUTF8;
 sal_Bool bDisplayName;
 sal_Bool bExtensionDescription;
-ByteString sPrj;
-ByteString sPrjRoot;
-ByteString sInputFileName;
-ByteString sActFileName;
-ByteString sOutputFile;
-ByteString sMergeSrc;
-ByteString sLangAttribute;
-ByteString sResourceType;
-String sUsedTempFile;
+rtl::OString sPrj;
+rtl::OString sPrjRoot;
+rtl::OString sInputFileName;
+rtl::OString sActFileName;
+rtl::OString sOutputFile;
+rtl::OString sMergeSrc;
+rtl::OString sLangAttribute;
+rtl::OString sResourceType;
 XRMResParser *pParser = NULL;
 
 extern "C" {
@@ -95,26 +95,26 @@ extern char *GetOutputFile( int argc, char* argv[])
 
     // parse command line
     for( int i = 1; i < argc; i++ ) {
-        if ( ByteString( argv[ i ] ).ToUpperAscii() == "-I" ) {
+        if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-I" ) {
             nState = STATE_INPUT; // next token specifies source file
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-O" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-O" ) {
             nState = STATE_OUTPUT; // next token specifies the dest file
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-P" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-P" ) {
             nState = STATE_PRJ; // next token specifies the cur. project
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-R" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-R" ) {
             nState = STATE_ROOT; // next token specifies path to project root
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-M" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-M" ) {
             nState = STATE_MERGESRC; // next token specifies the merge database
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-E" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-E" ) {
             nState = STATE_ERRORLOG;
             bErrorLog = sal_False;
         }
-        else if ( ByteString( argv[ i ] ).ToUpperAscii() == "-L" ) {
+        else if ( rtl::OString( argv[ i ] ).toAsciiUpperCase() == "-L" ) {
             nState = STATE_LANGUAGES;
         }
         else {
@@ -132,20 +132,20 @@ extern char *GetOutputFile( int argc, char* argv[])
                 }
                 break;
                 case STATE_PRJ: {
-                    sPrj = ByteString( argv[ i ]);
+                    sPrj = rtl::OString( argv[ i ]);
                 }
                 break;
                 case STATE_ROOT: {
-                    sPrjRoot = ByteString( argv[ i ]); // path to project root
+                    sPrjRoot = rtl::OString( argv[ i ]); // path to project root
                 }
                 break;
                 case STATE_MERGESRC: {
-                    sMergeSrc = ByteString( argv[ i ]);
+                    sMergeSrc = rtl::OString( argv[ i ]);
                     bMergeMode = sal_True; // activate merge mode, cause merge database found
                 }
                 break;
                 case STATE_LANGUAGES: {
-                    Export::sLanguages = ByteString( argv[ i ]);
+                    Export::sLanguages = rtl::OString( argv[ i ]);
                 }
                 break;
             }
@@ -155,32 +155,27 @@ extern char *GetOutputFile( int argc, char* argv[])
     if ( bInput ) {
         // command line is valid
         bEnableExport = sal_True;
-        char *pReturn = new char[ sOutputFile.Len() + 1 ];
-        strcpy( pReturn, sOutputFile.GetBuffer());  // #100211# - checked
+        char *pReturn = new char[ sOutputFile.getLength() + 1 ];
+        std::strcpy( pReturn, sOutputFile.getStr());  // #100211# - checked
         return pReturn;
     }
 
     // command line is not valid
     return NULL;
 }
-void removeTempFile(){
-    if( !sUsedTempFile.EqualsIgnoreCaseAscii( "" ) ){
-        DirEntry aTempFile( sUsedTempFile );
-        aTempFile.Kill();
-    }
-}
+
 /*****************************************************************************/
 int InitXrmExport( char *pOutput , char* pFilename)
 /*****************************************************************************/
 {
     // instanciate Export
-    ByteString sOutput( pOutput );
-    ByteString sFilename( pFilename );
+    rtl::OString sOutput( pOutput );
+    rtl::OString sFilename( pFilename );
     Export::InitLanguages( false );
 
     if ( bMergeMode )
         pParser = new XRMResMerge( sMergeSrc, sOutputFile, sFilename );
-      else if ( sOutputFile.Len()) {
+      else if (!sOutputFile.isEmpty()) {
         pParser = new XRMResExport( sOutputFile, sPrj, sActFileName );
     }
 
@@ -196,49 +191,25 @@ int EndXrmExport()
 }
 extern const char* getFilename()
 {
-    return sInputFileName.GetBuffer();
+    return sInputFileName.getStr();
 }
 /*****************************************************************************/
 extern FILE *GetXrmFile()
 /*****************************************************************************/
 {
-    FILE *pFile = 0;
     // look for valid filename
-    if ( sInputFileName.Len()) {
-        if( Export::fileHasUTF8ByteOrderMarker( sInputFileName ) ){
-            DirEntry aTempFile = Export::GetTempFile();
-            DirEntry aSourceFile( String( sInputFileName , RTL_TEXTENCODING_ASCII_US ) );
-            aSourceFile.CopyTo( aTempFile , FSYS_ACTION_COPYFILE );
-            String sTempFile = aTempFile.GetFull();
-            Export::RemoveUTF8ByteOrderMarkerFromFile(rtl::OUStringToOString(sTempFile , RTL_TEXTENCODING_ASCII_US) );
-            pFile = fopen(rtl::OUStringToOString(sTempFile , RTL_TEXTENCODING_ASCII_US).getStr(), "r");
-            sUsedTempFile = sTempFile;
-        }else{
-            // able to open file?
-            pFile = fopen( sInputFileName.GetBuffer(), "r" );
-            sUsedTempFile = String::CreateFromAscii("");
-        }
+    if (!sInputFileName.isEmpty()) {
+        //TODO: explicit BOM handling?
+        FILE * pFile = fopen(sInputFileName.getStr(), "r");
         if ( !pFile ){
             fprintf( stderr, "Error: Could not open file %s\n",
-                sInputFileName.GetBuffer());
+                sInputFileName.getStr());
         }
         else {
-            // this is a valid file which can be opened, so
-            // create path to project root
-            DirEntry aEntry( String( sInputFileName, RTL_TEXTENCODING_ASCII_US ));
-            aEntry.ToAbs();
-            rtl::OString sFullEntry(rtl::OUStringToOString(aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US));
-            aEntry += DirEntry( String( "..", RTL_TEXTENCODING_ASCII_US ));
-            aEntry += DirEntry( sPrjRoot );
-            rtl::OString sPrjEntry(rtl::OUStringToOString(aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US));
-
-            // create file name, beginnig with project root
-            // (e.g.: source\ui\src\menue.src)
-            sActFileName = sFullEntry.copy(sPrjEntry.getLength() + 1);
-
-
-            sActFileName.SearchAndReplaceAll( "/", "\\" );
-
+            if (!bMergeMode) {
+                sActFileName = common::pathnameToken(
+                    sInputFileName.getStr(), sPrjRoot.getStr());
+            }
             return pFile;
         }
     }
@@ -298,11 +269,11 @@ XRMResParser::~XRMResParser()
 int XRMResParser::Execute( int nToken, char * pToken )
 /*****************************************************************************/
 {
-    ByteString rToken( pToken );
+    rtl::OString rToken( pToken );
 
     switch ( nToken ) {
         case XRM_TEXT_START:{
-                ByteString sNewLID = GetAttribute( rToken, "id" );
+                rtl::OString sNewLID = GetAttribute( rToken, "id" );
                 if ( sNewLID != sLID ) {
                     sLID = sNewLID;
                 }
@@ -315,14 +286,14 @@ int XRMResParser::Execute( int nToken, char * pToken )
 
         case XRM_TEXT_END: {
                 sCurrentCloseTag = rToken;
-                sResourceType = ByteString ( "readmeitem" );
-                sLangAttribute = ByteString ( "xml:lang" );
+                sResourceType = rtl::OString ( "readmeitem" );
+                sLangAttribute = rtl::OString ( "xml:lang" );
                 WorkOnText( sCurrentOpenTag, sCurrentText );
                 Output( sCurrentText );
                 EndOfText( sCurrentOpenTag, sCurrentCloseTag );
                 bText = sal_False;
-                rToken = ByteString("");
-                sCurrentText  = ByteString("");
+                rToken = rtl::OString("");
+                sCurrentText  = rtl::OString("");
         }
         break;
 
@@ -338,7 +309,7 @@ int XRMResParser::Execute( int nToken, char * pToken )
 
         case DESC_TEXT_START:{
                 if (bDisplayName) {
-                    sLID = ByteString("dispname");
+                    sLID = rtl::OString("dispname");
                     bText = sal_True;
                     sCurrentText = "";
                     sCurrentOpenTag = rToken;
@@ -350,14 +321,14 @@ int XRMResParser::Execute( int nToken, char * pToken )
         case DESC_TEXT_END: {
                 if (bDisplayName) {
                     sCurrentCloseTag = rToken;
-                    sResourceType = ByteString ( "description" );
-                    sLangAttribute = ByteString ( "lang" );
+                    sResourceType = rtl::OString ( "description" );
+                    sLangAttribute = rtl::OString ( "lang" );
                     WorkOnText( sCurrentOpenTag, sCurrentText );
                     Output( sCurrentText );
                     EndOfText( sCurrentOpenTag, sCurrentCloseTag );
                     bText = sal_False;
-                    rToken = ByteString("");
-                    sCurrentText  = ByteString("");
+                    rToken = rtl::OString("");
+                    sCurrentText  = rtl::OString("");
                 }
         }
         break;
@@ -374,17 +345,17 @@ int XRMResParser::Execute( int nToken, char * pToken )
 
         case DESC_EXTENSION_DESCRIPTION_SRC: {
                 if (bExtensionDescription) {
-                    sLID = ByteString("extdesc");
-                    sResourceType = ByteString ( "description" );
-                    sLangAttribute = ByteString ( "lang" );
+                    sLID = rtl::OString("extdesc");
+                    sResourceType = rtl::OString ( "description" );
+                    sLangAttribute = rtl::OString ( "lang" );
                     sCurrentOpenTag = rToken;
-                    sCurrentText  = ByteString("");
+                    sCurrentText  = rtl::OString("");
                     Output( rToken );
                     WorkOnDesc( sCurrentOpenTag, sCurrentText );
                     sCurrentCloseTag = rToken;
                     Output( sCurrentText );
-                    rToken = ByteString("");
-                    sCurrentText  = ByteString("");
+                    rToken = rtl::OString("");
+                    sCurrentText  = rtl::OString("");
                 }
             }
         break;
@@ -404,54 +375,46 @@ int XRMResParser::Execute( int nToken, char * pToken )
 }
 
 /*****************************************************************************/
-ByteString XRMResParser::GetAttribute( const ByteString &rToken, const ByteString &rAttribute )
+rtl::OString XRMResParser::GetAttribute( const rtl::OString &rToken, const rtl::OString &rAttribute )
 /*****************************************************************************/
 {
-    ByteString sTmp( rToken );
-    sTmp.SearchAndReplaceAll( "\t", " " );
+    rtl::OString sTmp( rToken );
+    sTmp = sTmp.replace('\t', ' ');
 
-    ByteString sSearch( " " );
+    rtl::OString sSearch( " " );
     sSearch += rAttribute;
     sSearch += "=";
-    sal_uInt16 nPos = sTmp.Search( sSearch );
+    sal_Int32 nPos = sTmp.indexOf( sSearch );
 
-    if ( nPos != STRING_NOTFOUND )
+    if ( nPos != -1 )
     {
-        sTmp = sTmp.Copy( nPos );
-        ByteString sId = comphelper::string::getToken(sTmp, 1, '\"');
+        sTmp = sTmp.copy( nPos );
+        rtl::OString sId = sTmp.getToken(1, '"');
         return sId;
     }
-    return "";
+    return rtl::OString();
 }
 
 
 /*****************************************************************************/
-void XRMResParser::Error( const ByteString &rError )
+void XRMResParser::Error( const rtl::OString &rError )
 /*****************************************************************************/
 {
-    yyerror(( char * ) rError.GetBuffer());
+    yyerror(( char * ) rError.getStr());
 }
 
 /*****************************************************************************/
-void XRMResParser::ConvertStringToDBFormat( ByteString &rString )
+void XRMResParser::ConvertStringToDBFormat( rtl::OString &rString )
 /*****************************************************************************/
 {
-    ByteString sResult;
-    do {
-        sResult = rString;
-        rString = comphelper::string::stripStart(rString, _LF);
-        rString = comphelper::string::stripStart(rString, '\t');
-        rString = comphelper::string::stripEnd(rString, '\t');
-    } while ( sResult != rString );
-
-    rString.SearchAndReplaceAll( "\t", "\\t" );
+    rString = rString.trim().replaceAll("\t", "\\t");
 }
 
 /*****************************************************************************/
-void XRMResParser::ConvertStringToXMLFormat( ByteString &rString )
+void XRMResParser::ConvertStringToXMLFormat( rtl::OString &rString )
 /*****************************************************************************/
 {
-    rString.SearchAndReplaceAll( "\\t", "\t" );
+    rString = rString.replaceAll("\\t", "\t");
 }
 
 
@@ -461,22 +424,16 @@ void XRMResParser::ConvertStringToXMLFormat( ByteString &rString )
 //
 
 /*****************************************************************************/
-XRMResOutputParser::XRMResOutputParser ( const ByteString &rOutputFile )
+XRMResOutputParser::XRMResOutputParser ( const rtl::OString &rOutputFile )
 /*****************************************************************************/
 {
     aLanguages = Export::GetLanguages();
-    pOutputStream =
-        new SvFileStream(
-            String( rOutputFile, RTL_TEXTENCODING_ASCII_US ),
-            STREAM_STD_WRITE | STREAM_TRUNC
-        );
-    pOutputStream->SetStreamCharSet( RTL_TEXTENCODING_UTF8 );
-    if ( !pOutputStream->IsOpen()) {
-        ByteString sError( "Unable to open output file: " );
+    pOutputStream.open(
+        rOutputFile.getStr(), std::ios_base::out | std::ios_base::trunc);
+    if (!pOutputStream.is_open()) {
+        rtl::OString sError( "Unable to open output file: " );
         sError += rOutputFile;
         Error( sError );
-        delete pOutputStream;
-        pOutputStream = NULL;
     }
 }
 
@@ -484,10 +441,7 @@ XRMResOutputParser::XRMResOutputParser ( const ByteString &rOutputFile )
 XRMResOutputParser::~XRMResOutputParser()
 /*****************************************************************************/
 {
-    if ( pOutputStream ) {
-        pOutputStream->Close();
-        delete pOutputStream;
-    }
+    pOutputStream.close();
 }
 
 //
@@ -496,8 +450,8 @@ XRMResOutputParser::~XRMResOutputParser()
 
 /*****************************************************************************/
 XRMResExport::XRMResExport(
-    const ByteString &rOutputFile, const ByteString &rProject,
-    const ByteString &rFilePath )
+    const rtl::OString &rOutputFile, const rtl::OString &rProject,
+    const rtl::OString &rFilePath )
 /*****************************************************************************/
                 : XRMResOutputParser( rOutputFile ),
                 pResData( NULL ),
@@ -514,27 +468,21 @@ XRMResExport::~XRMResExport()
     delete pResData;
 }
 
-void XRMResExport::Output( const ByteString& rOutput )
-{
-    // Dummy to suppress warnings caused by poor class design
-    (void) rOutput;
-}
+void XRMResExport::Output( const rtl::OString& ) {}
 
 /*****************************************************************************/
 void XRMResExport::WorkOnDesc(
-    const ByteString &rOpenTag,
-    ByteString &rText
+    const rtl::OString &rOpenTag,
+    rtl::OString &rText
 )
 /*****************************************************************************/
 {
-    DirEntry aEntry( String( sInputFileName, RTL_TEXTENCODING_ASCII_US ));
-    aEntry.ToAbs();
-    ByteString sDescFileName(rtl::OUStringToOString(aEntry.GetFull(), RTL_TEXTENCODING_ASCII_US));
-    sDescFileName.SearchAndReplaceAll( "description.xml", "" );
+    rtl::OString sDescFileName(
+        sInputFileName.replaceAll("description.xml", rtl::OString()));
     sDescFileName += GetAttribute( rOpenTag, "xlink:href" );
     int size;
     char * memblock;
-    ifstream file (sDescFileName.GetBuffer(), ios::in|ios::binary|ios::ate);
+    ifstream file (sDescFileName.getStr(), ios::in|ios::binary|ios::ate);
     if (file.is_open()) {
         size = static_cast<int>(file.tellg());
         memblock = new char [size+1];
@@ -542,8 +490,7 @@ void XRMResExport::WorkOnDesc(
         file.read (memblock, size);
         file.close();
         memblock[size] = '\0';
-        rText = ByteString(memblock);
-        rText.SearchAndReplaceAll( "\n", "\\n" );
+        rText = rtl::OString(memblock).replaceAll("\n", "\\n");
         delete[] memblock;
      }
     WorkOnText( rOpenTag, rText );
@@ -552,48 +499,43 @@ void XRMResExport::WorkOnDesc(
 
 //*****************************************************************************/
 void XRMResExport::WorkOnText(
-    const ByteString &rOpenTag,
-    ByteString &rText
+    const rtl::OString &rOpenTag,
+    rtl::OString &rText
 )
 /*****************************************************************************/
 {
-    ByteString sLang( GetAttribute( rOpenTag, sLangAttribute ));
+    rtl::OString sLang( GetAttribute( rOpenTag, sLangAttribute ));
 
     if ( !pResData )
     {
-        ByteString sPlatform( "" );
+        rtl::OString sPlatform( "" );
         pResData = new ResData( sPlatform, GetGID() );
         pResData->sId = GetLID();
     }
 
-    ByteString sText(rText);
+    rtl::OString sText(rText);
     ConvertStringToDBFormat(sText);
     pResData->sText[sLang] = sText;
 }
 
 /*****************************************************************************/
 void XRMResExport::EndOfText(
-    const ByteString &rOpenTag,
-    const ByteString &rCloseTag
+    const rtl::OString &,
+    const rtl::OString &
 )
 /*****************************************************************************/
 {
-
-    (void) rOpenTag;        // FIXME
-    (void) rCloseTag;       // FIXME
-
-    if ( pResData && pOutputStream )
+    if ( pResData )
     {
-        ByteString sTimeStamp( Export::GetTimeStamp());
-        ByteString sCur;
+        rtl::OString sCur;
         for( unsigned int n = 0; n < aLanguages.size(); n++ )
         {
             sCur = aLanguages[ n ];
 
-            rtl::OString sAct = pResData->sText[ sCur ];
-            sAct = comphelper::string::remove(sAct, 0x0A);
+            rtl::OString sAct(
+                pResData->sText[sCur].replaceAll("\x0A", rtl::OString()));
 
-            ByteString sOutput( sPrj ); sOutput += "\t";
+            rtl::OString sOutput( sPrj ); sOutput += "\t";
             sOutput += sPath;
             sOutput += "\t0\t";
             sOutput += sResourceType;
@@ -609,12 +551,10 @@ void XRMResExport::EndOfText(
 
             sOutput += sAct;
             sOutput += "\t\t\t\t";
-            sOutput += sTimeStamp;
 
-            sal_Char cSearch = 0x00;
-            sOutput.SearchAndReplaceAll( cSearch, '_' );
+            sOutput = sOutput.replace('\0', '_');
             if( sAct.getLength() > 1 )
-                pOutputStream->WriteLine( sOutput );
+                pOutputStream << sOutput.getStr() << '\n';
         }
     }
     delete pResData;
@@ -627,15 +567,15 @@ void XRMResExport::EndOfText(
 
 /*****************************************************************************/
 XRMResMerge::XRMResMerge(
-    const ByteString &rMergeSource, const ByteString &rOutputFile,
-    ByteString &rFilename)
+    const rtl::OString &rMergeSource, const rtl::OString &rOutputFile,
+    const rtl::OString &rFilename)
 /*****************************************************************************/
                 : XRMResOutputParser( rOutputFile ),
                 pMergeDataFile( NULL ),
                 sFilename( rFilename ) ,
                 pResData( NULL )
 {
-    if ( rMergeSource.Len())
+    if (!rMergeSource.isEmpty())
         pMergeDataFile = new MergeDataFile(
             rMergeSource, sInputFileName, bErrorLog);
     if( Export::sLanguages.equalsIgnoreAsciiCaseL(RTL_CONSTASCII_STRINGPARAM("ALL")))
@@ -657,8 +597,8 @@ XRMResMerge::~XRMResMerge()
 
 /*****************************************************************************/
 void XRMResMerge::WorkOnDesc(
-    const ByteString &rOpenTag,
-    ByteString &rText
+    const rtl::OString &rOpenTag,
+    rtl::OString &rText
 )
 /*****************************************************************************/
 {
@@ -666,50 +606,61 @@ void XRMResMerge::WorkOnDesc(
     if ( pMergeDataFile && pResData ) {
         PFormEntrys *pEntrys = pMergeDataFile->GetPFormEntrys( pResData );
         if ( pEntrys ) {
-            ByteString sCur;
-            ByteString sDescFilename = GetAttribute ( rOpenTag, "xlink:href" );
+            rtl::OString sCur;
+            rtl::OString sDescFilename = GetAttribute ( rOpenTag, "xlink:href" );
             for( unsigned int n = 0; n < aLanguages.size(); n++ ){
                 sCur = aLanguages[ n ];
-                ByteString sContent;
-                if ( !sCur.EqualsIgnoreCaseAscii("en-US")  &&
+                rtl::OString sContent;
+                if ( !sCur.equalsIgnoreAsciiCaseL(RTL_CONSTASCII_STRINGPARAM("en-US"))  &&
                     ( pEntrys->GetText(
                         sContent, STRING_TYP_TEXT, sCur, sal_True )) &&
-                    ( sContent != "-" ) && ( sContent.Len()))
+                    ( sContent != "-" ) && !sContent.isEmpty())
                 {
-                    ByteString sText( sContent );
-                    ByteString sAdditionalLine( "\n        " );
+                    rtl::OString sText( sContent );
+                    rtl::OString sAdditionalLine( "\n        " );
                     sAdditionalLine += rOpenTag;
-                    ByteString sSearch = sLangAttribute;
+                    rtl::OString sSearch = sLangAttribute;
                     sSearch += "=\"";
-                    ByteString sReplace( sSearch );
+                    rtl::OString sReplace( sSearch );
 
                     sSearch += GetAttribute( rOpenTag, sLangAttribute );
                     sReplace += sCur;
-                    sAdditionalLine.SearchAndReplace( sSearch, sReplace );
+                    sAdditionalLine = sAdditionalLine.replaceFirst(
+                        sSearch, sReplace);
 
-                    sSearch = ByteString("xlink:href=\"");
+                    sSearch = rtl::OString("xlink:href=\"");
                     sReplace = sSearch;
 
-                    ByteString sLocDescFilename = sDescFilename;
-                    sLocDescFilename.SearchAndReplace( "en-US", sCur );
+                    rtl::OString sLocDescFilename = sDescFilename;
+                    sLocDescFilename = sLocDescFilename.replaceFirst(
+                        "en-US", sCur);
 
                     sSearch += sDescFilename;
                     sReplace += sLocDescFilename;
-                    sAdditionalLine.SearchAndReplace( sSearch, sReplace );
+                    sAdditionalLine = sAdditionalLine.replaceFirst(
+                        sSearch, sReplace);
 
                     Output( sAdditionalLine );
 
-                    DirEntry aEntry( String( sOutputFile, RTL_TEXTENCODING_ASCII_US ));
-                    aEntry.ToAbs();
-                    ByteString sOutputDescFile(rtl::OUStringToOString(aEntry.GetPath().GetFull(), RTL_TEXTENCODING_ASCII_US));
-                    rtl::OString sDel(rtl::OUStringToOString(DirEntry::GetAccessDelimiter(), RTL_TEXTENCODING_ASCII_US));
-                    sOutputDescFile += sDel;
-                    sOutputDescFile += sLocDescFilename;
-                    sText.SearchAndReplaceAll( "\\n", "\n" );
-                    ofstream file ( sOutputDescFile.GetBuffer() );
+                    sal_Int32 i = sOutputFile.lastIndexOf('/');
+                    if (i == -1) {
+                        std::cerr
+                            << "Error: output file " << sOutputFile.getStr()
+                            << " does not contain any /\n";
+                        throw false; //TODO
+                    }
+                    rtl::OString sOutputDescFile(
+                        sOutputFile.copy(0, i + 1) + sLocDescFilename);
+                    sText = sText.replaceAll("\\n", "\n");
+                    ofstream file(sOutputDescFile.getStr());
                     if (file.is_open()) {
-                        file << sText.GetBuffer();
+                        file << sText.getStr();
                         file.close();
+                    } else {
+                        std::cerr
+                            << "Error: cannot write "
+                            << sOutputDescFile.getStr() << '\n';
+                        throw false; //TODO
                     }
                 }
             }
@@ -721,16 +672,16 @@ void XRMResMerge::WorkOnDesc(
 
 /*****************************************************************************/
 void XRMResMerge::WorkOnText(
-    const ByteString &rOpenTag,
-    ByteString &rText
+    const rtl::OString &rOpenTag,
+    rtl::OString &rText
 )
 /*****************************************************************************/
 {
-    ByteString sLang( GetAttribute( rOpenTag, sLangAttribute ));
+    rtl::OString sLang( GetAttribute( rOpenTag, sLangAttribute ));
 
     if ( pMergeDataFile ) {
         if ( !pResData ) {
-            ByteString sPlatform( "" );
+            rtl::OString sPlatform( "" );
             pResData = new ResData( sPlatform, GetLID() , sFilename );
             pResData->sId = GetLID();
             pResData->sResTyp = sResourceType;
@@ -738,11 +689,11 @@ void XRMResMerge::WorkOnText(
 
         PFormEntrys *pEntrys = pMergeDataFile->GetPFormEntrys( pResData );
             if ( pEntrys ) {
-                ByteString sContent;
+                rtl::OString sContent;
                 if ( Export::isAllowed( sLang ) &&
                     ( pEntrys->GetText(
                         sContent, STRING_TYP_TEXT, sLang )) &&
-                    ( sContent != "-" ) && ( sContent.Len()))
+                    ( sContent != "-" ) && !sContent.isEmpty())
 
                 {
                     rText = sContent;
@@ -753,18 +704,17 @@ void XRMResMerge::WorkOnText(
 }
 
 /*****************************************************************************/
-void XRMResMerge::Output( const ByteString& rOutput )
+void XRMResMerge::Output( const rtl::OString& rOutput )
 /*****************************************************************************/
 {
-    //printf("W: %s\n",rOutput.GetBuffer());
-    if ( pOutputStream && rOutput.Len() > 0 )
-        pOutputStream->Write( rOutput.GetBuffer(), rOutput.Len());
+    if (!rOutput.isEmpty())
+        pOutputStream << rOutput.getStr();
 }
 
 /*****************************************************************************/
 void XRMResMerge::EndOfText(
-    const ByteString &rOpenTag,
-    const ByteString &rCloseTag
+    const rtl::OString &rOpenTag,
+    const rtl::OString &rCloseTag
 )
 /*****************************************************************************/
 {
@@ -773,26 +723,27 @@ void XRMResMerge::EndOfText(
     if ( pMergeDataFile && pResData ) {
         PFormEntrys *pEntrys = pMergeDataFile->GetPFormEntrys( pResData );
         if ( pEntrys ) {
-            ByteString sCur;
+            rtl::OString sCur;
             for( unsigned int n = 0; n < aLanguages.size(); n++ ){
                 sCur = aLanguages[ n ];
-                ByteString sContent;
-                if ( !sCur.EqualsIgnoreCaseAscii("en-US")  &&
+                rtl::OString sContent;
+                if (!sCur.equalsIgnoreAsciiCaseL(RTL_CONSTASCII_STRINGPARAM("en-US")) &&
                     ( pEntrys->GetText(
                         sContent, STRING_TYP_TEXT, sCur, sal_True )) &&
-                    ( sContent != "-" ) && ( sContent.Len()))
+                    ( sContent != "-" ) && !sContent.isEmpty())
                 {
-                    ByteString sText( sContent );
-                    ByteString sAdditionalLine( "\n        " );
+                    rtl::OString sText( sContent );
+                    rtl::OString sAdditionalLine( "\n        " );
                     sAdditionalLine += rOpenTag;
-                    ByteString sSearch = sLangAttribute;
+                    rtl::OString sSearch = sLangAttribute;
                     sSearch += "=\"";
-                    ByteString sReplace( sSearch );
+                    rtl::OString sReplace( sSearch );
 
                     sSearch += GetAttribute( rOpenTag, sLangAttribute );
                     sReplace += sCur;
 
-                    sAdditionalLine.SearchAndReplace( sSearch, sReplace );
+                    sAdditionalLine = sAdditionalLine.replaceFirst(
+                        sSearch, sReplace);
 
                     sAdditionalLine += sText;
                     sAdditionalLine += rCloseTag;
