@@ -310,7 +310,7 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
 
                     OUString aGraphicUrl = rGraphicHelper.createGraphicObject( maBlipProps.mxGraphic );
                     // push bitmap or named bitmap to property map
-                    if( (aGraphicUrl.getLength() > 0) && rPropMap.setProperty( SHAPEPROP_FillBitmapUrl, aGraphicUrl ) )
+                    if( !aGraphicUrl.isEmpty() && rPropMap.setProperty( SHAPEPROP_FillBitmapUrl, aGraphicUrl ) )
                         eFillStyle = FillStyle_BITMAP;
 
                     // set other bitmap properties, if bitmap has been inserted into the map
@@ -376,11 +376,6 @@ void FillProperties::pushToPropMap( ShapePropertyMap& rPropMap,
 
 // ============================================================================
 
-void GraphicProperties::assignUsed( const GraphicProperties& rSourceProps )
-{
-    maBlipProps.assignUsed( rSourceProps.maBlipProps );
-}
-
 void GraphicProperties::pushToPropMap( PropertyMap& rPropMap, const GraphicHelper& rGraphicHelper, sal_Int32 nPhClr ) const
 {
     if( maBlipProps.mxGraphic.is() )
@@ -404,7 +399,7 @@ void GraphicProperties::pushToPropMap( PropertyMap& rPropMap, const GraphicHelpe
         }
 
         OUString aGraphicUrl = rGraphicHelper.createGraphicObject( xGraphic );
-        if( aGraphicUrl.getLength() > 0 )
+        if( !aGraphicUrl.isEmpty() )
             rPropMap[ PROP_GraphicURL ] <<= aGraphicUrl;
 
         // cropping
@@ -444,6 +439,10 @@ void GraphicProperties::pushToPropMap( PropertyMap& rPropMap, const GraphicHelpe
     sal_Int16 nContrast = getLimitedValue< sal_Int16, sal_Int32 >( maBlipProps.moContrast.get( 0 ) / PER_PERCENT, -100, 100 );
     if( nContrast != 0 )
         rPropMap[ PROP_AdjustContrast ] <<= nContrast;
+
+    // Media content
+    if( !maAudio.msEmbed.isEmpty() )
+        rPropMap[ PROP_MediaURL ] <<= maAudio.msEmbed;
 }
 
 // ============================================================================
