@@ -27,6 +27,7 @@
  ************************************************************************/
 
 #include <stdio.h>
+#include <tools/config.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
 #include <rtsetup.hrc>
@@ -81,7 +82,7 @@ void CommandStore::getSystemPdfCommands( ::std::list< String >& rCommands )
                 int nLen = strlen( pBuffer );
                 if( pBuffer[nLen-1] == '\n' ) // strip newline
                     pBuffer[--nLen] = 0;
-                aCommand = String( ByteString( pBuffer ), aEncoding );
+                aCommand = rtl::OUString(pBuffer, nLen, aEncoding);
                 if( ( ( aCommand.GetChar( 0 ) == '/' )
                       || ( aCommand.GetChar( 0 ) == '.' && aCommand.GetChar( 1 ) == '/' )
                       || ( aCommand.GetChar( 0 ) == '.' && aCommand.GetChar( 1 ) == '.' && aCommand.GetChar( 2 ) == '/' ) )
@@ -104,7 +105,7 @@ void CommandStore::getSystemPdfCommands( ::std::list< String >& rCommands )
                 int nLen = strlen( pBuffer );
                 if( pBuffer[nLen-1] == '\n' ) // strip newline
                     pBuffer[--nLen] = 0;
-                aCommand = String( ByteString( pBuffer ), aEncoding );
+                aCommand = rtl::OUString(pBuffer, nLen, aEncoding);
                 if( ( ( aCommand.GetChar( 0 ) == '/' )
                       || ( aCommand.GetChar( 0 ) == '.' && aCommand.GetChar( 1 ) == '/' )
                       || ( aCommand.GetChar( 0 ) == '.' && aCommand.GetChar( 1 ) == '.' && aCommand.GetChar( 2 ) == '/' ) )
@@ -344,7 +345,7 @@ void RTSCommandPage::save()
             aToken.compareToAscii( "external_dialog" )
           )
         {
-            if( aToken.getLength() )
+            if( !aToken.isEmpty() )
             {
                 if( aFeatures.Len() )
                     aFeatures += ',';
