@@ -47,13 +47,17 @@
 #include <rtl/uri.hxx>
 #include "rtl/allocator.hxx"
 
-#include "macro.hxx"
-
 #include <algorithm>
 #include <map>
 #include <memory>
 #include <utility>
 
+#ifdef IOS
+#include <premac.h>
+#import <Foundation/Foundation.h>
+#include <postmac.h>
+#endif
+
 #define MY_STRING_(x) # x
 #define MY_STRING(x) MY_STRING_(x)
 
@@ -189,11 +193,6 @@ CommandLineParameterMap::CommandLineParameterMap() {
         static char const PREFIX[] = "-env:";
         if (s.matchAsciiL(RTL_CONSTASCII_STRINGPARAM(PREFIX))) {
             sal_Int32 j = s.indexOf('=', RTL_CONSTASCII_LENGTH(PREFIX));
-            rtl::OUString k(
-                s.copy(
-                    RTL_CONSTASCII_LENGTH(PREFIX),
-                    ((j < 0 ? s.getLength() : j) -
-                     RTL_CONSTASCII_LENGTH(PREFIX))));
             if (j < 0) {
                 map_.erase(s.copy(RTL_CONSTASCII_LENGTH(PREFIX)));
             } else {
@@ -271,11 +270,11 @@ Bootstrap_Impl::Bootstrap_Impl( OUString const & rIniName )
 {
 #if OSL_DEBUG_LEVEL > 1
     OString sFile = OUStringToOString(_iniName, RTL_TEXTENCODING_ASCII_US);
-    OSL_TRACE(__FILE__" -- Bootstrap_Impl() - %s\n", sFile.getStr());
+    OSL_TRACE("Bootstrap_Impl(): sFile=%s", sFile.getStr());
 #endif /* OSL_DEBUG_LEVEL > 1 */
 
     oslFileHandle handle;
-    if (_iniName.getLength() &&
+    if (!_iniName.isEmpty() &&
         osl_File_E_None == osl_openFile(_iniName.pData, &handle, osl_File_OpenFlag_Read))
     {
         rtl::ByteSequence seq;
@@ -295,7 +294,7 @@ Bootstrap_Impl::Bootstrap_Impl( OUString const & rIniName )
 				OString name_tmp = OUStringToOString(sName, RTL_TEXTENCODING_ASCII_US);
 				OString value_tmp = OUStringToOString(sValue, RTL_TEXTENCODING_UTF8);
                 OSL_TRACE(
-                    __FILE__" -- pushing: name=%s value=%s\n",
+                    "pushing: name=%s value=%s",
                     name_tmp.getStr(), value_tmp.getStr() );
 #endif /* OSL_DEBUG_LEVEL > 1 */
 
@@ -308,7 +307,7 @@ Bootstrap_Impl::Bootstrap_Impl( OUString const & rIniName )
     else
     {
         OString file_tmp = OUStringToOString(_iniName, RTL_TEXTENCODING_ASCII_US);
-        OSL_TRACE( __FILE__" -- couldn't open file: %s", file_tmp.getStr() );
+        OSL_TRACE( "couldn't open file: %s", file_tmp.getStr() );
     }
 #endif /* OSL_DEBUG_LEVEL > 1 */
 }
@@ -379,9 +378,9 @@ Bootstrap_Impl * BootstrapMap::getIni(
 }
 
 void BootstrapMap::setBaseIniUri(rtl::OUString const & uri) {
-    OSL_ASSERT(uri.getLength() != 0);
+    OSL_ASSERT(!uri.isEmpty());
     osl::MutexGuard g(mutex_);
-    OSL_ASSERT(baseIniUri_.getLength() == 0 && baseIni_ == 0);
+    OSL_ASSERT(baseIniUri_.isEmpty() && baseIni_ == 0);
     baseIniUri_ = uri;
 }
 
@@ -389,7 +388,22 @@ Bootstrap_Impl * BootstrapMap::getBaseIni() {
     osl::MutexGuard g(mutex_);
     if (baseIni_ == 0) {
         rtl::OUString uri;
-        if (baseIniUri_.getLength() == 0) {
+        if (baseIniUri_.isEmpty()) {
+#if defined IOS
+            // On iOS hardcode the inifile as "rc" in the .app
+            // directory. Apps are self-contained anyway, there is no
+            // possibility to have several "applications" in the same
+            // installation location with different inifiles.
+            const char *inifile = [[@"vnd.sun.star.pathname:" stringByAppendingString: [[[NSBundle mainBundle] bundlePath] stringByAppendingPathComponent: @"rc"]] UTF8String];
+            uri = rtl::OUString(inifile, strlen(inifile), RTL_TEXTENCODING_UTF8);
+            resolvePathnameUrl(&uri);
+#elif defined ANDROID
+            // Apps are self-contained on Android, too, can as well hardcode
+            // it as "rc" in the "/assets" directory, i.e.  inside the app's
+            // .apk (zip) archive as the /assets/rc file.
+            uri = rtl::OUString("vnd.sun.star.pathname:/assets/rc");
+            resolvePathnameUrl(&uri);
+#else
             if (CommandLineParameters::get().get(
                     rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("INIFILENAME")),
                     &uri))
@@ -416,6 +430,7 @@ Bootstrap_Impl * BootstrapMap::getBaseIni() {
                 uri += rtl::OUString(
                     RTL_CONSTASCII_USTRINGPARAM(SAL_CONFIGFILE("")));
             }
+#endif
         } else {
             uri = baseIniUri_;
         }
@@ -458,24 +473,24 @@ bool Bootstrap_Impl::getValue(
     if (override && getDirectValue(key, value, mode, requestStack)) {
         return true;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("_OS"))) {
+    if ( key == "_OS" ) {
         rtl_uString_assign(
-            value, rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(THIS_OS)).pData);
+            value, rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(RTL_OS)).pData);
         return true;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("_ARCH"))) {
+    if ( key == "_ARCH" ) {
         rtl_uString_assign(
-            value, rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(THIS_ARCH)).pData);
+            value, rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(RTL_ARCH)).pData);
         return true;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("_CPPU_ENV"))) {
+    if ( key == "_CPPU_ENV" ) {
         rtl_uString_assign(
             value,
             (rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(MY_STRING(CPPU_ENV))).
              pData));
         return true;
     }
-    if (key.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("ORIGIN"))) {
+    if ( key == "ORIGIN" ) {
         rtl_uString_assign(
             value,
             _iniName.copy(
@@ -485,21 +500,21 @@ bool Bootstrap_Impl::getValue(
     if (getAmbienceValue(key, value, mode, requestStack)) {
         return true;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("SYSUSERCONFIG"))) {
+    if ( key == "SYSUSERCONFIG" ) {
         rtl::OUString v;
         bool b = osl::Security().getConfigDir(v);
         EnsureNoFinalSlash(v);
         rtl_uString_assign(value, v.pData);
         return b;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("SYSUSERHOME"))) {
+    if ( key == "SYSUSERHOME" ) {
         rtl::OUString v;
         bool b = osl::Security().getHomeDir(v);
         EnsureNoFinalSlash(v);
         rtl_uString_assign(value, v.pData);
         return b;
     }
-    if (key.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("SYSBINDIR"))) {
+    if ( key == "SYSBINDIR" ) {
         getExecutableDirectory_Impl(value);
         return true;
     }
@@ -581,7 +596,7 @@ rtlBootstrapHandle SAL_CALL rtl_bootstrap_args_open (
 //----------------------------------------------------------------------------
 
 void SAL_CALL rtl_bootstrap_args_close (
-    rtlBootstrapHandle
+    SAL_UNUSED_PARAMETER rtlBootstrapHandle
 ) SAL_THROW_EXTERN_C()
 {
     // do nothing; the BootstrapMap::map_ just keeps growing for now
@@ -779,7 +794,7 @@ rtl::OUString expandMacros(
                 for (int j = 0; j < n; ++j) {
                     seg[j] = expandMacros(file, seg[j], mode, requestStack);
                 }
-                if (n == 3 && seg[1].getLength() == 0) {
+                if (n == 3 && seg[1].isEmpty()) {
                     // For backward compatibility, treat ${file::key} the same
                     // as just ${file:key}:
                     seg[1] = seg[2];
@@ -788,8 +803,7 @@ rtl::OUString expandMacros(
                 if (n == 1) {
                     buf.append(lookup(file, mode, false, seg[0], requestStack));
                 } else if (n == 2) {
-                    if (seg[0].equalsAsciiL(
-                            RTL_CONSTASCII_STRINGPARAM(".link")))
+                    if ( seg[0] == ".link" )
                     {
                         osl::File f(seg[1]);
                         rtl::ByteSequence seq;
@@ -821,8 +835,7 @@ rtl::OUString expandMacros(
                                     rtl::Bootstrap(seg[0]).getHandle()),
                                 mode, false, seg[1], requestStack));
                     }
-                } else if (seg[0].equalsAsciiL(
-                               RTL_CONSTASCII_STRINGPARAM(".override")))
+                } else if ( seg[0] == ".override" )
                 {
                     rtl::Bootstrap b(seg[1]);
                     Bootstrap_Impl * f = static_cast< Bootstrap_Impl * >(
