@@ -1076,6 +1076,11 @@ void ScModule::ModifyOptions( const SfxItemSet& rOptSet )
     if (rOptSet.HasItem(SID_SCFORMULAOPTIONS, &pItem))
     {
         const ScFormulaOptions& rOpt = ((const ScTpFormulaItem*)pItem)->GetFormulaOptions();
+
+        if (!pFormulaCfg || (*pFormulaCfg != rOpt))
+            // Formula options have changed. Repaint the column headers.
+            bRepaint = true;
+
         SetFormulaOptions( rOpt );
 
         if ( pDocSh )
@@ -2051,7 +2056,10 @@ SfxItemSet*  ScModule::CreateItemSet( sal_uInt16 nId )
 
         // TP_USERLISTS
         if ( pUL )
+        {
             aULItem.SetUserList( *pUL );
+            pRet->Put(aULItem);
+        }
 
         // TP_COMPATIBILITY
         pRet->Put( SfxUInt16Item( SID_SC_OPT_KEY_BINDING_COMPAT,
