@@ -67,7 +67,6 @@ using ::rtl::OUStringBuffer;
 #define INVALID_HEADER_POS std::numeric_limits<size_t>::max()
 
 ScFilterDlg::EntryList::EntryList() :
-    maList(128, 128),
     mnHeaderPos(INVALID_HEADER_POS) {}
 
 ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
@@ -114,12 +113,12 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
         aBtnDestPers    ( this, ScResId( BTN_DEST_PERS ) ),
         aFtDbAreaLabel  ( this, ScResId( FT_DBAREA_LABEL ) ),
         aFtDbArea       ( this, ScResId( FT_DBAREA ) ),
-        aStrUndefined   ( ResId::toString(ScResId(SCSTR_UNDEFINED)) ),
-        aStrNone        ( ResId::toString(ScResId(SCSTR_NONE)) ),
-        aStrEmpty       ( ResId::toString(ScResId(SCSTR_EMPTY)) ),
-        aStrNotEmpty    ( ResId::toString(ScResId(SCSTR_NOTEMPTY)) ),
-        aStrRow         ( ResId::toString(ScResId(SCSTR_ROW)) ),
-        aStrColumn      ( ResId::toString(ScResId(SCSTR_COLUMN)) ),
+        aStrUndefined   ( SC_RESSTR(SCSTR_UNDEFINED) ),
+        aStrNone        ( SC_RESSTR(SCSTR_NONE) ),
+        aStrEmpty       ( SC_RESSTR(SCSTR_FILTER_EMPTY) ),
+        aStrNotEmpty    ( SC_RESSTR(SCSTR_FILTER_NOTEMPTY) ),
+        aStrRow         ( SC_RESSTR(SCSTR_ROW) ),
+        aStrColumn      ( SC_RESSTR(SCSTR_COLUMN) ),
         //
         pOptionsMgr     ( NULL ),
         nWhichQuery     ( rArgSet.GetPool()->GetWhich( SID_QUERY ) ),
@@ -144,7 +143,7 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
 
     OUStringBuffer aBuf;
 
-    OUString sAccName = ResId::toString(ScResId(RID_FILTER_OPERATOR));
+    OUString sAccName = SC_RESSTR(RID_FILTER_OPERATOR);
     aBuf.append(sAccName);
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
     aLbConnect1.SetAccessibleName(aBuf.makeStringAndClear());
@@ -152,7 +151,7 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 2"));
     aLbConnect2.SetAccessibleName(aBuf.makeStringAndClear());
 
-    sAccName = ResId::toString(ScResId(RID_FILTER_FIELDNAME));
+    sAccName = SC_RESSTR(RID_FILTER_FIELDNAME);
     aBuf.append(sAccName);
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
     aLbField1.SetAccessibleName(aBuf.makeStringAndClear());
@@ -163,7 +162,7 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 3"));
     aLbField3.SetAccessibleName(aBuf.makeStringAndClear());
 
-    sAccName = ResId::toString(ScResId(RID_FILTER_CONDITION));
+    sAccName = SC_RESSTR(RID_FILTER_CONDITION);
     aBuf.append(sAccName);
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
     aLbCond1.SetAccessibleName(aBuf.makeStringAndClear());
@@ -174,7 +173,7 @@ ScFilterDlg::ScFilterDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 3"));
     aLbCond3.SetAccessibleName(aBuf.makeStringAndClear());
 
-    sAccName = ResId::toString(ScResId(RID_FILTER_VALUE));
+    sAccName = SC_RESSTR(RID_FILTER_VALUE);
     aBuf.append(sAccName);
     aBuf.appendAscii(RTL_CONSTASCII_STRINGPARAM (" 1"));
     aEdVal1.SetAccessibleName(aBuf.makeStringAndClear());
@@ -522,11 +521,10 @@ void ScFilterDlg::FillFieldLists()
     }
 }
 
-
-//----------------------------------------------------------------------------
-
 void ScFilterDlg::UpdateValueList( size_t nList )
 {
+    bool bCaseSens = aBtnCase.IsChecked();
+
     if (pDoc && nList > 0 && nList <= QUERY_ENTRY_COUNT)
     {
         ComboBox*   pValList        = maValueEdArr[nList-1];
@@ -563,44 +561,51 @@ void ScFilterDlg::UpdateValueList( size_t nList )
                     return;
 
                 pList = r.first->second;
-                pList->maList.SetCaseSensitive(aBtnCase.IsChecked());
-                pDoc->GetFilterEntriesArea( nColumn, nFirstRow+1, nLastRow,
-                                            nTab, pList->maList, maHasDates[nOffset+nList-1] );
+                pDoc->GetFilterEntriesArea(
+                    nColumn, nFirstRow+1, nLastRow,
+                    nTab, bCaseSens, pList->maList, maHasDates[nOffset+nList-1] );
 
                 // Entry for the first line
                 //! Entry (pHdrEntry) doesn't generate collection?
 
                 pList->mnHeaderPos = INVALID_HEADER_POS;
-                TypedScStrCollection aHdrColl( 1, 1 );
+                std::vector<ScTypedStrData> aHdrColl;
                 bool bDummy = false;
-                pDoc->GetFilterEntriesArea( nColumn, nFirstRow, nFirstRow,
-                                            nTab, aHdrColl, bDummy );
-                TypedStrData* pHdrEntry = aHdrColl[0];
-                if ( pHdrEntry )
+                pDoc->GetFilterEntriesArea(
+                    nColumn, nFirstRow, nFirstRow, nTab, true, aHdrColl, bDummy );
+                if (!aHdrColl.empty())
                 {
-                    TypedStrData* pNewEntry = new TypedStrData(*pHdrEntry);
-                    if ( pList->maList.Insert(pNewEntry) )
+                    // See if the header value is already in the list.
+                    std::vector<ScTypedStrData>::iterator itBeg = pList->maList.begin(), itEnd = pList->maList.end();
+                    std::vector<ScTypedStrData>::iterator it = std::find_if(
+                        itBeg, itEnd, FindTypedStrData(aHdrColl.front(), bCaseSens));
+                    if (it == itEnd)
                     {
-                        pList->mnHeaderPos = pList->maList.IndexOf(pNewEntry);
-                        OSL_ENSURE( pList->mnHeaderPos != INVALID_HEADER_POS,
-                                    "Header-Eintrag nicht wiedergefunden" );
+                        // Not in the list. Insert it.
+                        pList->maList.push_back(aHdrColl.front());
+                        if (bCaseSens)
+                            std::sort(pList->maList.begin(), pList->maList.end(), ScTypedStrData::LessCaseSensitive());
+                        else
+                            std::sort(pList->maList.begin(), pList->maList.end(), ScTypedStrData::LessCaseInsensitive());
+
+                        // Record its position.
+                        itBeg = pList->maList.begin();
+                        itEnd = pList->maList.end();
+                        it = std::find_if(itBeg, itEnd, FindTypedStrData(aHdrColl.front(), bCaseSens));
+                        pList->mnHeaderPos = std::distance(itBeg, it);
                     }
-                    else
-                        delete pNewEntry;           // was already there
                 }
             }
             else
                 pList = &maEntryLists[nColumn];
 
             OSL_ASSERT(pList);
-            sal_uInt16 nValueCount = pList->maList.GetCount();
-            if ( nValueCount > 0 )
+
+            std::vector<ScTypedStrData>::const_iterator it = pList->maList.begin(), itEnd = pList->maList.end();
+            for (; it != itEnd; ++it)
             {
-                for ( sal_uInt16 i=0; i<nValueCount; i++ )
-                {
-                    pValList->InsertEntry(pList->maList[i]->GetString(), nListPos);
-                    nListPos++;
-                }
+                pValList->InsertEntry(it->GetString(), nListPos);
+                nListPos++;
             }
         }
         pValList->SetText( aCurValue );
@@ -638,14 +643,9 @@ void ScFilterDlg::UpdateHdrInValueList( size_t nList )
     ComboBox* pValList = maValueEdArr[nList-1];
     size_t nListPos = nPos + 2;                 // for "empty" and "non-empty"
 
-    TypedStrData* pHdrEntry = maEntryLists[nColumn].maList[nPos];
-    if (!pHdrEntry)
-    {
-        OSL_FAIL("Eintag in Liste nicht gefunden");
-        return;
-    }
+    const ScTypedStrData& rHdrEntry = maEntryLists[nColumn].maList[nPos];
 
-    rtl::OUString aHdrStr = pHdrEntry->GetString();
+    const rtl::OUString& aHdrStr = rHdrEntry.GetString();
     bool bWasThere = aHdrStr.equals(pValList->GetEntry(nListPos));
     bool bInclude = !aBtnHeader.IsChecked();
 
@@ -784,7 +784,7 @@ IMPL_LINK( ScFilterDlg, EndDlgHdl, Button*, pBtn )
 
 //----------------------------------------------------------------------------
 
-IMPL_LINK( ScFilterDlg, MoreClickHdl, MoreButton*, EMPTYARG )
+IMPL_LINK_NOARG(ScFilterDlg, MoreClickHdl)
 {
     if ( aBtnMore.GetState() )
         pTimer->Start();
@@ -1200,7 +1200,7 @@ IMPL_LINK( ScFilterDlg, ValModifyHdl, ComboBox*, pEd )
 }
 
 //----------------------------------------------------------------------------
-IMPL_LINK( ScFilterDlg, ScrollHdl, ScrollBar*, EMPTYARG )
+IMPL_LINK_NOARG(ScFilterDlg, ScrollHdl)
 {
     SliderMoved();
     return 0;
