@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <comphelper/processfactory.hxx>
 
 #include <com/sun/star/frame/UnknownModuleException.hpp>
@@ -47,10 +46,8 @@
 #include "DrawDocShell.hxx"
 #include <sfx2/app.hxx>
 #include "PaneChildWindows.hxx"
-#include "NotesChildWindow.hxx"
 #include "ViewShellManager.hxx"
 #include "DrawController.hxx"
-#include "UpdateLockManager.hxx"
 #include "FrameView.hxx"
 #include "ViewTabBar.hxx"
 #include <sfx2/event.hxx>
@@ -88,7 +85,6 @@
 #include <sfx2/objface.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svl/whiter.hxx>
-#include <comphelper/processfactory.hxx>
 #include <vcl/msgbox.hxx>
 #include <tools/diagnose_ex.h>
 
@@ -152,15 +148,9 @@ public:
         It does not include the ViewTabBar.
     */
     ::boost::scoped_ptr< ::Window> mpViewWindow;
-
     ::boost::shared_ptr<ToolBarManager> mpToolBarManager;
-
     ::boost::shared_ptr<ViewShellManager> mpViewShellManager;
-
     ::boost::shared_ptr<tools::EventMultiplexer> mpEventMultiplexer;
-
-    ::boost::shared_ptr<UpdateLockManager> mpUpdateLockManager;
-
     ::boost::shared_ptr<FormShellManager> mpFormShellManager;
 
     Implementation (ViewShellBase& rBase);
@@ -245,13 +235,12 @@ SfxViewShell* ViewShellBase::CreateInstance (
     SfxViewFrame *pFrame, SfxViewShell *pOldView)
 {
     ViewShellBase* pBase = new ViewShellBase(pFrame, pOldView);
-    pBase->LateInit(OUString());
+    pBase->LateInit("");
     return pBase;
 }
 void ViewShellBase::RegisterFactory( sal_uInt16 nPrio )
 {
-    pFactory = new SfxViewFactory(
-        &CreateInstance,&InitFactory,nPrio,"Default");
+    pFactory = new SfxViewFactory( &CreateInstance,&InitFactory,nPrio,"Default" );
     InitFactory();
 }
 void ViewShellBase::InitFactory()
@@ -282,7 +271,6 @@ ViewShellBase::ViewShellBase (
     mpImpl.reset(new Implementation(*this));
     mpImpl->mpViewWindow.reset(new FocusForwardingWindow(_pFrame->GetWindow(),*this));
     mpImpl->mpViewWindow->SetBackground(Wallpaper());
-    mpImpl->mpUpdateLockManager.reset(new UpdateLockManager(*this));
 
     _pFrame->GetWindow().SetBackground(Wallpaper());
 
@@ -323,7 +311,6 @@ ViewShellBase::~ViewShellBase (void)
         pShell->GetActiveWindow()->GetParent()->Hide();
     }
 
-    mpImpl->mpUpdateLockManager->Disable();
     mpImpl->mpToolBarManager->Shutdown();
     mpImpl->mpViewShellManager->Shutdown();
 
@@ -360,7 +347,7 @@ void ViewShellBase::LateInit (const ::rtl::OUString& rsDefaultView)
         if (xConfigurationController.is())
         {
             OUString sView (rsDefaultView);
-            if (sView.getLength() == 0)
+            if (sView.isEmpty())
                 sView = GetInitialViewShellType();
 
             ::boost::shared_ptr<FrameworkHelper> pHelper (FrameworkHelper::Instance(*this));
@@ -824,7 +811,7 @@ void ViewShellBase::ReadUserDataSequence (
                         sViewURL = framework::FrameworkHelper::msHandoutViewURL;
                         break;
                 }
-                if (sViewURL.getLength() > 0)
+                if (!sViewURL.isEmpty())
                     framework::FrameworkHelper::Instance(*this)->RequestView(
                         sViewURL,
                         framework::FrameworkHelper::msCenterPaneURL);
@@ -1095,19 +1082,6 @@ const Rectangle& ViewShellBase::getClientRectangle (void) const
 }
 
 
-
-
-::boost::shared_ptr<UpdateLockManager> ViewShellBase::GetUpdateLockManager (void) const
-{
-    OSL_ASSERT(mpImpl.get()!=NULL);
-    OSL_ASSERT(mpImpl->mpUpdateLockManager.get()!=NULL);
-
-    return mpImpl->mpUpdateLockManager;
-}
-
-
-
-
 ::boost::shared_ptr<ToolBarManager> ViewShellBase::GetToolBarManager (void) const
 {
     OSL_ASSERT(mpImpl.get()!=NULL);
@@ -1162,18 +1136,18 @@ void ViewShellBase::SetViewTabBar (const ::rtl::Reference<ViewTabBar>& rViewTabB
 {
     ::rtl::OUString aLabel;
 
-    if ( aCmdURL.getLength() > 0 ) try
+    if ( !aCmdURL.isEmpty() ) try
     {
         Reference< XMultiServiceFactory > xServiceManager( ::comphelper::getProcessServiceFactory(), UNO_QUERY_THROW );
 
-        Reference< XModuleManager > xModuleManager( xServiceManager->createInstance( OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.ModuleManager") ) ), UNO_QUERY_THROW );
+        Reference< XModuleManager > xModuleManager( xServiceManager->createInstance( "com.sun.star.frame.ModuleManager" ), UNO_QUERY_THROW );
         Reference< XInterface > xIfac( xFrame, UNO_QUERY_THROW );
 
         ::rtl::OUString aModuleIdentifier( xModuleManager->identify( xIfac ) );
 
-        if( aModuleIdentifier.getLength() > 0 )
+        if( !aModuleIdentifier.isEmpty() )
         {
-            Reference< XNameAccess > xNameAccess( xServiceManager->createInstance( rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.frame.UICommandDescription" ) ) ), UNO_QUERY );
+            Reference< XNameAccess > xNameAccess( xServiceManager->createInstance( "com.sun.star.frame.UICommandDescription" ), UNO_QUERY );
             if( xNameAccess.is() )
             {
                 Reference< ::com::sun::star::container::XNameAccess > m_xUICommandLabels( xNameAccess->getByName( aModuleIdentifier ), UNO_QUERY_THROW );
@@ -1182,7 +1156,7 @@ void ViewShellBase::SetViewTabBar (const ::rtl::Reference<ViewTabBar>& rViewTabB
                 {
                     for( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
                     {
-                        if( aPropSeq[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Name" ) ))
+                        if ( aPropSeq[i].Name == "Name" )
                         {
                             aPropSeq[i].Value >>= aLabel;
                             break;
@@ -1218,7 +1192,6 @@ ViewShellBase::Implementation::Implementation (ViewShellBase& rBase)
       mpToolBarManager(),
       mpViewShellManager(),
       mpEventMultiplexer(),
-      mpUpdateLockManager(),
       mpFormShellManager(),
       mrBase(rBase),
       mpPageCacheManager(slidesorter::cache::PageCacheManager::Instance())
@@ -1265,9 +1238,7 @@ void ViewShellBase::Implementation::ProcessRestoreEditingViewSlot (void)
             pHelper->RequestView(
                 pHelper->GetViewURL(pFrameView->GetViewShellTypeOnLoad()),
                 FrameworkHelper::msCenterPaneURL);
-            pHelper->RunOnConfigurationEvent(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ConfigurationUpdateEnd")),
-                CurrentPageSetter(mrBase));
+            pHelper->RunOnConfigurationEvent("ConfigurationUpdateEnd", CurrentPageSetter(mrBase));
         }
     }
 }
