@@ -26,18 +26,17 @@
  *
  ************************************************************************/
 
-
 #if defined UNX
 #include <limits.h>
 #else // UNX
 #include <stdlib.h>
+#ifndef PATH_MAX
 #define PATH_MAX _MAX_PATH
+#endif
 #endif // UNX
 
 #include <sfx2/app.hxx>
 #include <sfx2/frame.hxx>
-#include <tools/simplerm.hxx>
-#include <tools/config.hxx>
 #include <basic/basrdll.hxx>
 #include <basic/sbmeth.hxx>
 #include <basic/sbmod.hxx>
@@ -51,13 +50,9 @@
 #include <svtools/ehdl.hxx>
 
 #include <svl/svdde.hxx>
-#include <tools/urlobj.hxx>
 #include <unotools/tempfile.hxx>
 #include <osl/file.hxx>
-
-#define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
-
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -106,21 +101,17 @@
 #include <sfx2/event.hxx>
 #include "imestatuswindow.hxx"
 #include "workwin.hxx"
-#include <sfx2/module.hxx>
 #include <sfx2/tbxctrl.hxx>
 #include <sfx2/sfxdlg.hxx>
 #include "sfx2/stbitem.hxx"
 #include "eventsupplier.hxx"
 #include <sfx2/dockwin.hxx>
-#include <tools/svlibrary.hxx>
 
 #ifdef DBG_UTIL
-#include <sfx2/tbxctrl.hxx>
 #include <sfx2/mnuitem.hxx>
 #endif
 
 #include <unotools/saveopt.hxx>
-#include <unotools/undoopt.hxx>
 #include <svtools/helpopt.hxx>
 #include <unotools/pathoptions.hxx>
 #include <unotools/viewoptions.hxx>
@@ -132,14 +123,12 @@
 #include <unotools/startoptions.hxx>
 #include <unotools/securityoptions.hxx>
 #include <unotools/localisationoptions.hxx>
-#include <unotools/inetoptions.hxx>
 #include <unotools/fontoptions.hxx>
 #include <unotools/internaloptions.hxx>
 #include <unotools/workingsetoptions.hxx>
 #include <unotools/syslocaleoptions.hxx>
 #include <unotools/syslocale.hxx>
 #include <framework/addonsoptions.hxx>
-#include <svtools/ttprops.hxx>
 #include <unotools/extendedsecurityoptions.hxx>
 #include <rtl/instance.hxx>
 #include <rtl/strbuf.hxx>
@@ -148,114 +137,13 @@ using namespace ::com::sun::star;
 
 // Static member
 SfxApplication* SfxApplication::pApp = NULL;
+#ifndef DISABLE_SCRIPTING
 static BasicDLL*       pBasic   = NULL;
+#endif
 static SfxHelp*        pSfxHelp = NULL;
 
 namespace
 {
-    class SfxPropertyHandler : public PropertyHandler
-    {
-        virtual void Property( ApplicationProperty& );
-    };
-
-    void SfxPropertyHandler::Property( ApplicationProperty& rProp )
-    {
-        TTProperties* pTTProperties = PTR_CAST( TTProperties, &rProp );
-        if ( pTTProperties )
-        {
-            pTTProperties->nPropertyVersion = TT_PROPERTIES_VERSION;
-            switch ( pTTProperties->nActualPR )
-            {
-                case TT_PR_SLOTS:
-                {
-                    pTTProperties->nSidOpenUrl = SID_OPENURL;
-                    pTTProperties->nSidFileName = SID_FILE_NAME;
-                    pTTProperties->nSidNewDocDirect = SID_NEWDOCDIRECT;
-                    pTTProperties->nSidCopy = SID_COPY;
-                    pTTProperties->nSidPaste = SID_PASTE;
-                    pTTProperties->nSidSourceView = SID_SOURCEVIEW;
-                    pTTProperties->nSidSelectAll = SID_SELECTALL;
-                    pTTProperties->nSidReferer = SID_REFERER;
-                    pTTProperties->nActualPR = 0;
-                }
-                break;
-                case TT_PR_DISPATCHER:
-                {
-                    // interface for TestTool
-                    SfxViewFrame* pViewFrame=0;
-                    SfxDispatcher* pDispatcher=0;
-                    pViewFrame = SfxViewFrame::Current();
-                    if ( !pViewFrame )
-                        pViewFrame = SfxViewFrame::GetFirst();
-                    if ( pViewFrame )
-                        pDispatcher = pViewFrame->GetDispatcher();
-                    else
-                        pDispatcher = NULL;
-                    if ( !pDispatcher )
-                        pTTProperties->nActualPR = TT_PR_ERR_NODISPATCHER;
-                    else
-                    {
-                        pDispatcher->SetExecuteMode(EXECUTEMODE_DIALOGASYNCHRON);
-                        if ( pTTProperties->mnSID == SID_NEWDOCDIRECT
-                          || pTTProperties->mnSID == SID_OPENDOC )
-                        {
-                            SfxPoolItem** pArgs = pTTProperties->mppArgs;
-                            SfxAllItemSet aSet( SFX_APP()->GetPool() );
-                            if ( pArgs && *pArgs )
-                            {
-                                for ( SfxPoolItem **pArg = pArgs; *pArg; ++pArg )
-                                    aSet.Put( **pArg );
-                            }
-                            if ( pTTProperties->mnSID == SID_NEWDOCDIRECT )
-                            {
-                                String aFactory = String::CreateFromAscii("private:factory/");
-                                if ( pArgs && *pArgs )
-                                {
-                                    SFX_ITEMSET_ARG( &aSet, pFactoryName, SfxStringItem, SID_NEWDOCDIRECT, sal_False );
-                                    if ( pFactoryName )
-                                        aFactory += pFactoryName->GetValue();
-                                    else
-                                        aFactory += String::CreateFromAscii("swriter");
-                                }
-                                else
-                                    aFactory += String::CreateFromAscii("swriter");
-
-                                aSet.Put( SfxStringItem( SID_FILE_NAME, aFactory ) );
-                                aSet.ClearItem( SID_NEWDOCDIRECT );
-                                pTTProperties->mnSID = SID_OPENDOC;
-                            }
-
-                            aSet.Put( SfxStringItem( SID_TARGETNAME, DEFINE_CONST_UNICODE("_blank") ) );
-                            if ( pDispatcher->ExecuteFunction( pTTProperties->mnSID, aSet, pTTProperties->mnMode )
-                                        == EXECUTE_NO )
-                                pTTProperties->nActualPR = TT_PR_ERR_NOEXECUTE;
-                            else
-                                pTTProperties->nActualPR = 0;
-                        }
-                        else
-                        {
-                            if ( pDispatcher->ExecuteFunction(
-                                    pTTProperties->mnSID, pTTProperties->mppArgs, pTTProperties->mnMode )
-                                == EXECUTE_NO )
-                                pTTProperties->nActualPR = TT_PR_ERR_NOEXECUTE;
-                            else
-                                pTTProperties->nActualPR = 0;
-                        }
-                    }
-                }
-                break;
-                default:
-                {
-                    pTTProperties->nPropertyVersion = 0;
-                }
-            }
-            return;
-        }
-    }
-
-    class thePropertyHandler
-        : public rtl::Static<SfxPropertyHandler, thePropertyHandler> {};
-
     class theApplicationMutex
         : public rtl::Static<osl::Mutex, theApplicationMutex> {};
 }
@@ -307,8 +195,6 @@ SfxApplication::SfxApplication()
     RTL_LOGFILE_CONTEXT( aLog, "sfx2 (mb93783) ::SfxApplication::SfxApplication" );
 
     SetName( DEFINE_CONST_UNICODE("StarOffice") );
-    GetpApp()->SetPropertyHandler( &thePropertyHandler::get() );
-
     SvtViewOptions::AcquireOptions();
 
     pAppData_Impl = new SfxAppData_Impl( this );
@@ -336,8 +222,10 @@ SfxApplication::SfxApplication()
 
     pSfxHelp = new SfxHelp;
 
+#ifndef DISABLE_SCRIPTING
     pBasic   = new BasicDLL;
     StarBASIC::SetGlobalErrorHdl( LINK( this, SfxApplication, GlobalBasicErrorHdl_Impl ) );
+#endif
     RTL_LOGFILE_CONTEXT_TRACE( aLog, "} initialize DDE" );
 }
 
@@ -354,8 +242,9 @@ SfxApplication::~SfxApplication()
 
     // delete global options
     SvtViewOptions::ReleaseOptions();
+#ifndef DISABLE_SCRIPTING
     delete pBasic;
-
+#endif
     if ( !pAppData_Impl->bDowning )
         Deinitialize();
 
@@ -595,35 +484,47 @@ void SfxApplication::Invalidate( sal_uInt16 nId )
 #define DOSTRING( x )                       #x
 #define STRING( x )                         DOSTRING( x )
 
+#ifndef DISABLE_SCRIPTING
+
 typedef long (SAL_CALL *basicide_handle_basic_error)(void*);
 typedef rtl_uString* (SAL_CALL *basicide_choose_macro)(void*, sal_Bool, rtl_uString*);
 typedef void* (SAL_CALL *basicide_macro_organizer)(sal_Int16);
 
 extern "C" { static void SAL_CALL thisModule() {} }
 
+#endif
+
 IMPL_LINK( SfxApplication, GlobalBasicErrorHdl_Impl, StarBASIC*, pStarBasic )
 {
+#ifdef DISABLE_SCRIPTING
+    (void) pStarBasic;
+    return 0;
+#else
     // get basctl dllname
-    static ::rtl::OUString aLibName( RTL_CONSTASCII_USTRINGPARAM( SVLIBRARY( "basctl" ) ) );
+    static ::rtl::OUString aLibName( SVLIBRARY( "basctl"  ) );
 
     // load module
     oslModule handleMod = osl_loadModuleRelative(
         &thisModule, aLibName.pData, 0 );
 
     // get symbol
-    ::rtl::OUString aSymbol( RTL_CONSTASCII_USTRINGPARAM( "basicide_handle_basic_error" ) );
+    ::rtl::OUString aSymbol( "basicide_handle_basic_error"  );
     basicide_handle_basic_error pSymbol = (basicide_handle_basic_error) osl_getFunctionSymbol( handleMod, aSymbol.pData );
 
     // call basicide_handle_basic_error in basctl
     long nRet = pSymbol ? pSymbol( pStarBasic ) : 0;
 
     return nRet;
+#endif
 }
 
 sal_Bool SfxApplication::IsXScriptURL( const String& rScriptURL )
 {
     sal_Bool result = sal_False;
 
+#ifdef DISABLE_SCRIPTING
+    (void) rScriptURL;
+#else
     ::com::sun::star::uno::Reference
         < ::com::sun::star::lang::XMultiServiceFactory > xSMgr =
             ::comphelper::getProcessServiceFactory();
@@ -631,8 +532,8 @@ sal_Bool SfxApplication::IsXScriptURL( const String& rScriptURL )
     ::com::sun::star::uno::Reference
         < ::com::sun::star::uri::XUriReferenceFactory >
             xFactory( xSMgr->createInstance(
-                ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                    "com.sun.star.uri.UriReferenceFactory" )) ),
+                ::rtl::OUString(
+                    "com.sun.star.uri.UriReferenceFactory" ) ),
                 ::com::sun::star::uno::UNO_QUERY );
 
     if ( xFactory.is() )
@@ -649,11 +550,12 @@ sal_Bool SfxApplication::IsXScriptURL( const String& rScriptURL )
                 result = sal_True;
             }
         }
-        catch ( ::com::sun::star::uno::RuntimeException& )
+        catch (const ::com::sun::star::uno::RuntimeException&)
         {
             // ignore, will just return FALSE
         }
     }
+#endif
     return result;
 }
 
@@ -662,6 +564,7 @@ SfxApplication::ChooseScript()
 {
     ::rtl::OUString aScriptURL;
 
+#ifndef DISABLE_SCRIPTING
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
     if ( pFact )
     {
@@ -687,29 +590,42 @@ SfxApplication::ChooseScript()
 
           delete pDlg;
     }
+#endif
     return aScriptURL;
 }
 
 void SfxApplication::MacroOrganizer( sal_Int16 nTabId )
 {
+#ifdef DISABLE_SCRIPTING
+    (void) nTabId;
+#else
     // get basctl dllname
-    static ::rtl::OUString aLibName( RTL_CONSTASCII_USTRINGPARAM( SVLIBRARY( "basctl" ) ) );
+    static ::rtl::OUString aLibName( SVLIBRARY( "basctl"  ) );
 
     // load module
     oslModule handleMod = osl_loadModuleRelative(
         &thisModule, aLibName.pData, 0 );
 
     // get symbol
-    ::rtl::OUString aSymbol( RTL_CONSTASCII_USTRINGPARAM( "basicide_macro_organizer" ) );
+    ::rtl::OUString aSymbol( "basicide_macro_organizer"  );
     basicide_macro_organizer pSymbol = (basicide_macro_organizer) osl_getFunctionSymbol( handleMod, aSymbol.pData );
 
     // call basicide_choose_macro in basctl
     pSymbol( nTabId );
+#endif
 }
 
 ErrCode SfxApplication::CallBasic( const String& rCode, BasicManager* pMgr, SbxArray* pArgs, SbxValue* pRet )
 {
+#ifdef DISABLE_SCRIPTING
+    (void) rCode;
+    (void) pMgr;
+    (void) pArgs;
+    (void) pRet;
+    return ERRCODE_BASIC_CANNOT_LOAD;
+#else
     return pMgr->ExecuteMacro( rCode, pArgs, pRet);
+#endif
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
