@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <boost/noncopyable.hpp>
 #include <boost/scoped_ptr.hpp>
 
@@ -34,13 +33,10 @@
 #include <svl/intitem.hxx>
 #include <svl/stritem.hxx>
 #include <svl/style.hxx>
-
-#define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <unotools/intlwrapper.hxx>
-#include <comphelper/processfactory.hxx>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
@@ -335,7 +331,7 @@ sal_Int8 DropListBox_Impl::ExecuteDrop( const ExecuteDropEvent& rEvt )
 }
 
 
-IMPL_LINK( DropListBox_Impl, OnAsyncExecuteDrop, SvLBoxEntry*, EMPTYARG )
+IMPL_LINK_NOARG(DropListBox_Impl, OnAsyncExecuteDrop)
 {
     pDialog->ActionSelect( SID_STYLE_NEW_BY_EXAMPLE );
     return 0;
@@ -431,7 +427,7 @@ void SfxTemplateDialogWrapper::SetParagraphFamily()
 }
 
 //=========================================================================
-SV_DECL_PTRARR_DEL(ExpandedEntries, StringPtr,16,8)
+SV_DECL_PTRARR_DEL(ExpandedEntries, StringPtr,16)
 SV_IMPL_PTRARR(ExpandedEntries, StringPtr)
 
 /*  [Description]
@@ -638,44 +634,44 @@ struct StyleTree_Impl
 {
     String aName;
     String aParent;
-    StyleTreeArr_Impl *pChilds;
+    StyleTreeArr_Impl *pChildren;
     sal_Bool bIsExpanded;
     sal_Bool HasParent() const { return aParent.Len() != 0; }
 
     StyleTree_Impl(const String &rName, const String &rParent):
-        aName(rName), aParent(rParent), pChilds(0), bIsExpanded(0) {}
+        aName(rName), aParent(rParent), pChildren(0), bIsExpanded(0) {}
     ~StyleTree_Impl();
     void Put(StyleTree_Impl* pIns, sal_uIntPtr lPos=ULONG_MAX);
     sal_uIntPtr Count();
 };
 
 typedef StyleTree_Impl* StyleTree_ImplPtr;
-SV_DECL_PTRARR_DEL(StyleTreeArr_Impl, StyleTree_ImplPtr, 16, 8)
+SV_DECL_PTRARR_DEL(StyleTreeArr_Impl, StyleTree_ImplPtr, 16)
 SV_IMPL_PTRARR(StyleTreeArr_Impl, StyleTree_ImplPtr)
 
 
 sal_uIntPtr StyleTree_Impl::Count()
 {
-    return pChilds ? pChilds->Count() : 0L;
+    return pChildren ? pChildren->Count() : 0L;
 }
 
 //-------------------------------------------------------------------------
 
 StyleTree_Impl::~StyleTree_Impl()
 {
-    delete pChilds;
+    delete pChildren;
 }
 
 //-------------------------------------------------------------------------
 
 void StyleTree_Impl::Put(StyleTree_Impl* pIns, sal_uIntPtr lPos)
 {
-    if ( !pChilds )
-        pChilds = new StyleTreeArr_Impl;
+    if ( !pChildren )
+        pChildren = new StyleTreeArr_Impl;
 
     if ( ULONG_MAX == lPos )
-        lPos = pChilds->Count();
-    pChilds->Insert( pIns, (sal_uInt16)lPos );
+        lPos = pChildren->Count();
+    pChildren->Insert( pIns, (sal_uInt16)lPos );
 }
 
 //-------------------------------------------------------------------------
@@ -703,7 +699,7 @@ StyleTreeArr_Impl &MakeTree_Impl(StyleTreeArr_Impl &rArr)
                     // Paste initial filter
                     sal_uInt16 nPos;
                     for( nPos = 0 ; nPos < pCmp->Count() &&
-                             aSorter.compare((*pCmp->pChilds)[nPos]->aName, pEntry->aName) < 0 ; nPos++)
+                             aSorter.compare((*pCmp->pChildren)[nPos]->aName, pEntry->aName) < 0 ; nPos++)
                     {};
                     pCmp->Put(pEntry,nPos);
                     break;
@@ -743,9 +739,9 @@ SvLBoxEntry* FillBox_Impl(SvTreeListBox *pBox,
                                  SvLBoxEntry* pParent = 0)
 {
     SvLBoxEntry* pNewEntry = pBox->InsertEntry(pEntry->aName, pParent);
-    const sal_uInt16 nCount = pEntry->pChilds? pEntry->pChilds->Count(): 0;
+    const sal_uInt16 nCount = pEntry->pChildren? pEntry->pChildren->Count(): 0;
     for(sal_uInt16 i = 0; i < nCount; ++i)
-        FillBox_Impl(pBox, (*pEntry->pChilds)[i], rEntries, pNewEntry);
+        FillBox_Impl(pBox, (*pEntry->pChildren)[i], rEntries, pNewEntry);
     return pNewEntry;
 }
 
@@ -1323,7 +1319,7 @@ void SfxCommonTemplateDialog_Impl::UpdateStyles_Impl(sal_uInt16 nFlags)
 
             SfxStyleSheetBase *pStyle = pStyleSheetPool->First();
             SvLBoxEntry* pEntry = aFmtLb.First();
-            SvStringsDtor aStrings;
+            std::vector<rtl::OUString> aStrings;
 
             comphelper::string::NaturalStringSorter aSorter(
                 ::comphelper::getProcessComponentContext(),
@@ -1332,21 +1328,19 @@ void SfxCommonTemplateDialog_Impl::UpdateStyles_Impl(sal_uInt16 nFlags)
             while( pStyle )
             {
                 //Bubblesort
-                sal_uInt16 nPos;
-                for( nPos = aStrings.Count() ; nPos &&
-                    aSorter.compare(*(aStrings[nPos-1]), pStyle->GetName()) > 0 ; nPos--)
+                size_t nPos;
+                for(nPos = aStrings.size(); nPos && aSorter.compare(aStrings[nPos-1], pStyle->GetName()) > 0; --nPos)
                 {};
-                aStrings.Insert( new String( pStyle->GetName() ), nPos );
+                aStrings.insert(aStrings.begin() + nPos, pStyle->GetName());
                 pStyle = pStyleSheetPool->Next();
             }
 
-
-            sal_uInt16 nCount = aStrings.Count();
-            sal_uInt16 nPos = 0;
-            while( nPos < nCount && pEntry &&
-                   *aStrings[ nPos ] == aFmtLb.GetEntryText( pEntry ) )
+            size_t nCount = aStrings.size();
+            size_t nPos = 0;
+            while(nPos < nCount && pEntry &&
+                  aStrings[nPos] == rtl::OUString(aFmtLb.GetEntryText(pEntry)))
             {
-                nPos++;
+                ++nPos;
                 pEntry = aFmtLb.Next( pEntry );
             }
 
@@ -1356,8 +1350,8 @@ void SfxCommonTemplateDialog_Impl::UpdateStyles_Impl(sal_uInt16 nFlags)
                 aFmtLb.SetUpdateMode(sal_False);
                 aFmtLb.Clear();
 
-                for(nPos = 0 ;  nPos < nCount ; ++nPos )
-                    aFmtLb.InsertEntry( *aStrings.GetObject( nPos ), 0, sal_False, nPos);
+                for(nPos = 0; nPos < nCount; ++nPos)
+                    aFmtLb.InsertEntry(aStrings[nPos], 0, sal_False, nPos);
 
                 aFmtLb.SetUpdateMode(true);
             }
@@ -2069,7 +2063,7 @@ void SfxCommonTemplateDialog_Impl::DeleteHdl(void *)
 
                 if ( pTreeBox )
                 {
-                    pTreeBox->RemoveParentKeepChilds( pTreeBox->FirstSelected() );
+                    pTreeBox->RemoveParentKeepChildren( pTreeBox->FirstSelected() );
                     bDontUpdate = sal_False;
                 }
             }
@@ -2547,7 +2541,7 @@ IMPL_LINK_INLINE_END( SfxTemplateDialog_Impl, ToolBoxLSelect, ToolBox *, pBox )
     {
         for( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
         {
-            if ( aPropSeq[i].Name.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "Label" ) ))
+            if ( aPropSeq[i].Name == "Label" )
             {
                 aPropSeq[i].Value >>= sRet;
                 break;
@@ -2577,12 +2571,12 @@ IMPL_LINK( SfxTemplateDialog_Impl, ToolBoxRClick, ToolBox *, pBox )
         boost::scoped_ptr<PopupMenu> pMenu(new PopupMenu);
         uno::Reference< container::XNameAccess > xNameAccess(
                     ::comphelper::getProcessServiceFactory()->
-                    createInstance( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                            "com.sun.star.frame.UICommandDescription")) ), uno::UNO_QUERY );
+                    createInstance( ::rtl::OUString(
+                            "com.sun.star.frame.UICommandDescription") ), uno::UNO_QUERY );
         uno::Reference< container::XNameAccess > xUICommands;
         if ( xNameAccess.is() )
         {
-            rtl::OUString sTextDoc(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.text.TextDocument"));
+            rtl::OUString sTextDoc("com.sun.star.text.TextDocument");
             if(xNameAccess->hasByName(sTextDoc))
             {
                 uno::Any a = xNameAccess->getByName( sTextDoc );
@@ -2594,18 +2588,18 @@ IMPL_LINK( SfxTemplateDialog_Impl, ToolBoxRClick, ToolBox *, pBox )
         try
         {
             uno::Sequence< beans::PropertyValue > aPropSeq;
-            uno::Any aCommand = xUICommands->getByName(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:StyleNewByExample")));
+            uno::Any aCommand = xUICommands->getByName(::rtl::OUString(".uno:StyleNewByExample"));
             ::rtl::OUString sLabel = lcl_GetLabel( aCommand );
             pMenu->InsertItem( SID_STYLE_NEW_BY_EXAMPLE, sLabel );
             pMenu->SetHelpId(SID_STYLE_NEW_BY_EXAMPLE, HID_TEMPLDLG_NEWBYEXAMPLE);
 
-            aCommand = xUICommands->getByName(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:StyleUpdateByExample")));
+            aCommand = xUICommands->getByName(::rtl::OUString(".uno:StyleUpdateByExample"));
             sLabel = lcl_GetLabel( aCommand );
 
             pMenu->InsertItem( SID_STYLE_UPDATE_BY_EXAMPLE, sLabel );
             pMenu->SetHelpId(SID_STYLE_UPDATE_BY_EXAMPLE, HID_TEMPLDLG_UPDATEBYEXAMPLE);
 
-            aCommand = xUICommands->getByName(::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(".uno:LoadStyles")));
+            aCommand = xUICommands->getByName(::rtl::OUString(".uno:LoadStyles"));
             sLabel = lcl_GetLabel( aCommand );
             pMenu->InsertItem( SID_TEMPLATE_LOAD, sLabel );
             pMenu->SetHelpId(SID_TEMPLATE_LOAD, ".uno:LoadStyles");
@@ -2807,7 +2801,7 @@ sal_Bool SfxTemplateCatalog_Impl::IsCheckedItem(sal_uInt16 nMesId)
     sal_uInt16 i;
     for ( i = 0; i < aFamIds.size() && aFamIds[i] != nMesId; i++ )
         ;
-    return aFamList.IsEntrySelected( String::CreateFromInt32(i) );
+    return aFamList.IsEntrySelected( rtl::OUString::valueOf(static_cast<sal_Int32>(i)) );
 }
 
 //-------------------------------------------------------------------------
