@@ -26,8 +26,8 @@
  *
  ************************************************************************/
 
+#include <comphelper/string.hxx>
 #include <sfx2/new.hxx>
-#include <vcl/gdimtf.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/morebtn.hxx>
 #include <svtools/svmedit.hxx>
@@ -40,24 +40,13 @@
 
 #include "new.hrc"
 #include "doc.hrc"
-#include <sfx2/sfx.hrc>
-#include "helpid.hrc"
-#include "sfxtypes.hxx"
 #include <sfx2/app.hxx>
-#include <sfx2/viewfrm.hxx>
-#include <sfx2/docfac.hxx>
 #include <sfx2/objsh.hxx>
-#include "fltfnc.hxx"
-#include <sfx2/viewsh.hxx>
-#include "sfx2/viewfac.hxx"
 #include "sfx2/sfxresid.hxx"
 #include <sfx2/docfile.hxx>
 #include "preview.hxx"
 #include <sfx2/printer.hxx>
 #include <vcl/waitobj.hxx>
-#include <vcl/virdev.hxx>
-#include <vcl/jobset.hxx>
-#include <svtools/accessibilityoptions.hxx>
 
 // Draw modes
 #define OUTPUT_DRAWMODE_COLOR       (DRAWMODE_DEFAULT)
@@ -189,12 +178,12 @@ class SfxNewFileDialog_Impl
     DECL_LINK( Update, void * );
 
     DECL_LINK( RegionSelect, ListBox * );
-    DECL_LINK( TemplateSelect, ListBox * );
+    DECL_LINK(TemplateSelect, void *);
     DECL_LINK( DoubleClick, ListBox * );
     void TogglePreview(CheckBox *);
-    DECL_LINK( Expand, MoreButton * );
+    DECL_LINK( Expand, void * );
     DECL_LINK( PreviewClick, CheckBox * );
-    DECL_LINK( LoadFile, PushButton* );
+    DECL_LINK(LoadFile, void *);
     sal_uInt16  GetSelectedTemplatePos() const;
 
 public:
@@ -226,7 +215,7 @@ void SfxNewFileDialog_Impl::ClearInfo()
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK( SfxNewFileDialog_Impl, Update, void *, EMPTYARG )
+IMPL_LINK_NOARG(SfxNewFileDialog_Impl, Update)
 {
     if ( xDocShell.Is() )
     {
@@ -253,7 +242,7 @@ IMPL_LINK( SfxNewFileDialog_Impl, Update, void *, EMPTYARG )
         {
             // temp. fix until Templates are managed by UCB compatible service
             // does NOT work with locally cached components !
-            String aTemp;
+            rtl::OUString aTemp;
             utl::LocalFileHelper::ConvertPhysicalNameToURL( aFileName, aTemp );
             aFileName = aTemp;
         }
@@ -328,12 +317,12 @@ IMPL_LINK( SfxNewFileDialog_Impl, RegionSelect, ListBox *, pBox )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK_INLINE_START( SfxNewFileDialog_Impl, Expand, MoreButton *, EMPTYARG )
+IMPL_LINK_NOARG_INLINE_START(SfxNewFileDialog_Impl, Expand)
 {
     TemplateSelect(&aTemplateLb);
     return 0;
 }
-IMPL_LINK_INLINE_END( SfxNewFileDialog_Impl, Expand, MoreButton *, pMoreButton )
+IMPL_LINK_NOARG_INLINE_END(SfxNewFileDialog_Impl, Expand)
 
 //-------------------------------------------------------------------------
 
@@ -359,7 +348,7 @@ IMPL_LINK( SfxNewFileDialog_Impl, PreviewClick, CheckBox *, pBox )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK( SfxNewFileDialog_Impl, TemplateSelect, ListBox *, EMPTYARG )
+IMPL_LINK_NOARG(SfxNewFileDialog_Impl, TemplateSelect)
 {
     // Still loading
     if ( xDocShell && xDocShell->GetProgress() )
@@ -387,12 +376,12 @@ IMPL_LINK_INLINE_END( SfxNewFileDialog_Impl, DoubleClick, ListBox *, pListBox )
 
 //-------------------------------------------------------------------------
 
-IMPL_LINK_INLINE_START( SfxNewFileDialog_Impl, LoadFile, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG_INLINE_START(SfxNewFileDialog_Impl, LoadFile)
 {
     pAntiImpl->EndDialog(RET_TEMPLATE_LOAD);
     return 0;
 }
-IMPL_LINK_INLINE_END( SfxNewFileDialog_Impl, LoadFile, PushButton *, EMPTYARG )
+IMPL_LINK_NOARG_INLINE_END(SfxNewFileDialog_Impl, LoadFile)
 //-------------------------------------------------------------------------
 
 sal_uInt16  SfxNewFileDialog_Impl::GetSelectedTemplatePos() const
@@ -550,7 +539,7 @@ SfxNewFileDialog_Impl::SfxNewFileDialog_Impl(
     }
 
     String &rExtra = pAntiImplP->GetExtraData();
-    sal_uInt16 nTokCount = rExtra.GetTokenCount( '|' );
+    sal_Int32 nTokCount = comphelper::string::getTokenCount(rExtra, '|');
     if( nTokCount > 0 && nFlags )
         MORE_BTN(SetState( rExtra.GetToken( 0, '|' ) == 'Y' ));
     if( nTokCount > 1 && nFlags )
