@@ -65,7 +65,6 @@
 #include <sfx2/fcontnr.hxx>
 #include "impframe.hxx"
 #include <sfx2/appuno.hxx>
-#include <sfx2/viewfrm.hxx>
 #include "workwin.hxx"
 #include <sfx2/sfxuno.hxx>
 #include <sfx2/msgpool.hxx>
@@ -496,11 +495,6 @@ void SfxFrame::GetTargetList( TargetList& rList ) const
 
 //-------------------------------------------------------------------------
 
-SfxBroadcaster& SfxFrame::GetBroadcaster() const
-{
-    return *pImp;
-}
-
 sal_Bool SfxFrame::IsParent( SfxFrame *pFrame ) const
 {
     SfxFrame *pParent = pParentFrame;
@@ -703,11 +697,6 @@ SfxFrame* SfxFrameIterator::NextSibling_Impl( SfxFrame& rPrev )
     return pRet;
 }
 
-sal_Bool SfxFrame::IsTop() const
-{
-    return GetFrameInterface().is() ? GetFrameInterface()->isTop() : sal_False;
-}
-
 sal_Bool SfxFrame::HasComponent() const
 {
     return sal_False;
@@ -917,8 +906,8 @@ void SfxFrame::Resize()
 
             if ( pWork )
             {
-                pWork->ArrangeChilds_Impl();
-                pWork->ShowChilds_Impl();
+                pWork->ArrangeChildren_Impl();
+                pWork->ShowChildren_Impl();
             }
 
             // problem in presence of UIActive object: when the window is resized, but the toolspace border
