@@ -659,7 +659,7 @@ void SvxRectCtl::SetState( CTL_STATE nState )
         ( (SvxTabPage*) GetParent() )->PointChanged( this, eRP );
 }
 
-sal_uInt8 SvxRectCtl::GetNumOfChilds( void ) const
+sal_uInt8 SvxRectCtl::GetNumOfChildren( void ) const
 {
     return ( eCS == CS_ANGLE )? 8 : 9;
 }
@@ -722,93 +722,6 @@ void SvxRectCtl::DoCompletelyDisable(sal_Bool bNew)
     Invalidate();
 }
 
-// Constructor without the size parameter
-
-SvxAngleCtl::SvxAngleCtl( Window* pParent, const ResId& rResId ) :
-
-    SvxRectCtl( pParent, rResId ),
-
-    aFont( Application::GetSettings().GetStyleSettings().GetAppFont() )
-{
-    aFontSize = Size( 250, 400 );
-    Initialize();
-}
-
-// Constructor with the size parameter
-
-SvxAngleCtl::SvxAngleCtl( Window* pParent, const ResId& rResId, Size _aSize ) :
-
-    SvxRectCtl( pParent, rResId ),
-
-    aFont( Application::GetSettings().GetStyleSettings().GetAppFont() )
-{
-    aFontSize = _aSize;
-    Initialize();
-}
-
-void SvxAngleCtl::Initialize()
-{
-    bPositive = sal_True;
-
-    aFont.SetSize( aFontSize );
-    aFont.SetWeight( WEIGHT_NORMAL );
-    aFont.SetTransparent( sal_False );
-
-    SetFont( aFont );
-}
-
-// Draws the (mini) coordinate system
-
-void SvxAngleCtl::Paint( const Rectangle& )
-{
-    SetLineColor( Color( COL_BLACK ) );     // PEN_DOT ???
-    DrawLine( aPtLT - Point( 0, 0), aPtRB + Point( 0, 0 ) );
-    DrawLine( aPtLB - Point( 0, 0), aPtRT + Point( 0, 0 ) );
-
-    SetLineColor( Color( COL_BLACK ) );
-    DrawLine( aPtLM - Point( 0, 0), aPtRM + Point( 0, 0 ) );
-    DrawLine( aPtMT - Point( 0, 0), aPtMB + Point( 0, 0 ) );
-
-    Point aDiff(aFontSize.Width() / 2, aFontSize.Height() / 2);
-
-    DrawText( aPtLT - aDiff, UniString::CreateFromAscii(
-                             RTL_CONSTASCII_STRINGPARAM( "135" ) ) );
-    DrawText( aPtLM - aDiff, UniString::CreateFromAscii(
-                             RTL_CONSTASCII_STRINGPARAM( "180" ) ) );
-
-    if ( bPositive )
-        DrawText( aPtLB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "225" ) ) );
-    else
-        DrawText( aPtLB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "-135" ) ) );
-
-    aDiff.X() = aFontSize.Width();
-    DrawText( aPtMT - aDiff, UniString::CreateFromAscii(
-                             RTL_CONSTASCII_STRINGPARAM( "90" ) ) );
-    DrawText( aPtRT - aDiff, UniString::CreateFromAscii(
-                             RTL_CONSTASCII_STRINGPARAM( "45" ) ) );
-    aDiff.X() = aDiff .X() * 3 / 2;
-
-    if ( bPositive )
-        DrawText( aPtMB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "270" ) ) );
-    else
-        DrawText( aPtMB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "-90" ) ) );
-
-    DrawText( aPtRM - Point( 0, aDiff.Y() ), UniString::CreateFromAscii(
-                                             RTL_CONSTASCII_STRINGPARAM( "0" ) ) );
-    aDiff.X() = aFontSize.Width() * 2;
-
-    if ( bPositive )
-        DrawText( aPtRB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "315" ) ) );
-    else
-        DrawText( aPtRB - aDiff, UniString::CreateFromAscii(
-                                 RTL_CONSTASCII_STRINGPARAM( "-45" ) ) );
-}
-
 // Control for editing bitmaps
 
 SvxPixelCtl::SvxPixelCtl( Window* pParent, const ResId& rResId, sal_uInt16 nNumber ) :
