@@ -33,7 +33,6 @@
 
 #include <comphelper/accessiblewrapper.hxx>
 #include <osl/mutex.hxx>
-#include <tools/debug.hxx>
 #include <vcl/svapp.hxx>
 
 #include <svx/AccessibleTableShape.hxx>
@@ -334,7 +333,7 @@ OUString SAL_CALL AccessibleTableShape::getImplementationName(void) throw (Runti
 
 OUString AccessibleTableShape::CreateAccessibleBaseName(void) throw (RuntimeException)
 {
-    return OUString (RTL_CONSTASCII_USTRINGPARAM("TableShape"));;
+    return OUString (RTL_CONSTASCII_USTRINGPARAM("TableShape"));
 }
 
 //--------------------------------------------------------------------
