@@ -36,7 +36,6 @@
 #include <comphelper/processfactory.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <unotools/streamwrap.hxx>
-#include <tools/debug.hxx>
 #include "comphelper/anytostring.hxx"
 #include "cppuhelper/exc_hlp.hxx"
 #include "rtl/ref.hxx"
@@ -99,28 +98,28 @@ void ConfigHandler::errorThrow( const OUString& rErrorMessage ) throw (SAXExcept
 
 ElementConfigType ConfigHandler::parseType( const OUString& sType ) throw (SAXException )
 {
-    if( sType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("uint") ) )
+    if ( sType == "uint" )
     {
         return ECT_UINT;
     }
-    else if( sType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("byte") ) )
+    else if ( sType == "byte" )
     {
         return ECT_BYTE;
     }
-    else if( sType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("unistring") ) )
+    else if ( sType == "unistring" )
     {
         return ECT_UNISTRING;
     }
-    else if( sType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("float") ) )
+    else if ( sType == "float" )
     {
         return ETC_FLOAT;
     }
-    else if( sType.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("hexdump") ) )
+    else if ( sType == "hexdump" )
     {
     }
     else
     {
-        OUString aMessage( RTL_CONSTASCII_USTRINGPARAM( "unknown type: " ) );
+        OUString aMessage( "unknown type: "  );
         aMessage += sType;
         errorThrow( aMessage );
     }
@@ -133,7 +132,7 @@ void ConfigHandler::addElement( ElementConfigPtr& rElementConfig ) throw ( SAXEx
     ElementConfigContainer* pParent = dynamic_cast< ElementConfigContainer* >( maElementStack.top().get() );
 
     if( !pParent )
-        errorThrow( OUString( RTL_CONSTASCII_USTRINGPARAM( "illegal parent for element" ) ) );
+        errorThrow( OUString( "illegal parent for element"  ) );
 
 
     pParent->addElementConfig( rElementConfig );
@@ -151,7 +150,7 @@ OUString ConfigHandler::getAttribute( const Reference< XAttributeList > & xAttri
             return xAttribs->getValueByIndex( i );
     }
 
-    OUString aMessage( RTL_CONSTASCII_USTRINGPARAM( "missing required attribute: ") );
+    OUString aMessage( "missing required attribute: " );
     aMessage += aName;
     errorThrow( aMessage );
 
@@ -170,39 +169,39 @@ void SAL_CALL ConfigHandler::startElement(const OUString& aName, const Reference
 {
     ElementConfigPtr pElement;
 
-    if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "config" ) ) )
+    if ( aName == "config" )
     {
         return;
     }
 
-    if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "container" ) ) )
+    if ( aName == "container" )
     {
         pElement = importAtomConfig( xAttribs, true );
     }
-    else if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "atom" ) ) )
+    else if ( aName == "atom" )
     {
         pElement = importAtomConfig( xAttribs, false );
     }
-    else if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "element" ) ) )
+    else if ( aName == "element" )
     {
         pElement = importElementConfig( xAttribs );
     }
-    else if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "value" ) ) )
+    else if ( aName == "value" )
     {
         pElement = importValueElementConfig( xAttribs );
     }
-    else if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "switch" ) ) )
+    else if ( aName == "switch" )
     {
         pElement = importSwitchConfig( xAttribs );
     }
-    else if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "case" ) ) )
+    else if ( aName == "case" )
     {
         pElement = importCaseConfig( xAttribs );
     }
 
     if( !pElement.get() )
     {
-        OUString aMessage( OUString( RTL_CONSTASCII_USTRINGPARAM("unknown config element: ")) );
+        OUString aMessage( OUString( "unknown config element: ") );
         aMessage += aName;
         errorThrow( aMessage  );
     }
@@ -247,7 +246,7 @@ sal_Int32 toInt( const OUString& rText )
 ElementConfigPtr ConfigHandler::importAtomConfig( const Reference< XAttributeList > & xAttribs, bool bIsContainer ) throw (SAXException)
 {
     if( !maElementStack.empty() )
-        errorThrow( OUString( RTL_CONSTASCII_USTRINGPARAM("atom elements must be root" ) ) );
+        errorThrow( OUString( "atom elements must be root"  ) );
 
     ElementConfigPtr aPtr( new AtomConfig( getAttribute(xAttribs,"name"), bIsContainer ) );
     gAtomConfigMap[ (UINT16)toInt(getAttribute(xAttribs,"id"))] = aPtr;
@@ -286,7 +285,7 @@ ElementConfigPtr ConfigHandler::importCaseConfig( const Reference< XAttributeLis
 
 void SAL_CALL ConfigHandler::endElement(const OUString& aName) throw( SAXException, RuntimeException )
 {
-    if( aName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "config" ) ) )
+    if ( aName == "config" )
     {
         return;
     }
@@ -326,7 +325,7 @@ void load_config( const OUString& rPath )
         // get parser
         Reference< XParser > xParser(
             comphelper::getProcessServiceFactory()->createInstance(
-                OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.xml.sax.Parser")) ),
+                OUString("com.sun.star.xml.sax.Parser") ),
             UNO_QUERY_THROW );
 
         // get filter
@@ -339,7 +338,7 @@ void load_config( const OUString& rPath )
         // finally, parser the stream
         xParser->parseStream( aParserInput );
     }
-    catch( Exception& r )
+    catch( Exception& )
     {
         OSL_FAIL(
             (rtl::OString("load_config(), "
@@ -347,8 +346,6 @@ void load_config( const OUString& rPath )
              rtl::OUStringToOString(
                  comphelper::anyToString( cppu::getCaughtException() ),
                  RTL_TEXTENCODING_UTF8 )).getStr() );
-
-        (void)r;
     }
 }
 
@@ -360,7 +357,7 @@ rtl::OUString ElementConfig::format( SvStream& rStream, sal_Size& nLength ) cons
     if( maName.getLength() )
     {
         aRet += maName;
-        aRet += OUString( RTL_CONSTASCII_USTRINGPARAM( " = " ) );
+        aRet += OUString( " = "  );
     }
 
     switch( mnType )
@@ -402,10 +399,10 @@ rtl::OUString ElementConfig::dump_hex( SvStream& rStream, sal_Size& nLength )
         if( (nRow == 16) || (nLength==0) )
         {
             while( aHex.getLength() < (16*3) )
-                aHex += OUString( RTL_CONSTASCII_USTRINGPARAM(" ") );
+                aHex += OUString( " " );
             aOut += aHex;
             aOut += aAscii;
-            aOut += OUString( RTL_CONSTASCII_USTRINGPARAM( "\n\r" ) );
+            aOut += OUString( "\n\r"  );
             aHex = aEmpty;
             aAscii = aEmpty;
             nRow = 0;
@@ -454,8 +451,7 @@ rtl::OUString ElementConfig::dump_uint( SvStream& rStream, sal_Size& nLength )
 
 rtl::OUString ElementConfig::dump_unistring( SvStream& rStream, sal_Size& nLength )
 {
-    String aString;
-    SvxMSDffManager::MSDFFReadZString( rStream, aString, nLength, sal_True );
+    String aString = SvxMSDffManager::MSDFFReadZString( rStream, nLength, sal_True );
     nLength = 0;
     return aString;
 }
@@ -492,7 +488,7 @@ rtl::OUString ElementConfigContainer::format( SvStream& rStream, sal_Size& nLeng
         {
             aRet += (*aIter++)->format( rStream, nLength );
             if( (aIter != aEnd) || (nLength != 0) )
-                aRet += OUString( RTL_CONSTASCII_USTRINGPARAM( "\n\r" ) );
+                aRet += OUString( "\n\r"  );
         }
 
         if( nLength )
@@ -502,7 +498,7 @@ rtl::OUString ElementConfigContainer::format( SvStream& rStream, sal_Size& nLeng
     {
         aRet = getName();
         if( aRet.getLength() )
-            aRet += OUString( RTL_CONSTASCII_USTRINGPARAM( " = " ) );
+            aRet += OUString( " = "  );
 
         OUString aValue;
         switch( getType() )
@@ -534,7 +530,7 @@ rtl::OUString ElementConfigContainer::format( SvStream& rStream, sal_Size& nLeng
         }
         else
         {
-            aValue = OUString( RTL_CONSTASCII_USTRINGPARAM("<empty!?>") );
+            aValue = OUString( "<empty!?>" );
         }
 
         aRet += aValue;
