@@ -30,6 +30,7 @@
 #include <algorithm>
 #include <functional>
 #include <SwNumberTree.hxx>
+#include <osl/diagnose.h>
 
 using std::vector;
 using std::find;
@@ -357,7 +358,7 @@ SwNumberTreeNode * SwNumberTreeNode::GetFirstNonPhantomChild()
 void SwNumberTreeNode::MoveGreaterChildren( SwNumberTreeNode& _rCompareNode,
                                             SwNumberTreeNode& _rDestNode )
 {
-    if ( mChildren.size() == 0 )
+    if ( mChildren.empty() )
         return;
 
     // determine first child, which has to move to <_rDestNode>
@@ -457,7 +458,7 @@ void SwNumberTreeNode::AddChild( SwNumberTreeNode * pChild,
        Algorithm:
 
        Search first child A that is greater than pChild,
-         A may be the end of childs.
+         A may be the end of children.
        If nDepth > 0 then
        {
           if A is first child then
@@ -833,7 +834,7 @@ bool SwNumberTreeNode::IsFirst() const
 
             // If node isn't the first child, it is the second child and the
             // first child is a phanton. In this case check, if the first phantom
-            // child have only phanton childs
+            // child have only phanton children
             if ( bResult &&
                  this != *(GetParent()->mChildren.begin()) &&
                  !(*(GetParent()->mChildren.begin()))->HasOnlyPhantoms() )
