@@ -664,7 +664,7 @@ sal_Bool SwCrsrShell::MoveFldType( const SwFieldType* pFldType, sal_Bool bNext,
         {
             // es gibt noch versteckte InputFelder in den SetExp. Feldern
             const SwFldTypes& rFldTypes = *pDoc->GetFldTypes();
-            const sal_uInt16 nSize = rFldTypes.Count();
+            const sal_uInt16 nSize = rFldTypes.size();
 
             // Alle Typen abklappern
             for( sal_uInt16 i=0; i < nSize; ++i )
@@ -676,7 +676,7 @@ sal_Bool SwCrsrShell::MoveFldType( const SwFieldType* pFldType, sal_Bool bNext,
     else
     {
         const SwFldTypes& rFldTypes = *pDoc->GetFldTypes();
-        const sal_uInt16 nSize = rFldTypes.Count();
+        const sal_uInt16 nSize = rFldTypes.size();
 
         // Alle Typen abklappern
         for( sal_uInt16 i=0; i < nSize; ++i )
@@ -710,7 +710,8 @@ sal_Bool SwCrsrShell::MoveFldType( const SwFieldType* pFldType, sal_Bool bNext,
             SwFmtFld* pFmtFld = new SwFmtFld( SwDateTimeField(
                 (SwDateTimeFieldType*)pDoc->GetSysFldType( RES_DATETIMEFLD ) ) );
 
-            pTxtFld = new SwTxtFld( *pFmtFld, rPos.nContent.GetIndex() );
+            pTxtFld = new SwTxtFld( *pFmtFld, rPos.nContent.GetIndex(),
+                        pDoc->IsClipBoard() );
             pTxtFld->ChgTxtNode( pTNd );
         }
 
@@ -903,7 +904,7 @@ sal_uInt16 SwCrsrShell::GetOutlinePos( sal_uInt8 nLevel )
 
 
 sal_Bool SwCrsrShell::MakeOutlineSel( sal_uInt16 nSttPos, sal_uInt16 nEndPos,
-                                    sal_Bool bWithChilds )
+                                    sal_Bool bWithChildren )
 {
     const SwNodes& rNds = GetDoc()->GetNodes();
     const SwOutlineNodes& rOutlNds = rNds.GetOutLineNds();
@@ -924,7 +925,7 @@ sal_Bool SwCrsrShell::MakeOutlineSel( sal_uInt16 nSttPos, sal_uInt16 nEndPos,
     SwNode* pSttNd = rOutlNds[ nSttPos ];
     SwNode* pEndNd = rOutlNds[ nEndPos ];
 
-    if( bWithChilds )
+    if( bWithChildren )
     {
         const int nLevel = pEndNd->GetTxtNode()->GetAttrOutlineLevel()-1;//<-end.zhaojianwei
         for( ++nEndPos; nEndPos < rOutlNds.Count(); ++nEndPos )
@@ -935,7 +936,7 @@ sal_Bool SwCrsrShell::MakeOutlineSel( sal_uInt16 nSttPos, sal_uInt16 nEndPos,
                 break;          // EndPos steht jetzt auf dem naechsten
         }
     }
-    // ohne Childs, dann aber zumindest auf den naechsten
+    // ohne Children, dann aber zumindest auf den naechsten
     else if( ++nEndPos < rOutlNds.Count() )
         pEndNd = rOutlNds[ nEndPos ];
 
@@ -1030,7 +1031,7 @@ sal_Bool SwCrsrShell::GetContentAtPos( const Point& rPt,
             if( pONd )
             {
                 rCntntAtPos.eCntntAtPos = SwContentAtPos::SW_OUTLINE;
-                rCntntAtPos.sStr = pONd->GetExpandTxt( 0, STRING_LEN, true );
+                rCntntAtPos.sStr = pONd->GetExpandTxt( 0, STRING_LEN, true, true );
                 bRet = sal_True;
             }
         }
