@@ -27,12 +27,7 @@
  ************************************************************************/
 
 
-
-
-
-#define _SVSTDARR_STRINGS
 #include <rsc/rscsfx.hxx>
-#include <tools/urlobj.hxx>
 #include <com/sun/star/embed/XStorage.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <comphelper/processfactory.hxx>
@@ -51,7 +46,6 @@
 #include <com/sun/star/packages/zip/ZipIOException.hpp>
 #include <com/sun/star/packages/WrongPasswordException.hpp>
 #include <com/sun/star/ucb/InteractiveAugmentedIOException.hpp>
-#include <svl/svstdarr.hxx>
 #include <sfx2/docfile.hxx>
 #include <svtools/sfxecode.hxx>
 #include <svl/stritem.hxx>
@@ -253,7 +247,7 @@ sal_Int32 ReadThroughComponent(
                              ERRCODE_BUTTON_OK | ERRCODE_MSG_ERROR );
         }
     }
-    catch( xml::sax::SAXException& r)
+    catch(const xml::sax::SAXException& r)
     {
         packages::zip::ZipIOException aBrokenPackage;
         if ( r.WrappedException >>= aBrokenPackage )
@@ -272,7 +266,7 @@ sal_Int32 ReadThroughComponent(
 
         return ERR_SWG_READ_ERROR;
     }
-    catch( packages::zip::ZipIOException& r)
+    catch(const packages::zip::ZipIOException& r)
     {
         (void)r;
 #if OSL_DEBUG_LEVEL > 0
@@ -284,7 +278,7 @@ sal_Int32 ReadThroughComponent(
 #endif
         return ERRCODE_IO_BROKENPACKAGE;
     }
-    catch( io::IOException& r)
+    catch(const io::IOException& r)
     {
         (void)r;
 #if OSL_DEBUG_LEVEL > 0
@@ -296,7 +290,7 @@ sal_Int32 ReadThroughComponent(
 #endif
         return ERR_SWG_READ_ERROR;
     }
-    catch( uno::Exception& r)
+    catch(const uno::Exception& r)
     {
         (void)r;
 #if OSL_DEBUG_LEVEL > 0
@@ -837,7 +831,7 @@ sal_uLong XMLReader::Read( SwDoc &rDoc, const String& rBaseURL, SwPaM &rPaM, con
             StreamPath = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("dummyObjectName"));
         }
 
-        if( StreamPath.getLength() )
+        if( !StreamPath.isEmpty() )
         {
             sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("StreamRelPath"));
             xInfoSet->setPropertyValue( sPropName, makeAny( StreamPath ) );
@@ -897,7 +891,7 @@ sal_uLong XMLReader::Read( SwDoc &rDoc, const String& rBaseURL, SwPaM &rPaM, con
                 pDocSh->GetMedium()->GetInteractionHandler() );
             xDMA->loadMetadataFromStorage(xStorage, xBaseURI, xHandler);
         }
-        catch (lang::WrappedTargetException & e)
+        catch (const lang::WrappedTargetException & e)
         {
             ucb::InteractiveAugmentedIOException iaioe;
             if (e.TargetException >>= iaioe)
@@ -1067,8 +1061,8 @@ sal_uLong XMLReader::Read( SwDoc &rDoc, const String& rBaseURL, SwPaM &rPaM, con
 
     // read the sections of the document, which is equal to the medium.
     // returns the count of it
-sal_uInt16 XMLReader::GetSectionList( SfxMedium& rMedium,
-                                    SvStrings& rStrings ) const
+size_t XMLReader::GetSectionList( SfxMedium& rMedium,
+                                  std::vector<String*>& rStrings ) const
 {
     uno::Reference< lang::XMultiServiceFactory > xServiceFactory =
             comphelper::getProcessServiceFactory();
@@ -1095,7 +1089,6 @@ sal_uInt16 XMLReader::GetSectionList( SfxMedium& rMedium,
             if( xXMLParser.is() )
             {
                 // get filter
-                // uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLSectionList( rStrings );
                 uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLSectionList( xServiceFactory, rStrings );
 
                 // connect parser and filter
@@ -1123,7 +1116,7 @@ sal_uInt16 XMLReader::GetSectionList( SfxMedium& rMedium,
             // re throw ?
         }
     }
-    return rStrings.Count();
+    return rStrings.size();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
