@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <sot/clsids.hxx>
 #include <com/sun/star/embed/XEmbedObjectCreator.hpp>
 #include <com/sun/star/embed/XEmbeddedObject.hpp>
@@ -50,16 +49,13 @@
 #include <ndgrf.hxx>
 #include "xmlexp.hxx"
 #include "xmltexte.hxx"
-#include <tools/urlobj.hxx>
 #include <SwAppletImpl.hxx>
 
-#define _SVSTDARR_ULONGS
 #include <svl/svstdarr.hxx>
 #include "svl/urihelper.hxx"
 #include <sfx2/frmdescr.hxx>
 #include <SwStyleNameMapper.hxx>
 
-
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
 using namespace ::com::sun::star;
@@ -82,8 +78,6 @@ enum SvEmbeddedObjectTypes
     SV_EMBEDDED_FRAME
 };
 
-const sal_Char sObjectReplacements[] = "ObjectReplacements/";
-
 // ---------------------------------------------------------------------
 
 SwNoTxtNode *SwXMLTextParagraphExport::GetNoTxtNode(
@@ -171,7 +165,7 @@ void SwXMLTextParagraphExport::exportStyleContent(
                     sBuffer.append( GetXMLToken(eFunc) );
                     sBuffer.append( (sal_Unicode)'(' );
                     sBuffer.append( (sal_Unicode)')' );
-                    if( sVal.getLength() )
+                    if( !sVal.isEmpty() )
                     {
                         sBuffer.append( (sal_Unicode)'=' );
                         sBuffer.append( sVal );
@@ -219,7 +213,7 @@ void SwXMLTextParagraphExport::setTextEmbeddedGraphicURL(
     const Reference < XPropertySet >& rPropSet,
     OUString& rURL) const
 {
-    if( !rURL.getLength() )
+    if( rURL.isEmpty() )
         return;
 
     SwGrfNode *pGrfNd = GetNoTxtNode( rPropSet )->GetGrfNode();
@@ -227,7 +221,9 @@ void SwXMLTextParagraphExport::setTextEmbeddedGraphicURL(
     {
         String aNewURL( RTL_CONSTASCII_USTRINGPARAM("vnd.sun.star.Package:") );
         aNewURL += String(rURL);
-        pGrfNd->SetNewStreamName( aNewURL );
+
+// This is nonsensical.
+//        pGrfNd->SetNewStreamName( aNewURL );
 
         // #i15411# save-as will swap all graphics in; we need to swap
         // them out again, to prevent excessive memory use
@@ -479,7 +475,7 @@ void SwXMLTextParagraphExport::_exportTextEmbedded(
         pStates++;
     }
 
-    if( sAutoStyle.getLength() )
+    if( !sAutoStyle.isEmpty() )
         rXMLExport.AddAttribute( XML_NAMESPACE_DRAW, XML_STYLE_NAME, sAutoStyle );
     addTextFrameAttributes( rPropSet, sal_False );
 
@@ -567,12 +563,12 @@ void SwXMLTextParagraphExport::_exportTextEmbedded(
                 ::rtl::OUString aStr;
                 Any aAny2 = xSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("AppletCodeBase")) );
                 aAny2 >>= aStr;
-                if (aStr.getLength() )
+                if (!aStr.isEmpty() )
                     lcl_addURL(rXMLExport, aStr);
 
                 aAny2 = xSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("AppletName")) );
                 aAny2 >>= aStr;
-                if (aStr.getLength())
+                if (!aStr.isEmpty())
                     rXMLExport.AddAttribute( XML_NAMESPACE_DRAW, XML_APPLET_NAME, aStr );
 
                 aAny2 = xSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("AppletCode")) );
@@ -618,7 +614,7 @@ void SwXMLTextParagraphExport::_exportTextEmbedded(
 
                 aAny2 = xSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PluginMimeType")) );
                 aAny2 >>= aStr;
-                if (aStr.getLength())
+                if (!aStr.isEmpty())
                     rXMLExport.AddAttribute( XML_NAMESPACE_DRAW, XML_MIME_TYPE, aStr );
                 eElementName = XML_PLUGIN;
             }
@@ -639,7 +635,7 @@ void SwXMLTextParagraphExport::_exportTextEmbedded(
                 aAny2 = xSet->getPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FrameName")) );
                 aAny2 >>= aStr;
 
-                if (aStr.getLength())
+                if (!aStr.isEmpty())
                     rXMLExport.AddAttribute( XML_NAMESPACE_DRAW, XML_FRAME_NAME, aStr );
                 eElementName = XML_FLOATING_FRAME;
             }
