@@ -43,6 +43,7 @@
 #include <comphelper/processfactory.hxx>
 #include <comphelper/types.hxx>
 #include <com/sun/star/sdb/CommandType.hpp>
+#include <rtl/instance.hxx>
 #include <unotools/configitem.hxx>
 #include <mailmergehelper.hxx>
 #include <swunohelper.hxx>
@@ -51,10 +52,7 @@
 #include <wrtsh.hxx>
 #include <dbui.hrc>
 #include <vector>
-
 #include <unomid.h>
-
-#define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
 
 using namespace utl;
@@ -604,7 +602,7 @@ void  SwMailMergeConfigItem_Impl::Commit()
         if(aAssignIter->bColumnAssignmentsChanged)
         {
             //create a new node name
-            OUString sNewNode = aAssignIter->sConfigNodeName.getLength() ?
+            OUString sNewNode = !aAssignIter->sConfigNodeName.isEmpty() ?
                         aAssignIter->sConfigNodeName :
                         lcl_CreateNodeName(aAssignments);
             OUString sSlash = C2U("/");
@@ -739,9 +737,13 @@ void SwMailMergeConfigItem_Impl::SetCurrentGreeting(
         SetModified();
 }
 
-static SwMailMergeConfigItem_Impl* pOptions = NULL;
-static sal_Int32            nRefCount = 0;
-static ::osl::Mutex aMutex;
+namespace
+{
+    static SwMailMergeConfigItem_Impl* pOptions = NULL;
+    static sal_Int32            nRefCount = 0;
+
+    class theMailMergeConfigMutex : public rtl::Static<osl::Mutex, theMailMergeConfigMutex> {};
+}
 
 SwMailMergeConfigItem::SwMailMergeConfigItem() :
     m_bAddressInserted(false),
@@ -754,7 +756,7 @@ SwMailMergeConfigItem::SwMailMergeConfigItem() :
     m_pTargetView(0)
 {
     // Global access, must be guarded (multithreading)
-    ::osl::MutexGuard aGuard( aMutex );
+    ::osl::MutexGuard aGuard( theMailMergeConfigMutex::get() );
     if ( !pOptions )
         pOptions = new SwMailMergeConfigItem_Impl;
     ++nRefCount;
@@ -764,7 +766,7 @@ SwMailMergeConfigItem::SwMailMergeConfigItem() :
 SwMailMergeConfigItem::~SwMailMergeConfigItem()
 {
     // Global access, must be guarded (multithreading)
-    ::osl::MutexGuard aGuard( aMutex );
+    ::osl::MutexGuard aGuard( theMailMergeConfigMutex::get() );
     if ( !--nRefCount )
     {
         DELETEZ( pOptions );
@@ -899,7 +901,7 @@ void SwMailMergeConfigItem::SetCurrentDBData( const SwDBData& rDBData)
 
 Reference< XResultSet>   SwMailMergeConfigItem::GetResultSet() const
 {
-    if(!m_pImpl->xConnection.is() && m_pImpl->aDBData.sDataSource.getLength())
+    if(!m_pImpl->xConnection.is() && !m_pImpl->aDBData.sDataSource.isEmpty())
     {
         m_pImpl->xConnection.reset(
             SwNewDBMgr::GetConnection( m_pImpl->aDBData.sDataSource, m_pImpl->xSource ),
@@ -923,7 +925,7 @@ Reference< XResultSet>   SwMailMergeConfigItem::GetResultSet() const
                 xRowProperties->setPropertyValue(C2U("ActiveConnection"), makeAny(m_pImpl->xConnection.getTyped()));
                 try
                 {
-                    xRowProperties->setPropertyValue(C2U("ApplyFilter"), makeAny(m_pImpl->sFilter.getLength()>0));
+                    xRowProperties->setPropertyValue(C2U("ApplyFilter"), makeAny(!m_pImpl->sFilter.isEmpty()));
                     xRowProperties->setPropertyValue(C2U("Filter"), makeAny(m_pImpl->sFilter));
                 }
                 catch (const Exception&)
@@ -969,7 +971,7 @@ void  SwMailMergeConfigItem::SetFilter(::rtl::OUString& rFilter)
         {
             try
             {
-                xRowProperties->setPropertyValue(C2U("ApplyFilter"), makeAny(m_pImpl->sFilter.getLength()>0));
+                xRowProperties->setPropertyValue(C2U("ApplyFilter"), makeAny(!m_pImpl->sFilter.isEmpty()));
                 xRowProperties->setPropertyValue(C2U("Filter"), makeAny(m_pImpl->sFilter));
                 uno::Reference<XRowSet> xRowSet( m_pImpl->xResultSet, UNO_QUERY_THROW );
                 xRowSet->execute();
@@ -1263,7 +1265,7 @@ Sequence< ::rtl::OUString> SwMailMergeConfigItem::GetColumnAssignment(
 {
     ::rtl::OUString sRet;
     Sequence< ::rtl::OUString> aAssignment = GetColumnAssignment( m_pImpl->aDBData );
-    if(aAssignment.getLength() > sal::static_int_cast< sal_Int32, sal_uInt32>(nColumn) && aAssignment[nColumn].getLength())
+    if(aAssignment.getLength() > sal::static_int_cast< sal_Int32, sal_uInt32>(nColumn) && !aAssignment[nColumn].isEmpty())
         sRet = aAssignment[nColumn];
     else if(nColumn < m_pImpl->m_AddressHeaderSA.Count())
         sRet = m_pImpl->m_AddressHeaderSA.GetString(nColumn);
@@ -1328,8 +1330,8 @@ bool SwMailMergeConfigItem::IsAddressFieldsAssigned() const
                     nColumn < rHeaders.Count() && nColumn < aAssignment.getLength();
                                                                                 ++nColumn)
             {
-                if(rHeaders.GetString(nColumn) == aItem.sText &&
-                    pAssignment[nColumn].getLength())
+                if (rHeaders.GetString(nColumn).equals(aItem.sText) &&
+                    !pAssignment[nColumn].isEmpty())
                 {
                     sConvertedColumn = pAssignment[nColumn];
                     break;
@@ -1387,8 +1389,8 @@ bool SwMailMergeConfigItem::IsGreetingFieldsAssigned() const
                     nColumn < rHeaders.Count() && nColumn < aAssignment.getLength();
                                                                                 ++nColumn)
             {
-                if(rHeaders.GetString(nColumn) == aItem.sText &&
-                    pAssignment[nColumn].getLength())
+                if (rHeaders.GetString(nColumn).equals(aItem.sText) &&
+                    !pAssignment[nColumn].isEmpty())
                 {
                     sConvertedColumn = pAssignment[nColumn];
                     break;
@@ -1707,10 +1709,10 @@ void SwMailMergeConfigItem::SetSourceView(SwView* pView)
 
     if(pView)
     {
-        SvStringsDtor aDBNameList(5, 1);
-        SvStringsDtor aAllDBNames(5, 5);
+        std::vector<String> aDBNameList;
+        std::vector<String> aAllDBNames;
         pView->GetWrtShell().GetAllUsedDB( aDBNameList, &aAllDBNames );
-        if(aDBNameList.Count())
+        if(!aDBNameList.empty())
         {
             // if fields are available there is usually no need of an addressblock and greeting
             if(!m_pImpl->bUserSettingWereOverwritten)
