@@ -26,11 +26,15 @@
  *
  ************************************************************************/
 
-
+#include "sal/config.h"
 
 #include <hintids.hxx>
 #include <cmdid.h>
 
+#include <com/sun/star/beans/XMultiPropertySet.hpp>
+#include <com/sun/star/beans/XPropertiesChangeListener.hpp>
+#include <cppuhelper/implbase1.hxx>
+#include <officecfg/Office/Common.hxx>
 #include <rtl/oustringostreaminserter.hxx>
 #include <rtl/ustring.hxx>
 #include <sal/log.hxx>
@@ -41,7 +45,6 @@
 #include <sfx2/app.hxx>
 #include <svtools/htmltokn.h>
 #include <svtools/txtattr.hxx>
-#include <unotools/sourceviewconfig.hxx>
 #include <svtools/colorcfg.hxx>
 #include <editeng/flstitem.hxx>
 #include <vcl/metric.hxx>
@@ -53,7 +56,11 @@
 #include <helpid.h>
 #include <deque>
 
+namespace {
 
+namespace css = com::sun::star;
+
+}
 
 struct SwTextPortion
 {
@@ -214,6 +221,33 @@ static void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
     }
 }
 
+class SwSrcEditWindow::ChangesListener:
+    public cppu::WeakImplHelper1< css::beans::XPropertiesChangeListener >
+{
+public:
+    ChangesListener(SwSrcEditWindow & editor): editor_(editor) {}
+
+private:
+    virtual ~ChangesListener() {}
+
+    virtual void SAL_CALL disposing(css::lang::EventObject const &)
+        throw (css::uno::RuntimeException)
+    {
+        osl::MutexGuard g(editor_.mutex_);
+        editor_.notifier_.clear();
+    }
+
+    virtual void SAL_CALL propertiesChange(
+        css::uno::Sequence< css::beans::PropertyChangeEvent > const &)
+        throw (css::uno::RuntimeException)
+    {
+        SolarMutexGuard g;
+        editor_.SetFont();
+    }
+
+    SwSrcEditWindow & editor_;
+};
+
 SwSrcEditWindow::SwSrcEditWindow( Window* pParent, SwSrcView* pParentView ) :
     Window( pParent, WB_BORDER|WB_CLIPCHILDREN ),
 
@@ -224,7 +258,6 @@ SwSrcEditWindow::SwSrcEditWindow( Window* pParent, SwSrcView* pParentView ) :
     pVScrollbar(0),
 
     pSrcView(pParentView),
-    pSourceViewConfig(new utl::SourceViewConfig),
 
     nCurTextWidth(0),
     nStartLine(USHRT_MAX),
@@ -234,13 +267,33 @@ SwSrcEditWindow::SwSrcEditWindow( Window* pParent, SwSrcView* pParentView ) :
 {
     SetHelpId(HID_SOURCE_EDITWIN);
     CreateTextEngine();
-    pSourceViewConfig->AddListener(this);
+
+    // Using "this" in ctor is a little fishy, but should work here at least as
+    // long as there are no derivations:
+    listener_ = new ChangesListener(*this);
+    css::uno::Reference< css::beans::XMultiPropertySet > n(
+        officecfg::Office::Common::Font::SourceViewFont::get(),
+        css::uno::UNO_QUERY_THROW);
+    {
+        osl::MutexGuard g(mutex_);
+        notifier_ = n;
+    }
+    css::uno::Sequence< rtl::OUString > s(2);
+    s[0] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FontHeight"));
+    s[1] = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("FontName"));
+    n->addPropertiesChangeListener(s, listener_.get());
 }
 
  SwSrcEditWindow::~SwSrcEditWindow()
 {
-    pSourceViewConfig->RemoveListener(this);
-    delete pSourceViewConfig;
+    css::uno::Reference< css::beans::XMultiPropertySet > n;
+    {
+        osl::MutexGuard g(mutex_);
+        n = notifier_;
+    }
+    if (n.is()) {
+        n->removePropertiesChangeListener(listener_.get());
+    }
     aSyntaxIdleTimer.Stop();
     if ( pTextEngine )
     {
@@ -542,7 +595,6 @@ IMPL_LINK( SwSrcEditWindow, SyntaxTimerHdl, Timer *, pTimer )
     SAL_WARN_IF(pTextView == 0, "sw", "No View yet, but syntax highlighting?!");
 
     bHighlighting = sal_True;
-    sal_uInt16 nLine;
     sal_uInt16 nCount  = 0;
     // at first the region around the cursor is processed
     TextSelection aSel = pTextView->GetSelection();
@@ -551,16 +603,15 @@ IMPL_LINK( SwSrcEditWindow, SyntaxTimerHdl, Timer *, pTimer )
         nCur -= 40;
     else
         nCur = 0;
-    if(aSyntaxLineTable.Count())
+    if(!aSyntaxLineTable.empty())
         for(sal_uInt16 i = 0; i < 80 && nCount < 40; i++, nCur++)
         {
-            void * p = aSyntaxLineTable.Get(nCur);
-            if(p)
+            if(aSyntaxLineTable.find(nCur) != aSyntaxLineTable.end())
             {
                 DoSyntaxHighlight( nCur );
-                aSyntaxLineTable.Remove( nCur );
+                aSyntaxLineTable.erase( nCur );
                 nCount++;
-                if(!aSyntaxLineTable.Count())
+                if(aSyntaxLineTable.empty())
                     break;
                 if((Time( Time::SYSTEM ).GetTime() - aSyntaxCheckStart.GetTime()) > MAX_HIGHLIGHTTIME )
                 {
@@ -571,14 +622,11 @@ IMPL_LINK( SwSrcEditWindow, SyntaxTimerHdl, Timer *, pTimer )
         }
 
     // when there is still anything left by then, go on from the beginning
-    void* p = aSyntaxLineTable.First();
-    while ( p && nCount < MAX_SYNTAX_HIGHLIGHT)
+    while ( !aSyntaxLineTable.empty() && nCount < MAX_SYNTAX_HIGHLIGHT)
     {
-        nLine = (sal_uInt16)aSyntaxLineTable.GetCurKey();
+        sal_uInt16 nLine = *aSyntaxLineTable.begin();
         DoSyntaxHighlight( nLine );
-        sal_uInt16 nCurKey = (sal_uInt16)aSyntaxLineTable.GetCurKey();
-        p = aSyntaxLineTable.Next();
-        aSyntaxLineTable.Remove(nCurKey);
+        aSyntaxLineTable.erase(nLine);
         nCount ++;
         if(Time( Time::SYSTEM ).GetTime() - aSyntaxCheckStart.GetTime() > MAX_HIGHLIGHTTIME)
         {
@@ -587,7 +635,7 @@ IMPL_LINK( SwSrcEditWindow, SyntaxTimerHdl, Timer *, pTimer )
         }
     }
 
-    if(aSyntaxLineTable.Count() && !pTimer->IsActive())
+    if(!aSyntaxLineTable.empty() && !pTimer->IsActive())
         pTimer->Start();
     // SyntaxTimerHdl is called when text changed
     // => good opportunity to determine text width!
@@ -628,7 +676,7 @@ void SwSrcEditWindow::DoDelayedSyntaxHighlight( sal_uInt16 nPara )
 {
     if ( !bHighlighting && bDoSyntaxHighlight )
     {
-        aSyntaxLineTable.Insert( nPara, (void*)(sal_uInt16)1 );
+        aSyntaxLineTable.insert( nPara );
         aSyntaxIdleTimer.Start();
     }
 }
@@ -724,12 +772,6 @@ void SwSrcEditWindow::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
     }
 }
 
-void SwSrcEditWindow::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal_uInt32 )
-{
-    if( pBrdCst == pSourceViewConfig)
-        SetFont();
-}
-
 void    SwSrcEditWindow::Invalidate(sal_uInt16 )
 {
     pOutWin->Invalidate();
@@ -928,8 +970,10 @@ sal_Bool  lcl_GetLanguagesForEncoding(rtl_TextEncoding eEnc, LanguageType aLangu
 }
 void SwSrcEditWindow::SetFont()
 {
-    String sFontName = pSourceViewConfig->GetFontName();
-    if(!sFontName.Len())
+    rtl::OUString sFontName(
+        officecfg::Office::Common::Font::SourceViewFont::FontName::get().
+        get_value_or(rtl::OUString()));
+    if(sFontName.isEmpty())
     {
         LanguageType aLanguages[5] =
         {
@@ -955,7 +999,8 @@ void SwSrcEditWindow::SetFont()
     Font aFont(aInfo);
     Size aSize(rFont.GetSize());
     //font height is stored in point and set in twip
-    aSize.Height() = pSourceViewConfig->GetFontHeight() * 20;
+    aSize.Height() =
+        officecfg::Office::Common::Font::SourceViewFont::FontHeight::get() * 20;
     aFont.SetSize(pOutWin->LogicToPixel(aSize, MAP_TWIP));
     GetTextEngine()->SetFont( aFont );
     pOutWin->SetFont(aFont);
