@@ -32,6 +32,8 @@
 #include <hintids.hxx>
 
 #include <svl/globalnameitem.hxx>
+#include <svl/ownlist.hxx>
+#include <sfx2/frmdescr.hxx>
 #include <sfx2/objface.hxx>
 #include <sfx2/lnkbase.hxx>
 
@@ -100,7 +102,6 @@
 #include <shells.hrc>
 #include <popup.hrc>
 #include <swerror.h>
-#include <SwAppletImpl.hxx>
 #include <unochart.hxx>
 
 #include <chartins.hxx>
@@ -286,7 +287,7 @@ void SwTextShell::ExecInsert(SfxRequest &rReq)
             SvCommandList aCommandList;
             if(pCommandsItem)
             {
-                sal_uInt16 nTemp;
+                sal_Int32 nTemp;
                 aCommandList.AppendCommands( pCommandsItem->GetValue(), &nTemp );
             }
 
@@ -630,7 +631,7 @@ void SwTextShell::ExecInsert(SfxRequest &rReq)
                 {
                     SwRewriter aRewriter;
 
-                    aRewriter.AddRule(UNDO_ARG1, SW_RES(STR_FRAME));
+                    aRewriter.AddRule(UndoArg1, SW_RESSTR(STR_FRAME));
 
                     rShell.EndUndo(UNDO_INSERT, &aRewriter);
                 }
@@ -1095,7 +1096,7 @@ void SwTextShell::InsertSymbol( SfxRequest& rReq )
 
         // Selektierten Inhalt loeschen
         SwRewriter aRewriter;
-        aRewriter.AddRule(UNDO_ARG1, SW_RES(STR_SPECIALCHAR));
+        aRewriter.AddRule(UndoArg1, SW_RESSTR(STR_SPECIALCHAR));
 
         rSh.StartUndo( UNDO_INSERT, &aRewriter );
         if ( rSh.HasSelection() )
