@@ -308,7 +308,7 @@ void SAL_CALL UniversalContentBroker::dispose()
     if ( m_pDisposeEventListeners && m_pDisposeEventListeners->getLength() )
     {
         EventObject aEvt;
-        aEvt.Source = SAL_STATIC_CAST( XComponent*, this );
+        aEvt.Source = (static_cast< XComponent* >(this));
         m_pDisposeEventListeners->disposeAndClear( aEvt );
     }
 
@@ -347,10 +347,8 @@ void SAL_CALL UniversalContentBroker::removeEventListener(
 //=========================================================================
 
 XSERVICEINFO_IMPL_1( UniversalContentBroker,
-                     OUString(RTL_CONSTASCII_USTRINGPARAM(
-                         "com.sun.star.comp.ucb.UniversalContentBroker" )),
-                     OUString(RTL_CONSTASCII_USTRINGPARAM(
-                         UCB_SERVICE_NAME )) );
+                     OUString( "com.sun.star.comp.ucb.UniversalContentBroker" ),
+                     OUString( UCB_SERVICE_NAME ) );
 
 //=========================================================================
 //
@@ -632,9 +630,7 @@ Any SAL_CALL UniversalContentBroker::execute(
     //       ctor in ucbcmds.cxx when adding new commands!
     //////////////////////////////////////////////////////////////////////
 
-    if ( ( aCommand.Handle == GETCOMMANDINFO_HANDLE ) ||
-         aCommand.Name.equalsAsciiL(
-                    RTL_CONSTASCII_STRINGPARAM( GETCOMMANDINFO_NAME ) ) )
+    if ( ( aCommand.Handle == GETCOMMANDINFO_HANDLE ) || aCommand.Name == GETCOMMANDINFO_NAME )
     {
         //////////////////////////////////////////////////////////////////
         // getCommandInfo
@@ -642,9 +638,7 @@ Any SAL_CALL UniversalContentBroker::execute(
 
         aRet <<= getCommandInfo();
     }
-    else if ( ( aCommand.Handle == GLOBALTRANSFER_HANDLE ) ||
-              aCommand.Name.equalsAsciiL(
-                    RTL_CONSTASCII_STRINGPARAM(GLOBALTRANSFER_NAME ) ) )
+    else if ( ( aCommand.Handle == GLOBALTRANSFER_HANDLE ) || aCommand.Name == GLOBALTRANSFER_NAME )
     {
         //////////////////////////////////////////////////////////////////
         // globalTransfer
@@ -655,8 +649,7 @@ Any SAL_CALL UniversalContentBroker::execute(
         {
             ucbhelper::cancelCommandExecution(
                 makeAny( IllegalArgumentException(
-                                OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                        "Wrong argument type!" )),
+                                OUString( "Wrong argument type!" ),
                                 static_cast< cppu::OWeakObject * >( this ),
                                 -1 ) ),
                 Environment );
@@ -828,7 +821,7 @@ bool UniversalContentBroker::getContentProviderData(
             const OUString & rKey2,
             ContentProviderDataList & rListToFill )
 {
-    if ( !m_xSMgr.is() || !rKey1.getLength() || !rKey2.getLength() )
+    if ( !m_xSMgr.is() || rKey1.isEmpty() || rKey2.isEmpty() )
     {
         OSL_FAIL( "UniversalContentBroker::getContentProviderData - Invalid argument!" );
         return false;
@@ -838,8 +831,8 @@ bool UniversalContentBroker::getContentProviderData(
     {
         uno::Reference< lang::XMultiServiceFactory > xConfigProv(
                 m_xSMgr->createInstance(
-                    OUString(RTL_CONSTASCII_USTRINGPARAM(
-                        "com.sun.star.configuration.ConfigurationProvider" )) ),
+                    OUString(
+                        "com.sun.star.configuration.ConfigurationProvider" ) ),
                 uno::UNO_QUERY_THROW );
 
         OUStringBuffer aFullPath;
@@ -852,14 +845,13 @@ bool UniversalContentBroker::getContentProviderData(
         uno::Sequence< uno::Any > aArguments( 1 );
         beans::PropertyValue      aProperty;
         aProperty.Name
-            = OUString( RTL_CONSTASCII_USTRINGPARAM( "nodepath" ) );
+            = OUString(  "nodepath"  );
         aProperty.Value <<= aFullPath.makeStringAndClear();
         aArguments[ 0 ] <<= aProperty;
 
         uno::Reference< uno::XInterface > xInterface(
                 xConfigProv->createInstanceWithArguments(
-                    OUString( RTL_CONSTASCII_USTRINGPARAM(
-                        "com.sun.star.configuration.ConfigurationAccess" ) ),
+                    OUString( "com.sun.star.configuration.ConfigurationAccess"  ),
                     aArguments ) );
 
         if ( !m_xNotifier.is() )
