@@ -67,10 +67,10 @@ int DAVAuthListener_Impl::authenticate(
         {
             // #102871# - Supply username and password from previous try.
             // Password container service depends on this!
-            if ( inoutUserName.getLength() == 0 )
+            if ( inoutUserName.isEmpty() )
                 inoutUserName = m_aPrevUsername;
 
-            if ( outPassWord.getLength() == 0 )
+            if ( outPassWord.isEmpty() )
                 outPassWord = m_aPrevPassword;
 
             rtl::Reference< ucbhelper::SimpleAuthenticationRequest > xRequest
@@ -151,6 +151,7 @@ DAVResourceAccess::DAVResourceAccess(
 DAVResourceAccess::DAVResourceAccess( const DAVResourceAccess & rOther )
 : m_aURL( rOther.m_aURL ),
   m_aPath( rOther.m_aPath ),
+  m_aFlags( rOther.m_aFlags ),
   m_xSession( rOther.m_xSession ),
   m_xSessionFactory( rOther.m_xSessionFactory ),
   m_xSMgr( rOther.m_xSMgr ),
@@ -164,6 +165,7 @@ DAVResourceAccess & DAVResourceAccess::operator=(
 {
     m_aURL            = rOther.m_aURL;
     m_aPath           = rOther.m_aPath;
+    m_aFlags          = rOther.m_aFlags;
     m_xSession        = rOther.m_xSession;
     m_xSessionFactory = rOther.m_xSessionFactory;
     m_xSMgr           = rOther.m_xSMgr;
@@ -191,8 +193,7 @@ void DAVResourceAccess::OPTIONS(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                       "OPTIONS" )),
+                                   rtl::OUString( "OPTIONS" ),
                                    aHeaders );
 
             m_xSession->OPTIONS( getRequestURI(),
@@ -202,7 +203,7 @@ void DAVResourceAccess::OPTIONS(
                                      new DAVAuthListener_Impl( xEnv, m_aURL ),
                                      aHeaders, xEnv) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -235,8 +236,7 @@ void DAVResourceAccess::PROPFIND(
 
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                       "PROPFIND" )),
+                                   rtl::OUString( "PROPFIND" ),
                                    aHeaders );
 
             m_xSession->PROPFIND( getRequestURI(),
@@ -248,7 +248,7 @@ void DAVResourceAccess::PROPFIND(
                                       new DAVAuthListener_Impl( xEnv, m_aURL ),
                                       aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -278,8 +278,7 @@ void DAVResourceAccess::PROPFIND(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                       "PROPFIND" )),
+                                   rtl::OUString( "PROPFIND" ),
                                    aHeaders );
 
             m_xSession->PROPFIND( getRequestURI(),
@@ -290,7 +289,7 @@ void DAVResourceAccess::PROPFIND(
                                       new DAVAuthListener_Impl( xEnv, m_aURL ),
                                       aHeaders, xEnv ) ) ;
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -319,8 +318,7 @@ void DAVResourceAccess::PROPPATCH(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                       "PROPPATCH" )),
+                                   rtl::OUString( "PROPPATCH" ),
                                    aHeaders );
 
             m_xSession->PROPPATCH( getRequestURI(),
@@ -330,7 +328,7 @@ void DAVResourceAccess::PROPPATCH(
                                        new DAVAuthListener_Impl( xEnv, m_aURL ),
                                        aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -360,7 +358,7 @@ void DAVResourceAccess::HEAD(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("HEAD")),
+                                   rtl::OUString("HEAD"),
                                    aHeaders );
 
             m_xSession->HEAD( getRequestURI(),
@@ -371,7 +369,7 @@ void DAVResourceAccess::HEAD(
                                   new DAVAuthListener_Impl( xEnv, m_aURL ),
                                   aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -400,7 +398,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::GET(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("GET")),
+                                   rtl::OUString("GET"),
                                    aHeaders );
 
             xStream = m_xSession->GET( getRequestURI(),
@@ -410,7 +408,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::GET(
                                                xEnv, m_aURL ),
                                            aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -441,7 +439,7 @@ void DAVResourceAccess::GET(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("GET")),
+                                   rtl::OUString("GET"),
                                    aHeaders );
 
             m_xSession->GET( getRequestURI(),
@@ -451,7 +449,7 @@ void DAVResourceAccess::GET(
                                  new DAVAuthListener_Impl( xEnv, m_aURL ),
                                  aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -482,7 +480,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::GET(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("GET")),
+                                   rtl::OUString("GET"),
                                    aHeaders );
 
             xStream = m_xSession->GET( getRequestURI(),
@@ -494,7 +492,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::GET(
                                                xEnv, m_aURL ),
                                            aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -527,7 +525,7 @@ void DAVResourceAccess::GET(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("GET")),
+                                   rtl::OUString("GET"),
                                    aHeaders );
 
             m_xSession->GET( getRequestURI(),
@@ -539,7 +537,7 @@ void DAVResourceAccess::GET(
                                  new DAVAuthListener_Impl( xEnv, m_aURL ),
                                  aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -614,7 +612,7 @@ void DAVResourceAccess::PUT(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PUT")),
+                                   rtl::OUString("PUT"),
                                    aHeaders );
 
             m_xSession->PUT( getRequestURI(),
@@ -624,7 +622,7 @@ void DAVResourceAccess::PUT(
                                  new DAVAuthListener_Impl( xEnv, m_aURL ),
                                  aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -666,7 +664,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::POST(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("POST")),
+                                   rtl::OUString("POST"),
                                    aHeaders );
 
             xStream = m_xSession->POST( getRequestURI(),
@@ -679,7 +677,7 @@ uno::Reference< io::XInputStream > DAVResourceAccess::POST(
                                                 xEnv, m_aURL ),
                                             aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -729,7 +727,7 @@ void DAVResourceAccess::POST(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("POST")),
+                                   rtl::OUString("POST"),
                                    aHeaders );
 
             m_xSession->POST( getRequestURI(),
@@ -742,7 +740,7 @@ void DAVResourceAccess::POST(
                                   new DAVAuthListener_Impl( xEnv, m_aURL ),
                                   aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -777,7 +775,7 @@ void DAVResourceAccess::MKCOL(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MKCOL")),
+                                   rtl::OUString("MKCOL"),
                                    aHeaders );
 
             m_xSession->MKCOL( getRequestURI(),
@@ -786,7 +784,7 @@ void DAVResourceAccess::MKCOL(
                                    new DAVAuthListener_Impl( xEnv, m_aURL ),
                                    aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -817,7 +815,7 @@ void DAVResourceAccess::COPY(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("COPY")),
+                                   rtl::OUString("COPY"),
                                    aHeaders );
 
             m_xSession->COPY( rSourcePath,
@@ -828,7 +826,7 @@ void DAVResourceAccess::COPY(
                                   aHeaders, xEnv ),
                               bOverwrite );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -859,7 +857,7 @@ void DAVResourceAccess::MOVE(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("MOVE")),
+                                   rtl::OUString("MOVE"),
                                    aHeaders );
 
             m_xSession->MOVE( rSourcePath,
@@ -870,7 +868,7 @@ void DAVResourceAccess::MOVE(
                                   aHeaders, xEnv ),
                               bOverwrite );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -898,8 +896,7 @@ void DAVResourceAccess::DESTROY(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                                       "DESTROY" )),
+                                   rtl::OUString( "DESTROY" ),
                                    aHeaders );
 
             m_xSession->DESTROY( getRequestURI(),
@@ -908,7 +905,7 @@ void DAVResourceAccess::DESTROY(
                                      new DAVAuthListener_Impl( xEnv, m_aURL ),
                                      aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -938,7 +935,7 @@ void DAVResourceAccess::LOCK(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LOCK")),
+                                   rtl::OUString("LOCK"),
                                    aHeaders );
 
             m_xSession->LOCK( getRequestURI(),
@@ -948,7 +945,7 @@ void DAVResourceAccess::LOCK(
                                   new DAVAuthListener_Impl( xEnv, m_aURL ),
                                   aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -980,7 +977,7 @@ sal_Int64 DAVResourceAccess::LOCK(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("LOCK")),
+                                   rtl::OUString("LOCK"),
                                    aHeaders );
 
             nNewTimeout = m_xSession->LOCK( getRequestURI(),
@@ -991,7 +988,7 @@ sal_Int64 DAVResourceAccess::LOCK(
                                                     xEnv, m_aURL ),
                                             aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -1022,7 +1019,7 @@ void DAVResourceAccess::UNLOCK(
             DAVRequestHeaders aHeaders;
             getUserRequestHeaders( xEnv,
                                    getRequestURI(),
-                                   rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("UNLOCK")),
+                                   rtl::OUString("UNLOCK"),
                                    aHeaders );
 
             m_xSession->UNLOCK( getRequestURI(),
@@ -1031,7 +1028,7 @@ void DAVResourceAccess::UNLOCK(
                                     new DAVAuthListener_Impl( xEnv, m_aURL ),
                                     aHeaders, xEnv ) );
         }
-        catch ( DAVException & e )
+        catch ( const DAVException & e )
         {
             errorCount++;
             bRetry = handleException( e, errorCount );
@@ -1042,6 +1039,14 @@ void DAVResourceAccess::UNLOCK(
     while ( bRetry );
 }
 
+//=========================================================================
+void DAVResourceAccess::setFlags( const uno::Sequence< beans::NamedValue >& rFlags )
+    throw ( DAVException )
+{
+    osl::Guard< osl::Mutex > aGuard( m_aMutex );
+    m_aFlags = rFlags;
+}
+
 //=========================================================================
 void DAVResourceAccess::setURL( const rtl::OUString & rNewURL )
     throw( DAVException )
@@ -1057,26 +1062,26 @@ void DAVResourceAccess::initialize()
     throw ( DAVException )
 {
     osl::Guard< osl::Mutex > aGuard( m_aMutex );
-    if ( m_aPath.getLength() == 0 )
+    if ( m_aPath.isEmpty() )
     {
         NeonUri aURI( m_aURL );
         rtl::OUString aPath( aURI.GetPath() );
 
         /* #134089# - Check URI */
-        if ( !aPath.getLength() )
+        if ( aPath.isEmpty() )
             throw DAVException( DAVException::DAV_INVALID_ARG );
 
         /* #134089# - Check URI */
-        if ( !aURI.GetHost().getLength() )
+        if ( aURI.GetHost().isEmpty() )
             throw DAVException( DAVException::DAV_INVALID_ARG );
 
-        if ( !m_xSession.is() || !m_xSession->CanUse( m_aURL ) )
+        if ( !m_xSession.is() || !m_xSession->CanUse( m_aURL, m_aFlags ) )
         {
             m_xSession.clear();
 
             // create new webdav session
             m_xSession
-                = m_xSessionFactory->createDAVSession( m_aURL, m_xSMgr );
+                = m_xSessionFactory->createDAVSession( m_aURL, m_aFlags, m_xSMgr );
 
             if ( !m_xSession.is() )
                 return;
@@ -1141,6 +1146,21 @@ void DAVResourceAccess::getUserRequestHeaders(
             }
         }
     }
+
+    // Make sure a User-Agent header is always included, as at least
+    // en.wikipedia.org:80 forces back 403 "Scripts should use an informative
+    // User-Agent string with contact information, or they may be IP-blocked
+    // without notice" otherwise:
+    for ( DAVRequestHeaders::iterator i(rRequestHeaders.begin());
+          i != rRequestHeaders.end(); ++i )
+    {
+        if ( i->first.equalsIgnoreAsciiCase( "User-Agent" ) )
+        {
+            return;
+        }
+    }
+    rRequestHeaders.push_back(
+        DAVRequestHeader( "User-Agent", "LibreOffice" ) );
 }
 
 //=========================================================================
@@ -1182,7 +1202,7 @@ void DAVResourceAccess::resetUri()
 }
 
 //=========================================================================
-sal_Bool DAVResourceAccess::handleException( DAVException & e, int errorCount )
+sal_Bool DAVResourceAccess::handleException( const DAVException & e, int errorCount )
     throw ( DAVException )
 {
     switch ( e.getError() )
