@@ -167,7 +167,7 @@ static bool noKeepAlive( const uno::Sequence< beans::NamedValue >& rFlags )
         std::find_if(pAry,pAry+nLen,
                      boost::bind(comphelper::TNamedValueEqualFunctor(),
                                  _1,
-                                 rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("KeepAlive")))));
+                                 rtl::OUString("KeepAlive"))));
     if ( pValue != pAry+nLen && !pValue->Value.get<sal_Bool>() )
         return true;
 
@@ -302,7 +302,7 @@ extern "C" int NeonSession_NeonAuth( void *       inUserData,
         {
             NeonUri uri( theSession->getRequestEnvironment().m_aRequestURI );
             rtl::OUString aUserInfo( uri.GetUserInfo() );
-            if ( aUserInfo.getLength() )
+            if ( !aUserInfo.isEmpty() )
             {
                 sal_Int32 nPos = aUserInfo.indexOf( '@' );
                 if ( nPos == -1 )
@@ -382,7 +382,7 @@ namespace {
     ::rtl::OUString GetHostnamePart( const ::rtl::OUString& _rRawString )
     {
         ::rtl::OUString sPart;
-        ::rtl::OUString sPartId(RTL_CONSTASCII_USTRINGPARAM("CN="));
+        ::rtl::OUString sPartId("CN=");
         sal_Int32 nContStart = _rRawString.indexOf( sPartId );
         if ( nContStart != -1 )
         {
@@ -409,8 +409,7 @@ extern "C" int NeonSession_CertificationNotify( void *userdata,
         xCertificateContainer
             = uno::Reference< security::XCertificateContainer >(
                 pSession->getMSF()->createInstance(
-                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
-                        "com.sun.star.security.CertificateContainer" )) ),
+                    rtl::OUString( "com.sun.star.security.CertificateContainer" ) ),
                 uno::UNO_QUERY );
     }
     catch ( uno::Exception const & )
@@ -442,7 +441,7 @@ extern "C" int NeonSession_CertificationNotify( void *userdata,
     {
         xSEInitializer = uno::Reference< xml::crypto::XSEInitializer >(
             pSession->getMSF()->createInstance(
-                rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( SEINITIALIZER_COMPONENT )) ),
+                rtl::OUString( SEINITIALIZER_COMPONENT ) ),
             uno::UNO_QUERY );
     }
     catch ( uno::Exception const & )
@@ -487,8 +486,7 @@ extern "C" int NeonSession_CertificationNotify( void *userdata,
 
         uno::Reference< security::XCertificate> xImCert(
             xSecurityEnv->createCertificateFromAscii(
-                rtl::OStringToOUString(
-                    sInterMediateCertB64, RTL_TEXTENCODING_ASCII_US ) ) );
+                rtl::OStringToOUString( sInterMediateCertB64, RTL_TEXTENCODING_ASCII_US ) ) );
         if ( xImCert.is() )
             vecCerts.push_back( xImCert );
     }
@@ -577,7 +575,7 @@ extern "C" void NeonSession_PreSendRequest( ne_request * req,
         RequestDataMap::const_iterator it = pRequestData->find( req );
         if ( it != pRequestData->end() )
         {
-            if ( (*it).second.aContentType.getLength() )
+            if ( !(*it).second.aContentType.isEmpty() )
             {
                 char * pData = headers->data;
                 if ( strstr( pData, "Content-Type:" ) == NULL )
@@ -590,7 +588,7 @@ extern "C" void NeonSession_PreSendRequest( ne_request * req,
                 }
             }
 
-            if ( (*it).second.aReferer.getLength() )
+            if ( !(*it).second.aReferer.isEmpty() )
             {
                 char * pData = headers->data;
                 if ( strstr( pData, "Referer:" ) == NULL )
@@ -778,7 +776,7 @@ void NeonSession::Init()
         m_aNeonLockStore.registerSession( m_pHttpSession );
 
         if ( m_aScheme.equalsIgnoreAsciiCase(
-            rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "https" ) ) ) )
+            rtl::OUString(  "https"  ) ) )
         {
             // Set a failure callback for certificate check
             ne_ssl_set_verify(
@@ -825,7 +823,7 @@ void NeonSession::Init()
         ne_hook_destroy_session( m_pHttpSession, destroy_sess_hook_fn, this );
 #endif
 
-        if ( m_aProxyName.getLength() )
+        if ( !m_aProxyName.isEmpty() )
         {
             ne_session_proxy( m_pHttpSession,
                               rtl::OUStringToOString(
@@ -878,7 +876,7 @@ sal_Bool NeonSession::CanUse( const rtl::OUString & inUri,
 sal_Bool NeonSession::UsesProxy()
 {
     Init();
-    return ( m_aProxyName.getLength() > 0 );
+    return  !m_aProxyName.isEmpty() ;
 }
 
 // -------------------------------------------------------------------
@@ -1677,8 +1675,7 @@ void NeonSession::abort()
 // -------------------------------------------------------------------
 const ucbhelper::InternetProxyServer & NeonSession::getProxySettings() const
 {
-    if ( m_aScheme.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "http" ) ) ||
-         m_aScheme.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM( "https" ) ) )
+    if ( m_aScheme == "http" || m_aScheme == "https" )
     {
         return m_rProxyDecider.getProxy( m_aScheme,
                                          m_aHostName,
@@ -1897,7 +1894,7 @@ void runResponseHeaderHandler( void * userdata,
             = static_cast< NeonRequestContext * >( userdata );
 
         // Note: Empty vector means that all headers are requested.
-        bool bIncludeIt = ( pCtx->pHeaderNames->size() == 0 );
+        bool bIncludeIt = ( pCtx->pHeaderNames->empty() );
 
         if ( !bIncludeIt )
         {
@@ -2026,7 +2023,7 @@ int NeonSession::POST( ne_session * sess,
 
     RequestDataMap * pData = 0;
 
-    if ( rContentType.getLength() || rReferer.getLength() )
+    if ( !rContentType.isEmpty() || !rReferer.isEmpty() )
     {
         // Remember contenttype and referer. Data will be added to HTTP request
         // header in in 'PreSendRequest' callback.
@@ -2170,7 +2167,7 @@ NeonSession::isDomainMatch( rtl::OUString certHostName )
     if (hostName.equalsIgnoreAsciiCase( certHostName ) )
         return sal_True;
 
-    if ( 0 == certHostName.indexOf( rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("*")) ) &&
+    if ( 0 == certHostName.indexOf( rtl::OUString("*") ) &&
          hostName.getLength() >= certHostName.getLength()  )
     {
         rtl::OUString cmpStr = certHostName.copy( 1 );
