@@ -26,7 +26,6 @@
  *
  ************************************************************************/
 
-
 #include <unotools/startoptions.hxx>
 #include <unotools/configmgr.hxx>
 #include <unotools/configitem.hxx>
@@ -36,21 +35,13 @@
 
 #include <rtl/logfile.hxx>
 #include "itemholder1.hxx"
-//_________________________________________________________________________________________________________________
-//  namespaces
-//_________________________________________________________________________________________________________________
 
 using namespace ::utl                   ;
 using namespace ::rtl                   ;
 using namespace ::osl                   ;
 using namespace ::com::sun::star::uno   ;
 
-//_________________________________________________________________________________________________________________
-//  const
-//_________________________________________________________________________________________________________________
-
 #define DEFAULT_SHOWINTRO               sal_True
-#define DEFAULT_CONNECTIONURL           OUString()
 
 #define ROOTNODE_START                  OUString(RTL_CONSTASCII_USTRINGPARAM("Setup/Office" ))
 #define PROPERTYNAME_SHOWINTRO          OUString(RTL_CONSTASCII_USTRINGPARAM("ooSetupShowIntro" ))
@@ -61,29 +52,13 @@ using namespace ::com::sun::star::uno   ;
 
 #define PROPERTYCOUNT                   2
 
-//_________________________________________________________________________________________________________________
-//  private declarations!
-//_________________________________________________________________________________________________________________
-
 class SvtStartOptions_Impl : public ConfigItem
 {
-    //-------------------------------------------------------------------------------------------------------------
-    //  public methods
-    //-------------------------------------------------------------------------------------------------------------
-
     public:
 
-        //---------------------------------------------------------------------------------------------------------
-        //  constructor / destructor
-        //---------------------------------------------------------------------------------------------------------
-
          SvtStartOptions_Impl();
         ~SvtStartOptions_Impl();
 
-        //---------------------------------------------------------------------------------------------------------
-        //  overloaded methods of baseclass
-        //---------------------------------------------------------------------------------------------------------
-
         /*-****************************************************************************************************//**
             @short      called for notify of configmanager
             @descr      These method is called from the ConfigManager before application ends or from the
@@ -119,10 +94,6 @@ class SvtStartOptions_Impl : public ConfigItem
 
         virtual void Commit();
 
-        //---------------------------------------------------------------------------------------------------------
-        //  public interface
-        //---------------------------------------------------------------------------------------------------------
-
         /*-****************************************************************************************************//**
             @short      access method to get internal values
             @descr      These method give us a chance to regulate acces to ouer internal values.
@@ -137,11 +108,6 @@ class SvtStartOptions_Impl : public ConfigItem
         *//*-*****************************************************************************************************/
 
         OUString    GetConnectionURL(                       ) const ;
-        void        SetConnectionURL( const OUString& sURL  )       ;
-
-    //-------------------------------------------------------------------------------------------------------------
-    //  private methods
-    //-------------------------------------------------------------------------------------------------------------
 
     private:
 
@@ -161,20 +127,12 @@ class SvtStartOptions_Impl : public ConfigItem
 
         static Sequence< OUString > impl_GetPropertyNames();
 
-    //-------------------------------------------------------------------------------------------------------------
-    //  private member
-    //-------------------------------------------------------------------------------------------------------------
-
     private:
 
         sal_Bool    m_bShowIntro        ;   /// cache "ShowIntro" of Start section
         OUString    m_sConnectionURL    ;   /// cache "Connection" of Start section
 };
 
-//_________________________________________________________________________________________________________________
-//  definitions
-//_________________________________________________________________________________________________________________
-
 //*****************************************************************************************************************
 //  constructor
 //*****************************************************************************************************************
@@ -299,15 +257,6 @@ OUString SvtStartOptions_Impl::GetConnectionURL() const
     return m_sConnectionURL;
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtStartOptions_Impl::SetConnectionURL( const OUString& sURL )
-{
-    m_sConnectionURL = sURL;
-    SetModified();
-}
-
 //*****************************************************************************************************************
 //  private method
 //*****************************************************************************************************************
@@ -379,15 +328,6 @@ OUString SvtStartOptions::GetConnectionURL() const
     return m_pDataContainer->GetConnectionURL();
 }
 
-//*****************************************************************************************************************
-//  public method
-//*****************************************************************************************************************
-void SvtStartOptions::SetConnectionURL( const OUString& sURL )
-{
-    MutexGuard aGuard( GetOwnStaticMutex() );
-    m_pDataContainer->SetConnectionURL( sURL );
-}
-
 namespace
 {
     class theStartOptionsMutex : public rtl::Static<osl::Mutex, theStartOptionsMutex>{};
