@@ -104,7 +104,7 @@ namespace
 
 class FontCfgWrapper
 {
-    FcFontSet*      m_pOutlineSet;
+    FcFontSet* m_pOutlineSet;
 
     void addFontSet( FcSetName );
 
@@ -165,13 +165,13 @@ namespace
     {
         FcChar8 *pNameA=NULL, *pNameB=NULL;
 
-        bool bHaveA = FcPatternGetString(a, FC_FAMILY, 0, &pNameA) == FcResultMatch;
-        bool bHaveB = FcPatternGetString(b, FC_FAMILY, 0, &pNameB) == FcResultMatch;
+        int nHaveA = FcPatternGetString(a, FC_FAMILY, 0, &pNameA) == FcResultMatch;
+        int nHaveB = FcPatternGetString(b, FC_FAMILY, 0, &pNameB) == FcResultMatch;
 
-        if (bHaveA && bHaveB)
+        if (nHaveA && nHaveB)
             return strcmp((const char*)pNameA, (const char*)pNameB);
 
-        return bHaveA - bHaveB;
+        return nHaveA - nHaveB;
     }
 
     //Sort fonts so that fonts with the same family name are side-by-side, with
@@ -187,13 +187,13 @@ namespace
 
             int nVersionA=0, nVersionB=0;
 
-            bool bHaveA = FcPatternGetInteger(a, FC_FONTVERSION, 0, &nVersionA) == FcResultMatch;
-            bool bHaveB = FcPatternGetInteger(b, FC_FONTVERSION, 0, &nVersionB) == FcResultMatch;
+            int nHaveA = FcPatternGetInteger(a, FC_FONTVERSION, 0, &nVersionA) == FcResultMatch;
+            int nHaveB = FcPatternGetInteger(b, FC_FONTVERSION, 0, &nVersionB) == FcResultMatch;
 
-            if (bHaveA && bHaveB)
+            if (nHaveA && nHaveB)
                 return nVersionA > nVersionB;
 
-            return bHaveA - bHaveA;
+            return nHaveA > nHaveB;
         }
     };
 
@@ -394,10 +394,9 @@ FcResult FontCfgWrapper::LocalizedElementFromPattern(FcPattern* pPattern, FcChar
 /*
  * PrintFontManager::initFontconfig
  */
-bool PrintFontManager::initFontconfig()
+void PrintFontManager::initFontconfig()
 {
     FontCfgWrapper::get();
-    return true;
 }
 
 namespace
@@ -467,10 +466,24 @@ namespace
     }
 }
 
-int PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, int, rtl::OStringHash>& o_rVisitedPaths )
+//FontConfig doesn't come with a way to remove an element from a FontSet as far
+//as I can see
+static void lcl_FcFontSetRemove(FcFontSet* pFSet, int i)
 {
-    int nFonts = 0;
+    FcPatternDestroy(pFSet->fonts[i]);
 
+    int nTail = pFSet->nfont - (i + 1);
+    --pFSet->nfont;
+    if (!nTail)
+        return;
+    memmove(pFSet->fonts + i, pFSet->fonts + i + 1, nTail*sizeof(FcPattern*));
+}
+
+void PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, int, rtl::OStringHash>& o_rVisitedPaths )
+{
+#if OSL_DEBUG_LEVEL > 1
+    int nFonts = 0;
+#endif
     FontCfgWrapper& rWrapper = FontCfgWrapper::get();
 
     FcFontSet* pFSet = rWrapper.getFontSet();
@@ -548,10 +561,9 @@ int PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, i
 #endif
                 // not known, analyze font file to get attributes
                 // not described by fontconfig (e.g. alias names, PSName)
-                std::list< OString > aDummy;
                 if (eFormatRes != FcResultMatch)
                     format = NULL;
-                analyzeFontFile( nDirID, aBase, aDummy, aFonts, (const char*)format );
+                analyzeFontFile( nDirID, aBase, aFonts, (const char*)format );
 #if OSL_DEBUG_LEVEL > 1
                 if( aFonts.empty() )
                     fprintf( stderr, "Warning: file \"%s\" is unusable to psprint\n", aOrgPath.getStr() );
@@ -559,7 +571,13 @@ int PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, i
             }
             if( aFonts.empty() )
             {
-                // TODO: remove fonts unusable to psprint from fontset
+                //remove font, reuse index
+                //we want to remove unusable fonts here, in case there is a usable font
+                //which duplicates the properties of the unusable one
+                //
+                //not removing the unusable font will risk the usable font being rejected
+                //as a duplicate by isPreviouslyDuplicateOrObsoleted
+                lcl_FcFontSetRemove(pFSet, i--);
                 continue;
             }
 
@@ -623,7 +641,9 @@ int PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, i
                 fontID aFont = m_nNextFontID++;
                 m_aFonts[ aFont ] = pUpdate;
                 m_aFontFileToFontID[ aBase ].insert( aFont );
+#if OSL_DEBUG_LEVEL > 1
                 nFonts++;
+#endif
 #if OSL_DEBUG_LEVEL > 2
                 fprintf( stderr, "inserted font %s as fontID %d\n", family, aFont );
 #endif
@@ -644,7 +664,6 @@ int PrintFontManager::countFontconfigFonts( boost::unordered_map<rtl::OString, i
 #if OSL_DEBUG_LEVEL > 1
     fprintf( stderr, "inserted %d fonts from fontconfig\n", nFonts );
 #endif
-    return nFonts;
 }
 
 void PrintFontManager::deinitFontconfig()
@@ -758,7 +777,7 @@ static void addtopattern(FcPattern *pPattern,
     }
 }
 
-bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& rMissingCodes ) const
+bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& rMissingCodes )
 {
     bool bRet = false;
 
@@ -775,7 +794,7 @@ bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& r
     FcPatternAddString(pPattern, FC_FAMILY, pTargetNameUtf8);
 
     const rtl::OString aLangAttrib = MsLangId::convertLanguageToIsoByteString(rPattern.meLanguage);
-    if( aLangAttrib.getLength() )
+    if( !aLangAttrib.isEmpty() )
     {
         const FcChar8* pLangAttribUtf8;
         if (aLangAttrib.equalsIgnoreAsciiCase(OString(RTL_CONSTASCII_STRINGPARAM("pa-in"))))
@@ -786,7 +805,7 @@ bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& r
     }
 
     // Add required Unicode characters, if any
-    if ( rMissingCodes.getLength() )
+    if ( !rMissingCodes.isEmpty() )
     {
        FcCharSet *unicodes = FcCharSetCreate();
        for( sal_Int32 nStrIndex = 0; nStrIndex < rMissingCodes.getLength(); )
@@ -826,21 +845,48 @@ bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& r
         if( pSet->nfont > 0 )
         {
             //extract the closest match
-            FcChar8* family = NULL;
-            FcResult eFileRes = FcPatternGetString( pSet->fonts[0], FC_FAMILY, 0, &family );
-
-            // get the family name
+            FcChar8* file = NULL;
+            FcResult eFileRes = FcPatternGetString(pSet->fonts[0], FC_FILE, 0, &file);
+            int nCollectionEntry = 0;
+            FcResult eIndexRes = FcPatternGetInteger(pSet->fonts[0], FC_INDEX, 0, &nCollectionEntry);
+            if (eIndexRes != FcResultMatch)
+                nCollectionEntry = 0;
             if( eFileRes == FcResultMatch )
             {
-                bRet = true;
+                OString aDir, aBase, aOrgPath( (sal_Char*)file );
+                splitPath( aOrgPath, aDir, aBase );
+                int nDirID = getDirectoryAtom( aDir, true );
+                fontID aFont = findFontFileID( nDirID, aBase, nCollectionEntry );
+                if( aFont > 0 )
+                {
+                    FastPrintFontInfo aInfo;
+                    bRet = getFontFastInfo( aFont, aInfo );
+                    rPattern.maSearchName = aInfo.m_aFamilyName;
+                }
+            }
 
-                OString sFamily((sal_Char*)family);
-                boost::unordered_map< rtl::OString, rtl::OString, rtl::OStringHash >::const_iterator aI =
-                    rWrapper.m_aFontNameToLocalized.find(sFamily);
-                if (aI != rWrapper.m_aFontNameToLocalized.end())
-                    sFamily = aI->second;
-                rPattern.maSearchName = rtl::OStringToOUString( sFamily, RTL_TEXTENCODING_UTF8 );
+            SAL_WARN_IF(!bRet, "vcl", "no FC_FILE found, falling back to name search");
 
+            if (!bRet)
+            {
+                FcChar8* family = NULL;
+                FcResult eFamilyRes = FcPatternGetString( pSet->fonts[0], FC_FAMILY, 0, &family );
+
+                // get the family name
+                if( eFamilyRes == FcResultMatch )
+                {
+                    OString sFamily((sal_Char*)family);
+                    boost::unordered_map< rtl::OString, rtl::OString, rtl::OStringHash >::const_iterator aI =
+                        rWrapper.m_aFontNameToLocalized.find(sFamily);
+                    if (aI != rWrapper.m_aFontNameToLocalized.end())
+                        sFamily = aI->second;
+                    rPattern.maSearchName = rtl::OStringToOUString( sFamily, RTL_TEXTENCODING_UTF8 );
+                    bRet = true;
+                }
+            }
+
+            if (bRet)
+            {
                 int val = 0;
                 if (FcResultMatch == FcPatternGetInteger(pSet->fonts[0], FC_WEIGHT, 0, &val))
                     rPattern.meWeight = convertWeight(val);
@@ -864,7 +910,7 @@ bool PrintFontManager::Substitute( FontSelectPattern &rPattern, rtl::OUString& r
             }
 
             // update rMissingCodes by removing resolved unicodes
-            if( rMissingCodes.getLength() > 0 )
+            if( !rMissingCodes.isEmpty() )
             {
                 sal_uInt32* pRemainingCodes = (sal_uInt32*)alloca( rMissingCodes.getLength() * sizeof(sal_uInt32) );
                 int nRemainingLen = 0;
@@ -929,7 +975,7 @@ ImplFontOptions* PrintFontManager::getFontOptions(
     boost::unordered_map< rtl::OString, rtl::OString, rtl::OStringHash >::const_iterator aI = rWrapper.m_aLocalizedToCanonical.find(sFamily);
     if (aI != rWrapper.m_aLocalizedToCanonical.end())
         sFamily = aI->second;
-    if( sFamily.getLength() )
+    if( !sFamily.isEmpty() )
         FcPatternAddString(pPattern, FC_FAMILY, (FcChar8*)sFamily.getStr());
 
     addtopattern(pPattern, rInfo.m_eItalic, rInfo.m_eWeight, rInfo.m_eWidth, rInfo.m_ePitch);
@@ -996,22 +1042,22 @@ bool PrintFontManager::matchFont( FastPrintFontInfo& rInfo, const com::sun::star
 
     OString aLangAttrib;
     // populate pattern with font characteristics
-    if( rLocale.Language.getLength() )
+    if( !rLocale.Language.isEmpty() )
     {
         OUStringBuffer aLang(6);
         aLang.append( rLocale.Language );
-        if( rLocale.Country.getLength() )
+        if( !rLocale.Country.isEmpty() )
         {
             aLang.append( sal_Unicode('-') );
             aLang.append( rLocale.Country );
         }
         aLangAttrib = OUStringToOString( aLang.makeStringAndClear(), RTL_TEXTENCODING_UTF8 );
     }
-    if( aLangAttrib.getLength() )
+    if( !aLangAttrib.isEmpty() )
         FcPatternAddString(pPattern, FC_LANG, (FcChar8*)aLangAttrib.getStr());
 
     OString aFamily = OUStringToOString( rInfo.m_aFamilyName, RTL_TEXTENCODING_UTF8 );
-    if( aFamily.getLength() )
+    if( !aFamily.isEmpty() )
         FcPatternAddString(pPattern, FC_FAMILY, (FcChar8*)aFamily.getStr());
 
     addtopattern(pPattern, rInfo.m_eItalic, rInfo.m_eWeight, rInfo.m_eWidth, rInfo.m_ePitch);
@@ -1031,12 +1077,16 @@ bool PrintFontManager::matchFont( FastPrintFontInfo& rInfo, const com::sun::star
             //extract the closest match
             FcChar8* file = NULL;
             FcResult eFileRes = FcPatternGetString(pSet->fonts[0], FC_FILE, 0, &file);
+            int nCollectionEntry = 0;
+            FcResult eIndexRes = FcPatternGetInteger(pSet->fonts[0], FC_INDEX, 0, &nCollectionEntry);
+            if (eIndexRes != FcResultMatch)
+                nCollectionEntry = 0;
             if( eFileRes == FcResultMatch )
             {
                 OString aDir, aBase, aOrgPath( (sal_Char*)file );
                 splitPath( aOrgPath, aDir, aBase );
                 int nDirID = getDirectoryAtom( aDir, true );
-                fontID aFont = findFontFileID( nDirID, aBase );
+                fontID aFont = findFontFileID( nDirID, aBase, nCollectionEntry );
                 if( aFont > 0 )
                     bSuccess = getFontFastInfo( aFont, rInfo );
             }
