@@ -46,7 +46,6 @@
 #include "XMLScriptContextFactory.hxx"
 #include "StyleMap.hxx"
 #include <xmloff/ProgressBarHelper.hxx>
-#include <xmloff/xmltoken.hxx>
 #include "xmloff/xmlerror.hxx"
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/ServiceNotRegisteredException.hpp>
@@ -59,7 +58,6 @@
 #include <comphelper/namecontainer.hxx>
 #include <comphelper/servicehelper.hxx>
 #include <rtl/logfile.hxx>
-#include <tools/string.hxx> // used in StartElement for logging
 #include <cppuhelper/implbase1.hxx>
 #include <comphelper/extract.hxx>
 #include <comphelper/processfactory.hxx>
@@ -222,9 +220,7 @@ public:
     ::comphelper::UnoInterfaceToUniqueIdentifierMapper  maInterfaceToIdentifierMapper;
 };
 
-typedef SvXMLImportContext *SvXMLImportContextPtr;
-SV_DECL_PTRARR( SvXMLImportContexts_Impl, SvXMLImportContextPtr, 20, 5 )
-SV_IMPL_PTRARR( SvXMLImportContexts_Impl, SvXMLImportContextPtr )
+class SvXMLImportContexts_Impl : public std::vector<SvXMLImportContext *> {};
 
 SvXMLImportContext *SvXMLImport::CreateContext( sal_uInt16 nPrefix,
                                          const OUString& rLocalName,
@@ -327,6 +323,8 @@ void SvXMLImport::_InitCtor()
         mpNamespaceMap->Add(
             OUString( RTL_CONSTASCII_USTRINGPARAM( sXML_np__css3text ) ),
             GetXMLToken(XML_N_CSS3TEXT), XML_NAMESPACE_CSS3TEXT );
+
+        mpNamespaceMap->Add( OUString("_calc_libo"), GetXMLToken(XML_N_CALC_EXT), XML_NAMESPACE_CALC_EXT);
     }
 
     msPackageProtocol = OUString( RTL_CONSTASCII_USTRINGPARAM( "vnd.sun.star.Package:" ) );
@@ -380,11 +378,10 @@ SvXMLImport::~SvXMLImport() throw ()
     delete mpEventImportHelper;
     if( mpContexts )
     {
-        while( mpContexts->Count() )
+        while( !mpContexts->empty() )
         {
-            sal_uInt16 n = mpContexts->Count() - 1;
-            SvXMLImportContext *pContext = (*mpContexts)[n];
-            mpContexts->Remove( n, 1 );
+            SvXMLImportContext *pContext = mpContexts->back();
+            mpContexts->pop_back();
             if( pContext )
                 pContext->ReleaseRef();
         }
@@ -581,13 +578,12 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
     for( sal_Int16 i=0; i < nAttrCount; i++ )
     {
         const OUString& rAttrName = xAttrList->getNameByIndex( i );
-        if ( rAttrName.equalsAsciiL(RTL_CONSTASCII_STRINGPARAM("office:version")) )
+        if ( rAttrName == "office:version" )
         {
             mpImpl->aODFVersion = xAttrList->getValueByIndex( i );
 
             // the ODF version in content.xml and manifest.xml must be the same starting from ODF1.2
-            if ( mpImpl->mStreamName.equals( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "content.xml" ) ) )
-              && !IsODFVersionConsistent( mpImpl->aODFVersion ) )
+            if ( mpImpl->mStreamName == "content.xml" && !IsODFVersionConsistent( mpImpl->aODFVersion ) )
             {
                 throw xml::sax::SAXException(
                         ::rtl::OUString(
@@ -639,7 +635,7 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
     // If there are contexts already, call a CreateChildContext at the topmost
     // context. Otherwise, create a default context.
     SvXMLImportContext *pContext;
-    sal_uInt16 nCount = mpContexts->Count();
+    sal_uInt16 nCount = mpContexts->size();
     if( nCount > 0 )
     {
         pContext = (*mpContexts)[nCount - 1]->CreateChildContext( nPrefix,
@@ -687,7 +683,7 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
     pContext->StartElement( xAttrList );
 
     // Push context on stack.
-    mpContexts->Insert( pContext, nCount );
+    mpContexts->push_back( pContext );
 }
 
 void SAL_CALL SvXMLImport::endElement( const OUString&
@@ -697,13 +693,13 @@ rName
 )
     throw(xml::sax::SAXException, uno::RuntimeException)
 {
-    sal_uInt16 nCount = mpContexts->Count();
+    sal_uInt16 nCount = mpContexts->size();
     DBG_ASSERT( nCount, "SvXMLImport::endElement: no context left" );
     if( nCount > 0 )
     {
         // Get topmost context and remove it from the stack.
-        SvXMLImportContext *pContext = (*mpContexts)[nCount-1];
-        mpContexts->Remove( nCount-1, 1 );
+        SvXMLImportContext *pContext = mpContexts->back();
+        mpContexts->pop_back();
 
 #ifdef DBG_UTIL
         // Non product only: check if endElement call matches startELement call.
@@ -738,10 +734,9 @@ rName
 void SAL_CALL SvXMLImport::characters( const OUString& rChars )
     throw(xml::sax::SAXException, uno::RuntimeException)
 {
-    sal_uInt16 nCount = mpContexts->Count();
-    if( nCount > 0 )
+    if( !mpContexts->empty() )
     {
-        (*mpContexts)[nCount - 1]->Characters( rChars );
+        mpContexts->back()->Characters( rChars );
     }
 }
 
@@ -905,9 +900,9 @@ void SAL_CALL SvXMLImport::initialize( const uno::Sequence< uno::Any >& aArgumen
                     uno::Any aAny = mxImportInfo->getPropertyValue(sPropName);
                     aAny >>= sName;
                 }
-                if( sBaseURI.getLength() && sName.getLength() )
+                if( !sBaseURI.isEmpty() && !sName.isEmpty() )
                 {
-                    if( sRelPath.getLength() )
+                    if( !sRelPath.isEmpty() )
                         mpImpl->aBaseURL.insertName( sRelPath );
                     mpImpl->aBaseURL.insertName( sName );
                 }
@@ -1191,14 +1186,14 @@ sal_Bool SvXMLImport::IsPackageURL( const ::rtl::OUString& rURL ) const
             sRet = mxGraphicResolver->resolveGraphicObjectURL( aTmp );
         }
 
-        if( !sRet.getLength() )
+        if( sRet.isEmpty() )
         {
             sRet = msPackageProtocol;
             sRet += rURL;
         }
     }
 
-    if( !sRet.getLength() )
+    if( sRet.isEmpty() )
         sRet = GetAbsoluteReference( rURL );
 
     return sRet;
@@ -1237,7 +1232,7 @@ Reference< XOutputStream > SvXMLImport::GetStreamForGraphicObjectURLFromBase64()
         if ( mxEmbeddedResolver.is() )
         {
             OUString sURL( rURL );
-            if( rClassId.getLength() )
+            if( !rClassId.isEmpty() )
             {
                 sURL += OUString( sal_Unicode('!') );
                 sURL += rClassId;
@@ -1325,7 +1320,7 @@ OUString SvXMLImport::GetStyleDisplayName( sal_uInt16 nFamily,
                                            const OUString& rName ) const
 {
     OUString sName( rName );
-    if( mpStyleMap && rName.getLength() )
+    if( mpStyleMap && !rName.isEmpty() )
     {
         StyleMap::key_type aKey( nFamily, rName );
         StyleMap::const_iterator aIter = mpStyleMap->find( aKey );
@@ -1388,7 +1383,7 @@ ProgressBarHelper*  SvXMLImport::GetProgressBarHelper()
                     if (aAny.getValueType() == getBooleanCppuType())
                         mpProgressBarHelper->SetRepeat(::cppu::any2bool(aAny));
                     else {
-                        DBG_ERRORFILE("why is it no boolean?");
+                        SAL_WARN( "xmloff.core", "why is it no boolean?" );
                     }
                 }
             }
@@ -1526,7 +1521,7 @@ const SvXMLStylesContext *SvXMLImport::GetAutoStyles() const
 
 OUString SvXMLImport::GetAbsoluteReference(const OUString& rValue) const
 {
-    if( rValue.getLength() == 0 || rValue[0] == '#' )
+    if( rValue.isEmpty() || rValue[0] == '#' )
         return rValue;
 
     INetURLObject aAbsURL;
@@ -1541,7 +1536,7 @@ sal_Bool SvXMLImport::IsODFVersionConsistent( const ::rtl::OUString& aODFVersion
     // the check returns sal_False only if the storage version could be retrieved
     sal_Bool bResult = sal_True;
 
-    if ( aODFVersion.getLength() && aODFVersion.compareTo( ODFVER_012_TEXT ) >= 0 )
+    if ( !aODFVersion.isEmpty() && aODFVersion.compareTo( ODFVER_012_TEXT ) >= 0 )
     {
         // check the consistency only for the ODF1.2 and later ( according to content.xml )
         // manifest.xml might have no version, it should be checked here and the correct version should be set
@@ -1575,7 +1570,7 @@ sal_Bool SvXMLImport::IsODFVersionConsistent( const ::rtl::OUString& aODFVersion
                     // if not, set it explicitly to be used further ( it will work even for readonly storage )
                     // This workaround is not nice, but I see no other way to handle it, since there are
                     // ODF1.2 documents without version in manifest.xml
-                    if ( aStorVersion.getLength() )
+                    if ( !aStorVersion.isEmpty() )
                         bResult = aODFVersion.equals( aStorVersion );
                     else
                         xStorProps->setPropertyValue( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Version" ) ),
@@ -1717,36 +1712,6 @@ void SvXMLImport::SetError(
     SetError( nId, aSeq );
 }
 
-void SvXMLImport::SetError(
-    sal_Int32 nId,
-    const OUString& rMsg1,
-    const OUString& rMsg2,
-    const OUString& rMsg3)
-{
-    Sequence<OUString> aSeq(3);
-    OUString* pSeq = aSeq.getArray();
-    pSeq[0] = rMsg1;
-    pSeq[1] = rMsg2;
-    pSeq[2] = rMsg3;
-    SetError( nId, aSeq );
-}
-
-void SvXMLImport::SetError(
-    sal_Int32 nId,
-    const OUString& rMsg1,
-    const OUString& rMsg2,
-    const OUString& rMsg3,
-    const OUString& rMsg4)
-{
-    Sequence<OUString> aSeq(4);
-    OUString* pSeq = aSeq.getArray();
-    pSeq[0] = rMsg1;
-    pSeq[1] = rMsg2;
-    pSeq[2] = rMsg3;
-    pSeq[3] = rMsg4;
-    SetError( nId, aSeq );
-}
-
 void SvXMLImport::DisposingModel()
 {
     if( mxFontDecls.Is() )
@@ -1779,12 +1744,12 @@ SvXMLImport::GetComponentContext() const
     return mpImpl->mxComponentContext;
 }
 
-String SvXMLImport::GetBaseURL() const
+::rtl::OUString SvXMLImport::GetBaseURL() const
 {
     return mpImpl->aBaseURL.GetMainURL( INetURLObject::NO_DECODE );
 }
 
-String SvXMLImport::GetDocumentBase() const
+::rtl::OUString SvXMLImport::GetDocumentBase() const
 {
     return mpImpl->aDocBase.GetMainURL( INetURLObject::NO_DECODE );
 }
@@ -1821,7 +1786,7 @@ bool SvXMLImport::getBuildIds( sal_Int32& rUPD, sal_Int32& rBuild ) const
         {
             OUString aBuildId;
             mxImportInfo->getPropertyValue( aPropName ) >>= aBuildId;
-            if( aBuildId.getLength() )
+            if( !aBuildId.isEmpty() )
             {
                 sal_Int32 nIndex = aBuildId.indexOf('$');
                 if( nIndex != -1 )
@@ -1869,7 +1834,7 @@ bool SvXMLImport::isGraphicLoadOnDemandSupported() const
 void SvXMLImport::SetXmlId(uno::Reference<uno::XInterface> const & i_xIfc,
     ::rtl::OUString const & i_rXmlId)
 {
-    if (i_rXmlId.getLength() > 0) {
+    if (!i_rXmlId.isEmpty()) {
         try {
             const uno::Reference<rdf::XMetadatable> xMeta(i_xIfc,
                 uno::UNO_QUERY);
